# Rankine cycle with reheat

!!! note "Cycle data"
    > ![](./assets/ex2.png) 

    !!! ukw "Known properties"
        - Water is used as working fluid;
        - Pressure at the outlet of the low pressure turbine of 10 kPa;
        - Pressure at the outlet of the high pressure turbine of 200 kPa;
        - Pressure at the pump outlet of 1000 kPa;
        - Temperatures after leaving the boiler of 250 °C;
        - The pump has an isentropic efficiency of 90%;
        - The turbines have an isentropic efficiency of 80%.


!!! compat "Input code"
    ```julia
    using CycleSolver
    
    @solve begin
        st3.T = 250 + 273
        st5.T = 250 + 273
        st3.p = 1000
        st5.p = 200
        st1.p = 10

        newCycle[]
            pump(st1, st2, 90)
            boiler(st2, st3)
            turbine(st3, st4, 80)
            boiler(st4, st5)
            turbine(st5, st6, 80)
            condenser(st6, st1) 
    end

    PrintResults()
    ```

#### Output:

```@raw html
<div style='display: inline-block; margin: 1px; text-align: center;
    border: 0.5px solid #666666;'><div style='display: inline-block; padding: 15px; margin: 20px;
        border: 2px solid #666666;'>
<h1 style='display: block; text-align: center; border: 1px solid #666666;margin: -17px; margin-bottom: 20px; padding: 10px'>1-  CYCLE [water]</h1><div style='display: flex; justify-content: space-around;'><div style = "display: inline-block; border: 1px solid #666666;"><!DOCTYPE html>
<html>
<meta charset="UTF-8">
<style>
  table, td, th {
      border-collapse: collapse; color: black;
      font-family: sans-serif;
  }

  td, th {
      border-bottom: 0;
      padding: 4px
  }

  tr:nth-child(odd) {
      background: #eee;
  }

  tr:nth-child(even) {
      background: #fff;
  }

  tr.header {
      background: #fff !important;
      font-weight: bold;
  }

  tr.subheader {
      background: #fff !important;
      color: dimgray;
  }

  tr.headerLastRow {
      border-bottom: 2px solid black;
  }

  th.rowNumber, td.rowNumber {
      text-align: right;
  }

</style>
<body>
<table>
  <thead>
    <tr class = "header headerLastRow">
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">State<br>Name</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">T [K]</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">P [kPa]</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">h [kJ/kg]</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">s [kJ/kg.K]</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">x</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">ṁ [kg/s]</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">Mass-flux<br>fraction</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">st1</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">318.956</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">10.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">191.806</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">0.6492</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">0.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;"></td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1.0</td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">st2</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">319.016</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1000.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">192.917</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">0.6495</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;"></td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;"></td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1.0</td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">st3</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">523.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1000.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">2942.79</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">6.9258</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;"></td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;"></td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1.0</td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">st4</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">393.36</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">200.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">2690.28</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">7.0863</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">0.9928</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;"></td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1.0</td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">st5</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">523.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">200.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">2970.91</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">7.7094</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;"></td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;"></td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1.0</td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">st6</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">318.956</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">10.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">2549.14</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">8.04</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">0.9855</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;"></td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1.0</td>
    </tr>
  </tbody>
</table>
</body>
</html>
</div></div><div style='display: flex; justify-content: space-around;
        padding: 10px; margin: 10px;'><?xml version="1.0" encoding="utf-8"?>
<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="600" height="400" viewBox="0 0 2400 1600">
<defs>
  <clipPath id="clip550">
    <rect x="0" y="0" width="2400" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip550)" d="M0 1600 L2400 1600 L2400 0 L0 0  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip551">
    <rect x="480" y="0" width="1681" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip550)" d="M235.283 1423.18 L2352.76 1423.18 L2352.76 47.2441 L235.283 47.2441  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip552">
    <rect x="235" y="47" width="2118" height="1377"/>
  </clipPath>
</defs>
<polyline clip-path="url(#clip550)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,1423.18 2352.76,1423.18 "/>
<polyline clip-path="url(#clip550)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="295.211,1423.18 295.211,1404.28 "/>
<polyline clip-path="url(#clip550)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="731.587,1423.18 731.587,1404.28 "/>
<polyline clip-path="url(#clip550)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1167.96,1423.18 1167.96,1404.28 "/>
<polyline clip-path="url(#clip550)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1604.34,1423.18 1604.34,1404.28 "/>
<polyline clip-path="url(#clip550)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2040.71,1423.18 2040.71,1404.28 "/>
<path clip-path="url(#clip550)" d="M295.211 1454.1 Q291.6 1454.1 289.772 1457.66 Q287.966 1461.2 287.966 1468.33 Q287.966 1475.44 289.772 1479.01 Q291.6 1482.55 295.211 1482.55 Q298.846 1482.55 300.651 1479.01 Q302.48 1475.44 302.48 1468.33 Q302.48 1461.2 300.651 1457.66 Q298.846 1454.1 295.211 1454.1 M295.211 1450.39 Q301.021 1450.39 304.077 1455 Q307.156 1459.58 307.156 1468.33 Q307.156 1477.06 304.077 1481.67 Q301.021 1486.25 295.211 1486.25 Q289.401 1486.25 286.322 1481.67 Q283.267 1477.06 283.267 1468.33 Q283.267 1459.58 286.322 1455 Q289.401 1450.39 295.211 1450.39 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M726.24 1481.64 L742.559 1481.64 L742.559 1485.58 L720.615 1485.58 L720.615 1481.64 Q723.277 1478.89 727.86 1474.26 Q732.466 1469.61 733.647 1468.27 Q735.892 1465.74 736.772 1464.01 Q737.675 1462.25 737.675 1460.56 Q737.675 1457.8 735.73 1456.07 Q733.809 1454.33 730.707 1454.33 Q728.508 1454.33 726.054 1455.09 Q723.624 1455.86 720.846 1457.41 L720.846 1452.69 Q723.67 1451.55 726.124 1450.97 Q728.577 1450.39 730.615 1450.39 Q735.985 1450.39 739.179 1453.08 Q742.374 1455.77 742.374 1460.26 Q742.374 1462.39 741.564 1464.31 Q740.777 1466.2 738.67 1468.8 Q738.091 1469.47 734.99 1472.69 Q731.888 1475.88 726.24 1481.64 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M1170.97 1455.09 L1159.17 1473.54 L1170.97 1473.54 L1170.97 1455.09 M1169.74 1451.02 L1175.62 1451.02 L1175.62 1473.54 L1180.55 1473.54 L1180.55 1477.43 L1175.62 1477.43 L1175.62 1485.58 L1170.97 1485.58 L1170.97 1477.43 L1155.37 1477.43 L1155.37 1472.92 L1169.74 1451.02 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M1604.74 1466.44 Q1601.59 1466.44 1599.74 1468.59 Q1597.91 1470.74 1597.91 1474.49 Q1597.91 1478.22 1599.74 1480.39 Q1601.59 1482.55 1604.74 1482.55 Q1607.89 1482.55 1609.72 1480.39 Q1611.57 1478.22 1611.57 1474.49 Q1611.57 1470.74 1609.72 1468.59 Q1607.89 1466.44 1604.74 1466.44 M1614.03 1451.78 L1614.03 1456.04 Q1612.27 1455.21 1610.46 1454.77 Q1608.68 1454.33 1606.92 1454.33 Q1602.29 1454.33 1599.84 1457.45 Q1597.4 1460.58 1597.06 1466.9 Q1598.42 1464.89 1600.48 1463.82 Q1602.54 1462.73 1605.02 1462.73 Q1610.23 1462.73 1613.24 1465.9 Q1616.27 1469.05 1616.27 1474.49 Q1616.27 1479.82 1613.12 1483.03 Q1609.97 1486.25 1604.74 1486.25 Q1598.75 1486.25 1595.58 1481.67 Q1592.4 1477.06 1592.4 1468.33 Q1592.4 1460.14 1596.29 1455.28 Q1600.18 1450.39 1606.73 1450.39 Q1608.49 1450.39 1610.28 1450.74 Q1612.08 1451.09 1614.03 1451.78 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M2040.71 1469.17 Q2037.38 1469.17 2035.46 1470.95 Q2033.56 1472.73 2033.56 1475.86 Q2033.56 1478.98 2035.46 1480.77 Q2037.38 1482.55 2040.71 1482.55 Q2044.05 1482.55 2045.97 1480.77 Q2047.89 1478.96 2047.89 1475.86 Q2047.89 1472.73 2045.97 1470.95 Q2044.07 1469.17 2040.71 1469.17 M2036.04 1467.18 Q2033.03 1466.44 2031.34 1464.38 Q2029.67 1462.32 2029.67 1459.35 Q2029.67 1455.21 2032.61 1452.8 Q2035.57 1450.39 2040.71 1450.39 Q2045.87 1450.39 2048.81 1452.8 Q2051.75 1455.21 2051.75 1459.35 Q2051.75 1462.32 2050.06 1464.38 Q2048.4 1466.44 2045.41 1467.18 Q2048.79 1467.96 2050.67 1470.26 Q2052.56 1472.55 2052.56 1475.86 Q2052.56 1480.88 2049.49 1483.57 Q2046.43 1486.25 2040.71 1486.25 Q2035 1486.25 2031.92 1483.57 Q2028.86 1480.88 2028.86 1475.86 Q2028.86 1472.55 2030.76 1470.26 Q2032.66 1467.96 2036.04 1467.18 M2034.32 1459.79 Q2034.32 1462.48 2035.99 1463.98 Q2037.68 1465.49 2040.71 1465.49 Q2043.72 1465.49 2045.41 1463.98 Q2047.12 1462.48 2047.12 1459.79 Q2047.12 1457.11 2045.41 1455.6 Q2043.72 1454.1 2040.71 1454.1 Q2037.68 1454.1 2035.99 1455.6 Q2034.32 1457.11 2034.32 1459.79 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M1160.39 1533.45 L1160.39 1538.98 Q1157.9 1537.71 1155.23 1537.07 Q1152.56 1536.44 1149.69 1536.44 Q1145.33 1536.44 1143.14 1537.77 Q1140.97 1539.11 1140.97 1541.79 Q1140.97 1543.82 1142.53 1545 Q1144.09 1546.15 1148.8 1547.2 L1150.81 1547.64 Q1157.05 1548.98 1159.66 1551.43 Q1162.3 1553.85 1162.3 1558.21 Q1162.3 1563.17 1158.35 1566.07 Q1154.44 1568.97 1147.56 1568.97 Q1144.7 1568.97 1141.58 1568.39 Q1138.49 1567.85 1135.05 1566.74 L1135.05 1560.69 Q1138.3 1562.38 1141.45 1563.24 Q1144.6 1564.07 1147.69 1564.07 Q1151.83 1564.07 1154.05 1562.66 Q1156.28 1561.23 1156.28 1558.65 Q1156.28 1556.27 1154.66 1554.99 Q1153.07 1553.72 1147.62 1552.54 L1145.59 1552.07 Q1140.14 1550.92 1137.73 1548.56 Q1135.31 1546.18 1135.31 1542.04 Q1135.31 1537.01 1138.87 1534.27 Q1142.44 1531.54 1148.99 1531.54 Q1152.24 1531.54 1155.1 1532.01 Q1157.97 1532.49 1160.39 1533.45 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M1191.8 1518.52 L1205.3 1518.52 L1205.3 1523.07 L1197.66 1523.07 L1197.66 1572.09 L1205.3 1572.09 L1205.3 1576.64 L1191.8 1576.64 L1191.8 1518.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M1217.55 1518.52 L1223.44 1518.52 L1223.44 1547.77 L1240.91 1532.4 L1248.39 1532.4 L1229.49 1549.07 L1249.19 1568.04 L1241.55 1568.04 L1223.44 1550.63 L1223.44 1568.04 L1217.55 1568.04 L1217.55 1518.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M1255.78 1520.52 L1262.21 1520.52 L1262.21 1564.73 Q1262.21 1573.33 1258.93 1577.21 Q1255.68 1581.09 1248.46 1581.09 L1246.01 1581.09 L1246.01 1575.68 L1248.01 1575.68 Q1252.28 1575.68 1254.03 1573.3 Q1255.78 1570.91 1255.78 1564.73 L1255.78 1520.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M1285.16 1520.52 L1290.57 1520.52 L1274.02 1574.09 L1268.6 1574.09 L1285.16 1520.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M1296.49 1518.52 L1302.37 1518.52 L1302.37 1547.77 L1319.85 1532.4 L1327.33 1532.4 L1308.42 1549.07 L1328.12 1568.04 L1320.48 1568.04 L1302.37 1550.63 L1302.37 1568.04 L1296.49 1568.04 L1296.49 1518.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M1357.92 1549.81 Q1357.92 1543.44 1355.27 1539.94 Q1352.66 1536.44 1347.92 1536.44 Q1343.21 1536.44 1340.57 1539.94 Q1337.96 1543.44 1337.96 1549.81 Q1337.96 1556.14 1340.57 1559.64 Q1343.21 1563.14 1347.92 1563.14 Q1352.66 1563.14 1355.27 1559.64 Q1357.92 1556.14 1357.92 1549.81 M1363.77 1563.62 Q1363.77 1572.72 1359.73 1577.15 Q1355.69 1581.6 1347.35 1581.6 Q1344.26 1581.6 1341.52 1581.13 Q1338.79 1580.68 1336.21 1579.72 L1336.21 1574.03 Q1338.79 1575.43 1341.3 1576.1 Q1343.82 1576.76 1346.43 1576.76 Q1352.19 1576.76 1355.05 1573.74 Q1357.92 1570.75 1357.92 1564.67 L1357.92 1561.77 Q1356.1 1564.92 1353.27 1566.48 Q1350.44 1568.04 1346.49 1568.04 Q1339.93 1568.04 1335.92 1563.05 Q1331.91 1558.05 1331.91 1549.81 Q1331.91 1541.53 1335.92 1536.53 Q1339.93 1531.54 1346.49 1531.54 Q1350.44 1531.54 1353.27 1533.1 Q1356.1 1534.66 1357.92 1537.81 L1357.92 1532.4 L1363.77 1532.4 L1363.77 1563.62 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M1376.66 1559.96 L1383.38 1559.96 L1383.38 1568.04 L1376.66 1568.04 L1376.66 1559.96 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M1396.81 1520.52 L1403.24 1520.52 L1403.24 1540.61 L1424.56 1520.52 L1432.84 1520.52 L1409.25 1542.68 L1434.53 1568.04 L1426.06 1568.04 L1403.24 1545.16 L1403.24 1568.04 L1396.81 1568.04 L1396.81 1520.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M1452.99 1518.52 L1452.99 1576.64 L1439.49 1576.64 L1439.49 1572.09 L1447.1 1572.09 L1447.1 1523.07 L1439.49 1523.07 L1439.49 1518.52 L1452.99 1518.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><polyline clip-path="url(#clip550)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,1423.18 235.283,47.2441 "/>
<polyline clip-path="url(#clip550)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,1291.07 254.18,1291.07 "/>
<polyline clip-path="url(#clip550)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,943.936 254.18,943.936 "/>
<polyline clip-path="url(#clip550)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,596.803 254.18,596.803 "/>
<polyline clip-path="url(#clip550)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,249.671 254.18,249.671 "/>
<path clip-path="url(#clip550)" d="M131.181 1289.71 Q134.538 1290.43 136.413 1292.7 Q138.311 1294.97 138.311 1298.3 Q138.311 1303.42 134.792 1306.22 Q131.274 1309.02 124.793 1309.02 Q122.617 1309.02 120.302 1308.58 Q118.01 1308.16 115.556 1307.31 L115.556 1302.79 Q117.501 1303.93 119.816 1304.51 Q122.13 1305.08 124.654 1305.08 Q129.052 1305.08 131.343 1303.35 Q133.658 1301.61 133.658 1298.3 Q133.658 1295.25 131.505 1293.53 Q129.376 1291.8 125.556 1291.8 L121.529 1291.8 L121.529 1287.95 L125.742 1287.95 Q129.191 1287.95 131.019 1286.59 Q132.848 1285.2 132.848 1282.61 Q132.848 1279.95 130.95 1278.53 Q129.075 1277.1 125.556 1277.1 Q123.635 1277.1 121.436 1277.51 Q119.237 1277.93 116.598 1278.81 L116.598 1274.64 Q119.26 1273.9 121.575 1273.53 Q123.913 1273.16 125.973 1273.16 Q131.297 1273.16 134.399 1275.59 Q137.501 1278 137.501 1282.12 Q137.501 1284.99 135.857 1286.98 Q134.214 1288.95 131.181 1289.71 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M157.177 1276.87 Q153.566 1276.87 151.737 1280.43 Q149.931 1283.97 149.931 1291.1 Q149.931 1298.21 151.737 1301.77 Q153.566 1305.32 157.177 1305.32 Q160.811 1305.32 162.616 1301.77 Q164.445 1298.21 164.445 1291.1 Q164.445 1283.97 162.616 1280.43 Q160.811 1276.87 157.177 1276.87 M157.177 1273.16 Q162.987 1273.16 166.042 1277.77 Q169.121 1282.35 169.121 1291.1 Q169.121 1299.83 166.042 1304.44 Q162.987 1309.02 157.177 1309.02 Q151.366 1309.02 148.288 1304.44 Q145.232 1299.83 145.232 1291.1 Q145.232 1282.35 148.288 1277.77 Q151.366 1273.16 157.177 1273.16 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M187.338 1276.87 Q183.727 1276.87 181.899 1280.43 Q180.093 1283.97 180.093 1291.1 Q180.093 1298.21 181.899 1301.77 Q183.727 1305.32 187.338 1305.32 Q190.973 1305.32 192.778 1301.77 Q194.607 1298.21 194.607 1291.1 Q194.607 1283.97 192.778 1280.43 Q190.973 1276.87 187.338 1276.87 M187.338 1273.16 Q193.149 1273.16 196.204 1277.77 Q199.283 1282.35 199.283 1291.1 Q199.283 1299.83 196.204 1304.44 Q193.149 1309.02 187.338 1309.02 Q181.528 1309.02 178.45 1304.44 Q175.394 1299.83 175.394 1291.1 Q175.394 1282.35 178.45 1277.77 Q181.528 1273.16 187.338 1273.16 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M129.862 930.73 L118.056 949.179 L129.862 949.179 L129.862 930.73 M128.635 926.656 L134.515 926.656 L134.515 949.179 L139.445 949.179 L139.445 953.068 L134.515 953.068 L134.515 961.216 L129.862 961.216 L129.862 953.068 L114.26 953.068 L114.26 948.554 L128.635 926.656 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M157.177 929.734 Q153.566 929.734 151.737 933.299 Q149.931 936.841 149.931 943.97 Q149.931 951.077 151.737 954.642 Q153.566 958.183 157.177 958.183 Q160.811 958.183 162.616 954.642 Q164.445 951.077 164.445 943.97 Q164.445 936.841 162.616 933.299 Q160.811 929.734 157.177 929.734 M157.177 926.031 Q162.987 926.031 166.042 930.637 Q169.121 935.22 169.121 943.97 Q169.121 952.697 166.042 957.304 Q162.987 961.887 157.177 961.887 Q151.366 961.887 148.288 957.304 Q145.232 952.697 145.232 943.97 Q145.232 935.22 148.288 930.637 Q151.366 926.031 157.177 926.031 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M187.338 929.734 Q183.727 929.734 181.899 933.299 Q180.093 936.841 180.093 943.97 Q180.093 951.077 181.899 954.642 Q183.727 958.183 187.338 958.183 Q190.973 958.183 192.778 954.642 Q194.607 951.077 194.607 943.97 Q194.607 936.841 192.778 933.299 Q190.973 929.734 187.338 929.734 M187.338 926.031 Q193.149 926.031 196.204 930.637 Q199.283 935.22 199.283 943.97 Q199.283 952.697 196.204 957.304 Q193.149 961.887 187.338 961.887 Q181.528 961.887 178.45 957.304 Q175.394 952.697 175.394 943.97 Q175.394 935.22 178.45 930.637 Q181.528 926.031 187.338 926.031 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M117.061 579.523 L135.417 579.523 L135.417 583.459 L121.343 583.459 L121.343 591.931 Q122.362 591.584 123.38 591.421 Q124.399 591.236 125.418 591.236 Q131.205 591.236 134.584 594.408 Q137.964 597.579 137.964 602.995 Q137.964 608.574 134.492 611.676 Q131.019 614.755 124.7 614.755 Q122.524 614.755 120.255 614.384 Q118.01 614.014 115.603 613.273 L115.603 608.574 Q117.686 609.708 119.908 610.264 Q122.13 610.82 124.607 610.82 Q128.612 610.82 130.95 608.713 Q133.288 606.607 133.288 602.995 Q133.288 599.384 130.95 597.278 Q128.612 595.171 124.607 595.171 Q122.732 595.171 120.857 595.588 Q119.006 596.005 117.061 596.884 L117.061 579.523 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M157.177 582.602 Q153.566 582.602 151.737 586.167 Q149.931 589.709 149.931 596.838 Q149.931 603.945 151.737 607.509 Q153.566 611.051 157.177 611.051 Q160.811 611.051 162.616 607.509 Q164.445 603.945 164.445 596.838 Q164.445 589.709 162.616 586.167 Q160.811 582.602 157.177 582.602 M157.177 578.898 Q162.987 578.898 166.042 583.505 Q169.121 588.088 169.121 596.838 Q169.121 605.565 166.042 610.171 Q162.987 614.755 157.177 614.755 Q151.366 614.755 148.288 610.171 Q145.232 605.565 145.232 596.838 Q145.232 588.088 148.288 583.505 Q151.366 578.898 157.177 578.898 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M187.338 582.602 Q183.727 582.602 181.899 586.167 Q180.093 589.709 180.093 596.838 Q180.093 603.945 181.899 607.509 Q183.727 611.051 187.338 611.051 Q190.973 611.051 192.778 607.509 Q194.607 603.945 194.607 596.838 Q194.607 589.709 192.778 586.167 Q190.973 582.602 187.338 582.602 M187.338 578.898 Q193.149 578.898 196.204 583.505 Q199.283 588.088 199.283 596.838 Q199.283 605.565 196.204 610.171 Q193.149 614.755 187.338 614.755 Q181.528 614.755 178.45 610.171 Q175.394 605.565 175.394 596.838 Q175.394 588.088 178.45 583.505 Q181.528 578.898 187.338 578.898 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M127.593 247.808 Q124.445 247.808 122.593 249.96 Q120.765 252.113 120.765 255.863 Q120.765 259.59 122.593 261.766 Q124.445 263.919 127.593 263.919 Q130.742 263.919 132.57 261.766 Q134.422 259.59 134.422 255.863 Q134.422 252.113 132.57 249.96 Q130.742 247.808 127.593 247.808 M136.876 233.155 L136.876 237.414 Q135.117 236.581 133.311 236.141 Q131.529 235.701 129.769 235.701 Q125.14 235.701 122.686 238.826 Q120.255 241.951 119.908 248.271 Q121.274 246.257 123.334 245.192 Q125.394 244.104 127.871 244.104 Q133.08 244.104 136.089 247.275 Q139.121 250.423 139.121 255.863 Q139.121 261.187 135.973 264.405 Q132.825 267.622 127.593 267.622 Q121.598 267.622 118.427 263.039 Q115.256 258.433 115.256 249.706 Q115.256 241.511 119.144 236.65 Q123.033 231.766 129.584 231.766 Q131.343 231.766 133.126 232.113 Q134.931 232.461 136.876 233.155 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M157.177 235.47 Q153.566 235.47 151.737 239.035 Q149.931 242.576 149.931 249.706 Q149.931 256.812 151.737 260.377 Q153.566 263.919 157.177 263.919 Q160.811 263.919 162.616 260.377 Q164.445 256.812 164.445 249.706 Q164.445 242.576 162.616 239.035 Q160.811 235.47 157.177 235.47 M157.177 231.766 Q162.987 231.766 166.042 236.373 Q169.121 240.956 169.121 249.706 Q169.121 258.433 166.042 263.039 Q162.987 267.622 157.177 267.622 Q151.366 267.622 148.288 263.039 Q145.232 258.433 145.232 249.706 Q145.232 240.956 148.288 236.373 Q151.366 231.766 157.177 231.766 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M187.338 235.47 Q183.727 235.47 181.899 239.035 Q180.093 242.576 180.093 249.706 Q180.093 256.812 181.899 260.377 Q183.727 263.919 187.338 263.919 Q190.973 263.919 192.778 260.377 Q194.607 256.812 194.607 249.706 Q194.607 242.576 192.778 239.035 Q190.973 235.47 187.338 235.47 M187.338 231.766 Q193.149 231.766 196.204 236.373 Q199.283 240.956 199.283 249.706 Q199.283 258.433 196.204 263.039 Q193.149 267.622 187.338 267.622 Q181.528 267.622 178.45 263.039 Q175.394 258.433 175.394 249.706 Q175.394 240.956 178.45 236.373 Q181.528 231.766 187.338 231.766 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M16.4842 809.579 L16.4842 769.38 L21.895 769.38 L21.895 786.249 L64.0042 786.249 L64.0042 792.71 L21.895 792.71 L21.895 809.579 L16.4842 809.579 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M14.479 743.249 L14.479 729.753 L19.0304 729.753 L19.0304 737.392 L68.0464 737.392 L68.0464 729.753 L72.5979 729.753 L72.5979 743.249 L14.479 743.249 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M16.4842 717.022 L16.4842 710.593 L36.568 710.593 L16.4842 689.267 L16.4842 680.992 L38.6368 704.577 L64.0042 679.305 L64.0042 687.772 L41.1194 710.593 L64.0042 710.593 L64.0042 717.022 L16.4842 717.022 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M14.479 660.845 L72.5979 660.845 L72.5979 674.34 L68.0464 674.34 L68.0464 666.733 L19.0304 666.733 L19.0304 674.34 L14.479 674.34 L14.479 660.845 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><polyline clip-path="url(#clip552)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:0.4; fill:none" points="295.211,1384.24 443.695,1216.93 563.227,1061.17 662.484,916.939 746.779,784.25 819.624,663.098 883.407,553.485 939.81,455.41 990.065,368.873 1035.11,293.874 1075.7,230.414 1112.49,178.492 1146.4,138.108 1178.19,109.262 1209.7,91.9548 1256.76,86.1857 1318.1,91.9548 1362.21,109.262 1401.83,138.108 1439.89,178.492 1477.32,230.414 1514.72,293.874 1552.89,368.873 1592.93,455.41 1636.42,553.485 1685.67,663.098 1744.32,784.25 1818.34,916.939 1918.32,1061.17 2063.88,1216.93 2292.83,1384.24 "/>
<polyline clip-path="url(#clip552)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:0.5; fill:none" stroke-dasharray="16, 10" points="436.858,1225.26 436.858,1225.15 "/>
<polyline clip-path="url(#clip552)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="436.858,1225.26 436.934,1225.06 "/>
<polyline clip-path="url(#clip552)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="436.934,1225.06 464.286,1191.34 490.865,1157.62 516.723,1123.9 541.909,1090.18 566.467,1056.46 590.442,1022.75 613.874,989.027 636.804,955.308 659.269,921.589 681.307,887.87 702.954,854.151 724.245,820.433 745.215,786.714 761.711,759.858 1731.98,759.858 1734.53,752.995 1746.42,719.276 1757.53,685.557 1768.07,651.838 1778.16,618.119 1787.87,584.401 1797.25,550.682 1806.35,516.963 "/>
<polyline clip-path="url(#clip552)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:0.5; fill:none" stroke-dasharray="16, 10" points="1806.35,516.963 1806.35,966.985 "/>
<polyline clip-path="url(#clip552)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1806.35,516.963 1841.36,966.985 "/>
<polyline clip-path="url(#clip552)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1841.36,966.985 1850.21,966.985 1861.95,932.368 1873.17,897.751 1883.97,863.134 1894.42,828.517 1904.55,793.9 1914.4,759.282 1924,724.665 1933.37,690.048 1942.52,655.431 1951.48,620.814 1960.26,586.197 1968.86,551.58 1977.3,516.963 "/>
<polyline clip-path="url(#clip552)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:0.5; fill:none" stroke-dasharray="16, 10" points="1977.3,516.963 1977.3,1225.26 "/>
<polyline clip-path="url(#clip552)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1977.3,516.963 2049.43,1225.26 "/>
<polyline clip-path="url(#clip552)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2049.43,1225.26 436.858,1225.26 "/>
<polyline clip-path="url(#clip552)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:0.4; fill:none" points="436.858,1225.26 2073.18,1225.26 2084.8,1194.28 2096.02,1163.29 2106.92,1132.3 2117.52,1101.31 2127.86,1070.32 2137.94,1039.34 2147.79,1008.35 2157.42,977.359 "/>
<polyline clip-path="url(#clip552)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:0.4; fill:none" points="761.711,759.858 1731.98,759.858 1743.73,727.138 1754.67,694.418 1765.04,661.698 1774.96,628.978 1784.5,596.258 1793.71,563.538 1802.64,530.818 1811.32,498.098 1819.77,465.378 1828.01,432.658 1836.07,399.938 1843.96,367.218 1851.68,334.498 1859.26,301.778 1866.7,269.057 "/>
<polyline clip-path="url(#clip552)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:0.4; fill:none" points="629.077,966.985 1850.21,966.985 1861.49,933.75 1872.29,900.516 1882.7,867.281 1892.77,834.046 1902.55,800.812 1912.07,767.577 1921.34,734.342 1930.4,701.108 1939.26,667.873 1947.93,634.639 1956.42,601.404 1964.76,568.169 1972.94,534.935 1980.98,501.7 1988.87,468.465 1996.64,435.231 2004.29,401.996 2011.81,368.761 2019.23,335.527 2026.53,302.292 2033.74,269.057 "/>
<path clip-path="url(#clip550)" d="M322.366 1261.63 L322.366 1201.21 L369.097 1201.21 L369.097 1261.63 L322.366 1261.63 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M367.939 1261.63 L367.939 1201.21 L414.669 1201.21 L414.669 1261.63 L367.939 1261.63 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M413.512 1261.63 L413.512 1201.21 L460.242 1201.21 L460.242 1261.63 L413.512 1261.63 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M459.084 1261.63 L459.084 1201.21 L505.815 1201.21 L505.815 1261.63 L459.084 1261.63 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M504.657 1261.63 L504.657 1201.21 L551.387 1201.21 L551.387 1261.63 L504.657 1261.63 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M368.069 1217.33 L368.069 1221.36 Q366.264 1220.43 364.319 1219.97 Q362.375 1219.51 360.292 1219.51 Q357.12 1219.51 355.523 1220.48 Q353.949 1221.45 353.949 1223.4 Q353.949 1224.88 355.083 1225.73 Q356.218 1226.57 359.643 1227.33 L361.102 1227.66 Q365.639 1228.63 367.537 1230.41 Q369.458 1232.17 369.458 1235.34 Q369.458 1238.95 366.588 1241.06 Q363.741 1243.16 358.741 1243.16 Q356.657 1243.16 354.389 1242.75 Q352.143 1242.35 349.644 1241.54 L349.644 1237.15 Q352.005 1238.37 354.296 1239 Q356.588 1239.6 358.833 1239.6 Q361.843 1239.6 363.463 1238.58 Q365.083 1237.54 365.083 1235.66 Q365.083 1233.93 363.903 1233 Q362.745 1232.08 358.787 1231.22 L357.305 1230.87 Q353.347 1230.04 351.588 1228.33 Q349.829 1226.59 349.829 1223.58 Q349.829 1219.92 352.421 1217.93 Q355.014 1215.94 359.782 1215.94 Q362.143 1215.94 364.227 1216.29 Q366.31 1216.64 368.069 1217.33 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M380.454 1209.21 L380.454 1216.57 L389.227 1216.57 L389.227 1219.88 L380.454 1219.88 L380.454 1233.95 Q380.454 1237.12 381.31 1238.03 Q382.19 1238.93 384.852 1238.93 L389.227 1238.93 L389.227 1242.49 L384.852 1242.49 Q379.921 1242.49 378.046 1240.66 Q376.171 1238.81 376.171 1233.95 L376.171 1219.88 L373.046 1219.88 L373.046 1216.57 L376.171 1216.57 L376.171 1209.21 L380.454 1209.21 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M396.24 1238.56 L403.879 1238.56 L403.879 1212.19 L395.569 1213.86 L395.569 1209.6 L403.833 1207.93 L408.509 1207.93 L408.509 1238.56 L416.148 1238.56 L416.148 1242.49 L396.24 1242.49 L396.24 1238.56 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M456.587 1217.33 L456.587 1221.36 Q454.782 1220.43 452.837 1219.97 Q450.893 1219.51 448.81 1219.51 Q445.638 1219.51 444.041 1220.48 Q442.467 1221.45 442.467 1223.4 Q442.467 1224.88 443.601 1225.73 Q444.736 1226.57 448.161 1227.33 L449.62 1227.66 Q454.157 1228.63 456.055 1230.41 Q457.976 1232.17 457.976 1235.34 Q457.976 1238.95 455.106 1241.06 Q452.259 1243.16 447.259 1243.16 Q445.175 1243.16 442.907 1242.75 Q440.662 1242.35 438.162 1241.54 L438.162 1237.15 Q440.523 1238.37 442.814 1239 Q445.106 1239.6 447.351 1239.6 Q450.361 1239.6 451.981 1238.58 Q453.601 1237.54 453.601 1235.66 Q453.601 1233.93 452.421 1233 Q451.263 1232.08 447.305 1231.22 L445.824 1230.87 Q441.865 1230.04 440.106 1228.33 Q438.347 1226.59 438.347 1223.58 Q438.347 1219.92 440.939 1217.93 Q443.532 1215.94 448.3 1215.94 Q450.661 1215.94 452.745 1216.29 Q454.828 1216.64 456.587 1217.33 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M468.972 1209.21 L468.972 1216.57 L477.745 1216.57 L477.745 1219.88 L468.972 1219.88 L468.972 1233.95 Q468.972 1237.12 469.828 1238.03 Q470.708 1238.93 473.37 1238.93 L477.745 1238.93 L477.745 1242.49 L473.37 1242.49 Q468.439 1242.49 466.564 1240.66 Q464.689 1238.81 464.689 1233.95 L464.689 1219.88 L461.564 1219.88 L461.564 1216.57 L464.689 1216.57 L464.689 1209.21 L468.972 1209.21 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M487.976 1238.56 L504.295 1238.56 L504.295 1242.49 L482.351 1242.49 L482.351 1238.56 Q485.013 1235.8 489.596 1231.17 Q494.203 1226.52 495.383 1225.18 Q497.629 1222.66 498.508 1220.92 Q499.411 1219.16 499.411 1217.47 Q499.411 1214.72 497.467 1212.98 Q495.545 1211.24 492.444 1211.24 Q490.245 1211.24 487.791 1212.01 Q485.36 1212.77 482.583 1214.32 L482.583 1209.6 Q485.407 1208.47 487.86 1207.89 Q490.314 1207.31 492.351 1207.31 Q497.721 1207.31 500.916 1209.99 Q504.11 1212.68 504.11 1217.17 Q504.11 1219.3 503.3 1221.22 Q502.513 1223.12 500.407 1225.71 Q499.828 1226.38 496.726 1229.6 Q493.624 1232.79 487.976 1238.56 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M1760.2 553.378 L1760.2 492.961 L1806.93 492.961 L1806.93 553.378 L1760.2 553.378 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M1805.77 553.378 L1805.77 492.961 L1852.5 492.961 L1852.5 553.378 L1805.77 553.378 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M1791.23 509.081 L1791.23 513.109 Q1789.43 512.183 1787.48 511.72 Q1785.54 511.257 1783.45 511.257 Q1780.28 511.257 1778.68 512.229 Q1777.11 513.201 1777.11 515.146 Q1777.11 516.627 1778.24 517.484 Q1779.38 518.317 1782.8 519.081 L1784.26 519.405 Q1788.8 520.377 1790.7 522.16 Q1792.62 523.919 1792.62 527.09 Q1792.62 530.701 1789.75 532.808 Q1786.9 534.914 1781.9 534.914 Q1779.82 534.914 1777.55 534.498 Q1775.3 534.104 1772.8 533.294 L1772.8 528.896 Q1775.17 530.123 1777.46 530.748 Q1779.75 531.349 1781.99 531.349 Q1785 531.349 1786.62 530.331 Q1788.24 529.289 1788.24 527.414 Q1788.24 525.678 1787.06 524.752 Q1785.91 523.826 1781.95 522.97 L1780.47 522.623 Q1776.51 521.789 1774.75 520.076 Q1772.99 518.34 1772.99 515.331 Q1772.99 511.674 1775.58 509.683 Q1778.18 507.692 1782.94 507.692 Q1785.3 507.692 1787.39 508.039 Q1789.47 508.387 1791.23 509.081 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M1803.61 500.956 L1803.61 508.317 L1812.39 508.317 L1812.39 511.627 L1803.61 511.627 L1803.61 525.701 Q1803.61 528.873 1804.47 529.775 Q1805.35 530.678 1808.01 530.678 L1812.39 530.678 L1812.39 534.243 L1808.01 534.243 Q1803.08 534.243 1801.21 532.414 Q1799.33 530.562 1799.33 525.701 L1799.33 511.627 L1796.21 511.627 L1796.21 508.317 L1799.33 508.317 L1799.33 500.956 L1803.61 500.956 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M1832.76 515.609 Q1836.11 516.326 1837.99 518.595 Q1839.89 520.863 1839.89 524.197 Q1839.89 529.312 1836.37 532.113 Q1832.85 534.914 1826.37 534.914 Q1824.19 534.914 1821.88 534.474 Q1819.59 534.058 1817.13 533.201 L1817.13 528.687 Q1819.08 529.822 1821.39 530.4 Q1823.71 530.979 1826.23 530.979 Q1830.63 530.979 1832.92 529.243 Q1835.24 527.507 1835.24 524.197 Q1835.24 521.141 1833.08 519.428 Q1830.95 517.692 1827.13 517.692 L1823.11 517.692 L1823.11 513.85 L1827.32 513.85 Q1830.77 513.85 1832.6 512.484 Q1834.42 511.095 1834.42 508.502 Q1834.42 505.84 1832.53 504.428 Q1830.65 502.993 1827.13 502.993 Q1825.21 502.993 1823.01 503.41 Q1820.81 503.826 1818.18 504.706 L1818.18 500.539 Q1820.84 499.799 1823.15 499.428 Q1825.49 499.058 1827.55 499.058 Q1832.87 499.058 1835.98 501.489 Q1839.08 503.896 1839.08 508.016 Q1839.08 510.887 1837.43 512.877 Q1835.79 514.845 1832.76 515.609 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M1795.21 1003.4 L1795.21 942.983 L1841.94 942.983 L1841.94 1003.4 L1795.21 1003.4 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M1840.78 1003.4 L1840.78 942.983 L1887.51 942.983 L1887.51 1003.4 L1840.78 1003.4 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M1825.68 959.103 L1825.68 963.131 Q1823.87 962.205 1821.93 961.742 Q1819.99 961.279 1817.9 961.279 Q1814.73 961.279 1813.13 962.251 Q1811.56 963.223 1811.56 965.168 Q1811.56 966.649 1812.69 967.506 Q1813.83 968.339 1817.25 969.103 L1818.71 969.427 Q1823.25 970.399 1825.15 972.182 Q1827.07 973.941 1827.07 977.112 Q1827.07 980.723 1824.2 982.83 Q1821.35 984.936 1816.35 984.936 Q1814.27 984.936 1812 984.52 Q1809.75 984.126 1807.25 983.316 L1807.25 978.918 Q1809.61 980.145 1811.91 980.77 Q1814.2 981.371 1816.44 981.371 Q1819.45 981.371 1821.07 980.353 Q1822.69 979.311 1822.69 977.436 Q1822.69 975.7 1821.51 974.774 Q1820.36 973.848 1816.4 972.992 L1814.92 972.645 Q1810.96 971.811 1809.2 970.098 Q1807.44 968.362 1807.44 965.353 Q1807.44 961.696 1810.03 959.705 Q1812.62 957.714 1817.39 957.714 Q1819.75 957.714 1821.84 958.061 Q1823.92 958.409 1825.68 959.103 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M1838.06 950.978 L1838.06 958.339 L1846.84 958.339 L1846.84 961.649 L1838.06 961.649 L1838.06 975.723 Q1838.06 978.895 1838.92 979.797 Q1839.8 980.7 1842.46 980.7 L1846.84 980.7 L1846.84 984.265 L1842.46 984.265 Q1837.53 984.265 1835.66 982.436 Q1833.78 980.584 1833.78 975.723 L1833.78 961.649 L1830.66 961.649 L1830.66 958.339 L1833.78 958.339 L1833.78 950.978 L1838.06 950.978 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M1865.89 953.779 L1854.08 972.228 L1865.89 972.228 L1865.89 953.779 M1864.66 949.705 L1870.54 949.705 L1870.54 972.228 L1875.47 972.228 L1875.47 976.117 L1870.54 976.117 L1870.54 984.265 L1865.89 984.265 L1865.89 976.117 L1850.29 976.117 L1850.29 971.603 L1864.66 949.705 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M1931.15 553.378 L1931.15 492.961 L1977.88 492.961 L1977.88 553.378 L1931.15 553.378 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M1976.72 553.378 L1976.72 492.961 L2023.45 492.961 L2023.45 553.378 L1976.72 553.378 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M1962.36 509.081 L1962.36 513.109 Q1960.55 512.183 1958.61 511.72 Q1956.67 511.257 1954.58 511.257 Q1951.41 511.257 1949.81 512.229 Q1948.24 513.201 1948.24 515.146 Q1948.24 516.627 1949.37 517.484 Q1950.51 518.317 1953.93 519.081 L1955.39 519.405 Q1959.93 520.377 1961.83 522.16 Q1963.75 523.919 1963.75 527.09 Q1963.75 530.701 1960.88 532.808 Q1958.03 534.914 1953.03 534.914 Q1950.95 534.914 1948.68 534.498 Q1946.43 534.104 1943.93 533.294 L1943.93 528.896 Q1946.3 530.123 1948.59 530.748 Q1950.88 531.349 1953.12 531.349 Q1956.13 531.349 1957.75 530.331 Q1959.37 529.289 1959.37 527.414 Q1959.37 525.678 1958.19 524.752 Q1957.04 523.826 1953.08 522.97 L1951.6 522.623 Q1947.64 521.789 1945.88 520.076 Q1944.12 518.34 1944.12 515.331 Q1944.12 511.674 1946.71 509.683 Q1949.3 507.692 1954.07 507.692 Q1956.43 507.692 1958.52 508.039 Q1960.6 508.387 1962.36 509.081 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M1974.74 500.956 L1974.74 508.317 L1983.52 508.317 L1983.52 511.627 L1974.74 511.627 L1974.74 525.701 Q1974.74 528.873 1975.6 529.775 Q1976.48 530.678 1979.14 530.678 L1983.52 530.678 L1983.52 534.243 L1979.14 534.243 Q1974.21 534.243 1972.34 532.414 Q1970.46 530.562 1970.46 525.701 L1970.46 511.627 L1967.34 511.627 L1967.34 508.317 L1970.46 508.317 L1970.46 500.956 L1974.74 500.956 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M1989.77 499.683 L2008.12 499.683 L2008.12 503.618 L1994.05 503.618 L1994.05 512.09 Q1995.07 511.743 1996.09 511.581 Q1997.11 511.396 1998.12 511.396 Q2003.91 511.396 2007.29 514.567 Q2010.67 517.738 2010.67 523.155 Q2010.67 528.734 2007.2 531.836 Q2003.73 534.914 1997.41 534.914 Q1995.23 534.914 1992.96 534.544 Q1990.72 534.174 1988.31 533.433 L1988.31 528.734 Q1990.39 529.868 1992.61 530.424 Q1994.84 530.979 1997.31 530.979 Q2001.32 530.979 2003.66 528.873 Q2005.99 526.766 2005.99 523.155 Q2005.99 519.544 2003.66 517.437 Q2001.32 515.331 1997.31 515.331 Q1995.44 515.331 1993.56 515.748 Q1991.71 516.164 1989.77 517.044 L1989.77 499.683 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M2003.28 1261.68 L2003.28 1201.26 L2050.01 1201.26 L2050.01 1261.68 L2003.28 1261.68 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M2048.85 1261.68 L2048.85 1201.26 L2095.58 1201.26 L2095.58 1261.68 L2048.85 1261.68 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M2033.91 1217.38 L2033.91 1221.41 Q2032.11 1220.48 2030.16 1220.02 Q2028.22 1219.56 2026.13 1219.56 Q2022.96 1219.56 2021.37 1220.53 Q2019.79 1221.5 2019.79 1223.45 Q2019.79 1224.93 2020.93 1225.79 Q2022.06 1226.62 2025.49 1227.38 L2026.94 1227.71 Q2031.48 1228.68 2033.38 1230.46 Q2035.3 1232.22 2035.3 1235.39 Q2035.3 1239 2032.43 1241.11 Q2029.58 1243.22 2024.58 1243.22 Q2022.5 1243.22 2020.23 1242.8 Q2017.99 1242.41 2015.49 1241.6 L2015.49 1237.2 Q2017.85 1238.42 2020.14 1239.05 Q2022.43 1239.65 2024.68 1239.65 Q2027.68 1239.65 2029.31 1238.63 Q2030.93 1237.59 2030.93 1235.72 Q2030.93 1233.98 2029.75 1233.05 Q2028.59 1232.13 2024.63 1231.27 L2023.15 1230.92 Q2019.19 1230.09 2017.43 1228.38 Q2015.67 1226.64 2015.67 1223.63 Q2015.67 1219.98 2018.26 1217.98 Q2020.86 1215.99 2025.62 1215.99 Q2027.99 1215.99 2030.07 1216.34 Q2032.15 1216.69 2033.91 1217.38 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M2046.3 1209.26 L2046.3 1216.62 L2055.07 1216.62 L2055.07 1219.93 L2046.3 1219.93 L2046.3 1234 Q2046.3 1237.17 2047.15 1238.08 Q2048.03 1238.98 2050.69 1238.98 L2055.07 1238.98 L2055.07 1242.54 L2050.69 1242.54 Q2045.76 1242.54 2043.89 1240.72 Q2042.01 1238.86 2042.01 1234 L2042.01 1219.93 L2038.89 1219.93 L2038.89 1216.62 L2042.01 1216.62 L2042.01 1209.26 L2046.3 1209.26 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip550)" d="M2071.85 1223.4 Q2068.7 1223.4 2066.85 1225.55 Q2065.02 1227.71 2065.02 1231.46 Q2065.02 1235.18 2066.85 1237.36 Q2068.7 1239.51 2071.85 1239.51 Q2075 1239.51 2076.83 1237.36 Q2078.68 1235.18 2078.68 1231.46 Q2078.68 1227.71 2076.83 1225.55 Q2075 1223.4 2071.85 1223.4 M2081.13 1208.75 L2081.13 1213.01 Q2079.37 1212.17 2077.57 1211.73 Q2075.79 1211.29 2074.03 1211.29 Q2069.4 1211.29 2066.94 1214.42 Q2064.51 1217.54 2064.17 1223.86 Q2065.53 1221.85 2067.59 1220.79 Q2069.65 1219.7 2072.13 1219.7 Q2077.34 1219.7 2080.35 1222.87 Q2083.38 1226.02 2083.38 1231.46 Q2083.38 1236.78 2080.23 1240 Q2077.08 1243.22 2071.85 1243.22 Q2065.86 1243.22 2062.68 1238.63 Q2059.51 1234.03 2059.51 1225.3 Q2059.51 1217.1 2063.4 1212.24 Q2067.29 1207.36 2073.84 1207.36 Q2075.6 1207.36 2077.38 1207.71 Q2079.19 1208.05 2081.13 1208.75 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /></svg>
</div><div style=' border: 1px solid;'><h3 style='text-align: center;margin: 8px;'>Cycle Properties:</h3><div style='display: flex; justify-content: space-around;'><div style = "display: inline-block; border: 1px solid #666666;"><!DOCTYPE html>
<html>
<meta charset="UTF-8">
<style>
  table, td, th {
      border-collapse: collapse; color: black;
      font-family: sans-serif;
  }

  td, th {
      border-bottom: 0;
      padding: 4px
  }

  tr:nth-child(odd) {
      background: #eee;
  }

  tr:nth-child(even) {
      background: #fff;
  }

  tr.header {
      background: #fff !important;
      font-weight: bold;
  }

  tr.subheader {
      background: #fff !important;
      color: dimgray;
  }

  tr.headerLastRow {
      border-bottom: 2px solid black;
  }

  th.rowNumber, td.rowNumber {
      text-align: right;
  }

</style>
<body>
<table>
  <thead>
    <tr class = "header headerLastRow">
      <th style = "color: black; text-align: center; padding: 11px; font-size: 130%;"></th>
      <th style = "color: black; text-align: center; padding: 11px; font-size: 130%;">Total</th>
      <th style = "color: black; text-align: center; padding: 11px; font-size: 130%;">Component</th>
      <th style = "color: black; text-align: center; padding: 11px; font-size: 130%;">Value</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">qin<BR>Q̇in</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">3030.508 kJ/kg<BR>0.0 kW</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">boiler:<BR>   st2 &gt;&gt; st3<BR><BR>boiler:<BR>   st4 &gt;&gt; st5</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">2749.8738 kJ/kg<BR><BR><BR>280.6342 kJ/kg<BR></td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">qout<BR>Q̇out</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">2357.3323 kJ/kg<BR>0.0 kW</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">condenser:<BR>   st6 &gt;&gt; st1</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">2357.3323 kJ/kg<BR></td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">win<BR>Ẇin</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">1.1111 kJ/kg<BR>0.0 kW</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">pump:<BR>   st1 &gt;&gt; st2</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">1.1111 kJ/kg<BR></td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">wout<BR>Ẇout</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">674.2868 kJ/kg<BR>0.0 kW</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">turbine:<BR>   st3 &gt;&gt; st4<BR><BR>turbine:<BR>   st5 &gt;&gt; st6</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">252.5148 kJ/kg<BR><BR><BR>421.772 kJ/kg<BR></td>
    </tr>
  </tbody>
</table>
</body>
</html>
</div></div><h3 style='text-align: center; border: 2px solid #666666; padding: 15px; margin: 10px;'>Thermal efficiency (n) = 22.2133 %</h3></div>
</div></br></div>

```
