# Brayton Cycle

!!! note "Cycle data"
    > ![](./assets/ex4.png) 

    !!! ukw "Known properties"
        - Air is used as working fluid;
        - Pressure at the compressor inlet 100 kPa;
        - Temperature at the compressor inlet 20 °C;
        - Pressure ratio equal to 7;
        - Temperature at the turbine inlet 500 °C;
        - The turbine and compressor have an isentropic efficiency of 90%.


!!! compat "Input code"
    ```julia
    using CycleSolver
    
    @solve begin
            st2.p / st1.p = 7
            st1.T = 20 + 273
            st1.p = 100
            st3.T = 500 + 273  
            newCycle[Air] 
                compressor(st1, st2, 90)
                combustion_chamber(st2, st3)
                turbine(st3, st4, 90)
                combustion_chamber(st4, st1)
    end

    PrintResults()
    ```

#### Output:

```@raw html
<div style='display: inline-block; margin: 1px; text-align: center;
    border: 0.5px solid #666666;'><div style='display: inline-block; padding: 15px; margin: 20px;
        border: 2px solid #666666;'>
<h1 style='display: block; text-align: center; border: 1px solid #666666;margin: -17px; margin-bottom: 20px; padding: 10px'>1-  CYCLE [Air]</h1><div style='display: flex; justify-content: space-around;'><div style = "display: inline-block; border: 1px solid #666666;"><!DOCTYPE html>
<html>
<meta charset="UTF-8">
<style>
  table, td, th {
      border-collapse: collapse; color: black;
      font-family: sans-serif;
  }

  td, th {
      border-bottom: 0;
      padding: 4px
  }

  tr:nth-child(odd) {
      background: #eee;
  }

  tr:nth-child(even) {
      background: #fff;
  }

  tr.header {
      background: #fff !important;
      font-weight: bold;
  }

  tr.subheader {
      background: #fff !important;
      color: dimgray;
  }

  tr.headerLastRow {
      border-bottom: 2px solid black;
  }

  th.rowNumber, td.rowNumber {
      text-align: right;
  }

</style>
<body>
<table>
  <thead>
    <tr class = "header headerLastRow">
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">State<br>Name</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">T [K]</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">P [kPa]</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">h [kJ/kg]</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">s [kJ/kg.K]</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">x</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">ṁ [kg/s]</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">Mass-flux<br>fraction</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">st1</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">293.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">100.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">419.257</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">3.8667</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;"></td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;"></td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1.0</td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">st2</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">532.122</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">700.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">662.359</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">3.9135</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;"></td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;"></td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1.0</td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">st3</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">773.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">700.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">918.995</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">4.3107</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;"></td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;"></td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1.0</td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">st4</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">487.236</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">100.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">616.266</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">4.3821</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;"></td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;"></td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1.0</td>
    </tr>
  </tbody>
</table>
</body>
</html>
</div></div><div style='display: flex; justify-content: space-around;
        padding: 10px; margin: 10px;'><?xml version="1.0" encoding="utf-8"?>
<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="600" height="400" viewBox="0 0 2400 1600">
<defs>
  <clipPath id="clip710">
    <rect x="0" y="0" width="2400" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip710)" d="M0 1600 L2400 1600 L2400 0 L0 0  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip711">
    <rect x="480" y="0" width="1681" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip710)" d="M235.283 1423.18 L2352.76 1423.18 L2352.76 47.2441 L235.283 47.2441  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip712">
    <rect x="235" y="47" width="2118" height="1377"/>
  </clipPath>
</defs>
<polyline clip-path="url(#clip710)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,1423.18 2352.76,1423.18 "/>
<polyline clip-path="url(#clip710)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="448.085,1423.18 448.085,1404.28 "/>
<polyline clip-path="url(#clip710)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="861.956,1423.18 861.956,1404.28 "/>
<polyline clip-path="url(#clip710)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1275.83,1423.18 1275.83,1404.28 "/>
<polyline clip-path="url(#clip710)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1689.7,1423.18 1689.7,1404.28 "/>
<polyline clip-path="url(#clip710)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2103.57,1423.18 2103.57,1404.28 "/>
<path clip-path="url(#clip710)" d="M429.439 1466.95 Q432.796 1467.66 434.671 1469.93 Q436.569 1472.2 436.569 1475.53 Q436.569 1480.65 433.05 1483.45 Q429.532 1486.25 423.05 1486.25 Q420.875 1486.25 418.56 1485.81 Q416.268 1485.39 413.814 1484.54 L413.814 1480.02 Q415.759 1481.16 418.074 1481.74 Q420.388 1482.32 422.912 1482.32 Q427.31 1482.32 429.601 1480.58 Q431.916 1478.84 431.916 1475.53 Q431.916 1472.48 429.763 1470.77 Q427.634 1469.03 423.814 1469.03 L419.787 1469.03 L419.787 1465.19 L424 1465.19 Q427.449 1465.19 429.277 1463.82 Q431.106 1462.43 431.106 1459.84 Q431.106 1457.18 429.208 1455.77 Q427.333 1454.33 423.814 1454.33 Q421.893 1454.33 419.694 1454.75 Q417.495 1455.16 414.856 1456.04 L414.856 1451.88 Q417.518 1451.14 419.833 1450.77 Q422.171 1450.39 424.231 1450.39 Q429.555 1450.39 432.657 1452.83 Q435.759 1455.23 435.759 1459.35 Q435.759 1462.22 434.115 1464.21 Q432.472 1466.18 429.439 1466.95 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M445.435 1479.7 L450.319 1479.7 L450.319 1485.58 L445.435 1485.58 L445.435 1479.7 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M470.504 1469.17 Q467.171 1469.17 465.249 1470.95 Q463.351 1472.73 463.351 1475.86 Q463.351 1478.98 465.249 1480.77 Q467.171 1482.55 470.504 1482.55 Q473.837 1482.55 475.759 1480.77 Q477.68 1478.96 477.68 1475.86 Q477.68 1472.73 475.759 1470.95 Q473.86 1469.17 470.504 1469.17 M465.828 1467.18 Q462.819 1466.44 461.129 1464.38 Q459.462 1462.32 459.462 1459.35 Q459.462 1455.21 462.402 1452.8 Q465.365 1450.39 470.504 1450.39 Q475.666 1450.39 478.606 1452.8 Q481.546 1455.21 481.546 1459.35 Q481.546 1462.32 479.856 1464.38 Q478.189 1466.44 475.203 1467.18 Q478.583 1467.96 480.458 1470.26 Q482.356 1472.55 482.356 1475.86 Q482.356 1480.88 479.277 1483.57 Q476.221 1486.25 470.504 1486.25 Q464.786 1486.25 461.708 1483.57 Q458.652 1480.88 458.652 1475.86 Q458.652 1472.55 460.55 1470.26 Q462.448 1467.96 465.828 1467.18 M464.115 1459.79 Q464.115 1462.48 465.782 1463.98 Q467.472 1465.49 470.504 1465.49 Q473.513 1465.49 475.203 1463.98 Q476.916 1462.48 476.916 1459.79 Q476.916 1457.11 475.203 1455.6 Q473.513 1454.1 470.504 1454.1 Q467.472 1454.1 465.782 1455.6 Q464.115 1457.11 464.115 1459.79 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M842.593 1455.09 L830.787 1473.54 L842.593 1473.54 L842.593 1455.09 M841.366 1451.02 L847.245 1451.02 L847.245 1473.54 L852.176 1473.54 L852.176 1477.43 L847.245 1477.43 L847.245 1485.58 L842.593 1485.58 L842.593 1477.43 L826.991 1477.43 L826.991 1472.92 L841.366 1451.02 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M859.907 1479.7 L864.791 1479.7 L864.791 1485.58 L859.907 1485.58 L859.907 1479.7 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M884.977 1454.1 Q881.365 1454.1 879.537 1457.66 Q877.731 1461.2 877.731 1468.33 Q877.731 1475.44 879.537 1479.01 Q881.365 1482.55 884.977 1482.55 Q888.611 1482.55 890.416 1479.01 Q892.245 1475.44 892.245 1468.33 Q892.245 1461.2 890.416 1457.66 Q888.611 1454.1 884.977 1454.1 M884.977 1450.39 Q890.787 1450.39 893.842 1455 Q896.921 1459.58 896.921 1468.33 Q896.921 1477.06 893.842 1481.67 Q890.787 1486.25 884.977 1486.25 Q879.166 1486.25 876.088 1481.67 Q873.032 1477.06 873.032 1468.33 Q873.032 1459.58 876.088 1455 Q879.166 1450.39 884.977 1450.39 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M1257.26 1455.09 L1245.46 1473.54 L1257.26 1473.54 L1257.26 1455.09 M1256.04 1451.02 L1261.91 1451.02 L1261.91 1473.54 L1266.85 1473.54 L1266.85 1477.43 L1261.91 1477.43 L1261.91 1485.58 L1257.26 1485.58 L1257.26 1477.43 L1241.66 1477.43 L1241.66 1472.92 L1256.04 1451.02 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M1274.58 1479.7 L1279.46 1479.7 L1279.46 1485.58 L1274.58 1485.58 L1274.58 1479.7 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M1293.67 1481.64 L1309.99 1481.64 L1309.99 1485.58 L1288.05 1485.58 L1288.05 1481.64 Q1290.71 1478.89 1295.29 1474.26 Q1299.9 1469.61 1301.08 1468.27 Q1303.33 1465.74 1304.21 1464.01 Q1305.11 1462.25 1305.11 1460.56 Q1305.11 1457.8 1303.16 1456.07 Q1301.24 1454.33 1298.14 1454.33 Q1295.94 1454.33 1293.49 1455.09 Q1291.06 1455.86 1288.28 1457.41 L1288.28 1452.69 Q1291.1 1451.55 1293.56 1450.97 Q1296.01 1450.39 1298.05 1450.39 Q1303.42 1450.39 1306.61 1453.08 Q1309.81 1455.77 1309.81 1460.26 Q1309.81 1462.39 1309 1464.31 Q1308.21 1466.2 1306.1 1468.8 Q1305.53 1469.47 1302.42 1472.69 Q1299.32 1475.88 1293.67 1481.64 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M1670.09 1455.09 L1658.29 1473.54 L1670.09 1473.54 L1670.09 1455.09 M1668.86 1451.02 L1674.74 1451.02 L1674.74 1473.54 L1679.67 1473.54 L1679.67 1477.43 L1674.74 1477.43 L1674.74 1485.58 L1670.09 1485.58 L1670.09 1477.43 L1654.49 1477.43 L1654.49 1472.92 L1668.86 1451.02 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M1687.41 1479.7 L1692.29 1479.7 L1692.29 1485.58 L1687.41 1485.58 L1687.41 1479.7 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M1715.32 1455.09 L1703.52 1473.54 L1715.32 1473.54 L1715.32 1455.09 M1714.1 1451.02 L1719.97 1451.02 L1719.97 1473.54 L1724.91 1473.54 L1724.91 1477.43 L1719.97 1477.43 L1719.97 1485.58 L1715.32 1485.58 L1715.32 1477.43 L1699.72 1477.43 L1699.72 1472.92 L1714.1 1451.02 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M2084.12 1455.09 L2072.32 1473.54 L2084.12 1473.54 L2084.12 1455.09 M2082.9 1451.02 L2088.78 1451.02 L2088.78 1473.54 L2093.71 1473.54 L2093.71 1477.43 L2088.78 1477.43 L2088.78 1485.58 L2084.12 1485.58 L2084.12 1477.43 L2068.52 1477.43 L2068.52 1472.92 L2082.9 1451.02 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M2101.44 1479.7 L2106.32 1479.7 L2106.32 1485.58 L2101.44 1485.58 L2101.44 1479.7 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M2127.09 1466.44 Q2123.94 1466.44 2122.09 1468.59 Q2120.26 1470.74 2120.26 1474.49 Q2120.26 1478.22 2122.09 1480.39 Q2123.94 1482.55 2127.09 1482.55 Q2130.23 1482.55 2132.06 1480.39 Q2133.92 1478.22 2133.92 1474.49 Q2133.92 1470.74 2132.06 1468.59 Q2130.23 1466.44 2127.09 1466.44 M2136.37 1451.78 L2136.37 1456.04 Q2134.61 1455.21 2132.8 1454.77 Q2131.02 1454.33 2129.26 1454.33 Q2124.63 1454.33 2122.18 1457.45 Q2119.75 1460.58 2119.4 1466.9 Q2120.77 1464.89 2122.83 1463.82 Q2124.89 1462.73 2127.36 1462.73 Q2132.57 1462.73 2135.58 1465.9 Q2138.61 1469.05 2138.61 1474.49 Q2138.61 1479.82 2135.47 1483.03 Q2132.32 1486.25 2127.09 1486.25 Q2121.09 1486.25 2117.92 1481.67 Q2114.75 1477.06 2114.75 1468.33 Q2114.75 1460.14 2118.64 1455.28 Q2122.53 1450.39 2129.08 1450.39 Q2130.84 1450.39 2132.62 1450.74 Q2134.42 1451.09 2136.37 1451.78 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M1160.39 1533.45 L1160.39 1538.98 Q1157.9 1537.71 1155.23 1537.07 Q1152.56 1536.44 1149.69 1536.44 Q1145.33 1536.44 1143.14 1537.77 Q1140.97 1539.11 1140.97 1541.79 Q1140.97 1543.82 1142.53 1545 Q1144.09 1546.15 1148.8 1547.2 L1150.81 1547.64 Q1157.05 1548.98 1159.66 1551.43 Q1162.3 1553.85 1162.3 1558.21 Q1162.3 1563.17 1158.35 1566.07 Q1154.44 1568.97 1147.56 1568.97 Q1144.7 1568.97 1141.58 1568.39 Q1138.49 1567.85 1135.05 1566.74 L1135.05 1560.69 Q1138.3 1562.38 1141.45 1563.24 Q1144.6 1564.07 1147.69 1564.07 Q1151.83 1564.07 1154.05 1562.66 Q1156.28 1561.23 1156.28 1558.65 Q1156.28 1556.27 1154.66 1554.99 Q1153.07 1553.72 1147.62 1552.54 L1145.59 1552.07 Q1140.14 1550.92 1137.73 1548.56 Q1135.31 1546.18 1135.31 1542.04 Q1135.31 1537.01 1138.87 1534.27 Q1142.44 1531.54 1148.99 1531.54 Q1152.24 1531.54 1155.1 1532.01 Q1157.97 1532.49 1160.39 1533.45 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M1191.8 1518.52 L1205.3 1518.52 L1205.3 1523.07 L1197.66 1523.07 L1197.66 1572.09 L1205.3 1572.09 L1205.3 1576.64 L1191.8 1576.64 L1191.8 1518.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M1217.55 1518.52 L1223.44 1518.52 L1223.44 1547.77 L1240.91 1532.4 L1248.39 1532.4 L1229.49 1549.07 L1249.19 1568.04 L1241.55 1568.04 L1223.44 1550.63 L1223.44 1568.04 L1217.55 1568.04 L1217.55 1518.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M1255.78 1520.52 L1262.21 1520.52 L1262.21 1564.73 Q1262.21 1573.33 1258.93 1577.21 Q1255.68 1581.09 1248.46 1581.09 L1246.01 1581.09 L1246.01 1575.68 L1248.01 1575.68 Q1252.28 1575.68 1254.03 1573.3 Q1255.78 1570.91 1255.78 1564.73 L1255.78 1520.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M1285.16 1520.52 L1290.57 1520.52 L1274.02 1574.09 L1268.6 1574.09 L1285.16 1520.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M1296.49 1518.52 L1302.37 1518.52 L1302.37 1547.77 L1319.85 1532.4 L1327.33 1532.4 L1308.42 1549.07 L1328.12 1568.04 L1320.48 1568.04 L1302.37 1550.63 L1302.37 1568.04 L1296.49 1568.04 L1296.49 1518.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M1357.92 1549.81 Q1357.92 1543.44 1355.27 1539.94 Q1352.66 1536.44 1347.92 1536.44 Q1343.21 1536.44 1340.57 1539.94 Q1337.96 1543.44 1337.96 1549.81 Q1337.96 1556.14 1340.57 1559.64 Q1343.21 1563.14 1347.92 1563.14 Q1352.66 1563.14 1355.27 1559.64 Q1357.92 1556.14 1357.92 1549.81 M1363.77 1563.62 Q1363.77 1572.72 1359.73 1577.15 Q1355.69 1581.6 1347.35 1581.6 Q1344.26 1581.6 1341.52 1581.13 Q1338.79 1580.68 1336.21 1579.72 L1336.21 1574.03 Q1338.79 1575.43 1341.3 1576.1 Q1343.82 1576.76 1346.43 1576.76 Q1352.19 1576.76 1355.05 1573.74 Q1357.92 1570.75 1357.92 1564.67 L1357.92 1561.77 Q1356.1 1564.92 1353.27 1566.48 Q1350.44 1568.04 1346.49 1568.04 Q1339.93 1568.04 1335.92 1563.05 Q1331.91 1558.05 1331.91 1549.81 Q1331.91 1541.53 1335.92 1536.53 Q1339.93 1531.54 1346.49 1531.54 Q1350.44 1531.54 1353.27 1533.1 Q1356.1 1534.66 1357.92 1537.81 L1357.92 1532.4 L1363.77 1532.4 L1363.77 1563.62 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M1376.66 1559.96 L1383.38 1559.96 L1383.38 1568.04 L1376.66 1568.04 L1376.66 1559.96 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M1396.81 1520.52 L1403.24 1520.52 L1403.24 1540.61 L1424.56 1520.52 L1432.84 1520.52 L1409.25 1542.68 L1434.53 1568.04 L1426.06 1568.04 L1403.24 1545.16 L1403.24 1568.04 L1396.81 1568.04 L1396.81 1520.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M1452.99 1518.52 L1452.99 1576.64 L1439.49 1576.64 L1439.49 1572.09 L1447.1 1572.09 L1447.1 1523.07 L1439.49 1523.07 L1439.49 1518.52 L1452.99 1518.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><polyline clip-path="url(#clip710)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,1423.18 235.283,47.2441 "/>
<polyline clip-path="url(#clip710)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,1298.68 254.18,1298.68 "/>
<polyline clip-path="url(#clip710)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,1109.52 254.18,1109.52 "/>
<polyline clip-path="url(#clip710)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,920.365 254.18,920.365 "/>
<polyline clip-path="url(#clip710)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,731.209 254.18,731.209 "/>
<polyline clip-path="url(#clip710)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,542.053 254.18,542.053 "/>
<polyline clip-path="url(#clip710)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,352.896 254.18,352.896 "/>
<polyline clip-path="url(#clip710)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="235.283,163.74 254.18,163.74 "/>
<path clip-path="url(#clip710)" d="M131.181 1297.32 Q134.538 1298.04 136.413 1300.31 Q138.311 1302.58 138.311 1305.91 Q138.311 1311.03 134.792 1313.83 Q131.274 1316.63 124.793 1316.63 Q122.617 1316.63 120.302 1316.19 Q118.01 1315.77 115.556 1314.92 L115.556 1310.4 Q117.501 1311.54 119.816 1312.12 Q122.13 1312.69 124.654 1312.69 Q129.052 1312.69 131.343 1310.96 Q133.658 1309.22 133.658 1305.91 Q133.658 1302.86 131.505 1301.14 Q129.376 1299.41 125.556 1299.41 L121.529 1299.41 L121.529 1295.56 L125.742 1295.56 Q129.191 1295.56 131.019 1294.2 Q132.848 1292.81 132.848 1290.22 Q132.848 1287.56 130.95 1286.14 Q129.075 1284.71 125.556 1284.71 Q123.635 1284.71 121.436 1285.12 Q119.237 1285.54 116.598 1286.42 L116.598 1282.25 Q119.26 1281.51 121.575 1281.14 Q123.913 1280.77 125.973 1280.77 Q131.297 1280.77 134.399 1283.2 Q137.501 1285.61 137.501 1289.73 Q137.501 1292.6 135.857 1294.59 Q134.214 1296.56 131.181 1297.32 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M157.177 1284.48 Q153.566 1284.48 151.737 1288.04 Q149.931 1291.58 149.931 1298.71 Q149.931 1305.82 151.737 1309.38 Q153.566 1312.93 157.177 1312.93 Q160.811 1312.93 162.616 1309.38 Q164.445 1305.82 164.445 1298.71 Q164.445 1291.58 162.616 1288.04 Q160.811 1284.48 157.177 1284.48 M157.177 1280.77 Q162.987 1280.77 166.042 1285.38 Q169.121 1289.96 169.121 1298.71 Q169.121 1307.44 166.042 1312.05 Q162.987 1316.63 157.177 1316.63 Q151.366 1316.63 148.288 1312.05 Q145.232 1307.44 145.232 1298.71 Q145.232 1289.96 148.288 1285.38 Q151.366 1280.77 157.177 1280.77 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M187.338 1284.48 Q183.727 1284.48 181.899 1288.04 Q180.093 1291.58 180.093 1298.71 Q180.093 1305.82 181.899 1309.38 Q183.727 1312.93 187.338 1312.93 Q190.973 1312.93 192.778 1309.38 Q194.607 1305.82 194.607 1298.71 Q194.607 1291.58 192.778 1288.04 Q190.973 1284.48 187.338 1284.48 M187.338 1280.77 Q193.149 1280.77 196.204 1285.38 Q199.283 1289.96 199.283 1298.71 Q199.283 1307.44 196.204 1312.05 Q193.149 1316.63 187.338 1316.63 Q181.528 1316.63 178.45 1312.05 Q175.394 1307.44 175.394 1298.71 Q175.394 1289.96 178.45 1285.38 Q181.528 1280.77 187.338 1280.77 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M129.862 1096.32 L118.056 1114.76 L129.862 1114.76 L129.862 1096.32 M128.635 1092.24 L134.515 1092.24 L134.515 1114.76 L139.445 1114.76 L139.445 1118.65 L134.515 1118.65 L134.515 1126.8 L129.862 1126.8 L129.862 1118.65 L114.26 1118.65 L114.26 1114.14 L128.635 1092.24 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M157.177 1095.32 Q153.566 1095.32 151.737 1098.89 Q149.931 1102.43 149.931 1109.56 Q149.931 1116.66 151.737 1120.23 Q153.566 1123.77 157.177 1123.77 Q160.811 1123.77 162.616 1120.23 Q164.445 1116.66 164.445 1109.56 Q164.445 1102.43 162.616 1098.89 Q160.811 1095.32 157.177 1095.32 M157.177 1091.62 Q162.987 1091.62 166.042 1096.22 Q169.121 1100.81 169.121 1109.56 Q169.121 1118.28 166.042 1122.89 Q162.987 1127.47 157.177 1127.47 Q151.366 1127.47 148.288 1122.89 Q145.232 1118.28 145.232 1109.56 Q145.232 1100.81 148.288 1096.22 Q151.366 1091.62 157.177 1091.62 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M187.338 1095.32 Q183.727 1095.32 181.899 1098.89 Q180.093 1102.43 180.093 1109.56 Q180.093 1116.66 181.899 1120.23 Q183.727 1123.77 187.338 1123.77 Q190.973 1123.77 192.778 1120.23 Q194.607 1116.66 194.607 1109.56 Q194.607 1102.43 192.778 1098.89 Q190.973 1095.32 187.338 1095.32 M187.338 1091.62 Q193.149 1091.62 196.204 1096.22 Q199.283 1100.81 199.283 1109.56 Q199.283 1118.28 196.204 1122.89 Q193.149 1127.47 187.338 1127.47 Q181.528 1127.47 178.45 1122.89 Q175.394 1118.28 175.394 1109.56 Q175.394 1100.81 178.45 1096.22 Q181.528 1091.62 187.338 1091.62 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M117.061 903.085 L135.417 903.085 L135.417 907.021 L121.343 907.021 L121.343 915.493 Q122.362 915.145 123.38 914.983 Q124.399 914.798 125.418 914.798 Q131.205 914.798 134.584 917.97 Q137.964 921.141 137.964 926.557 Q137.964 932.136 134.492 935.238 Q131.019 938.317 124.7 938.317 Q122.524 938.317 120.255 937.946 Q118.01 937.576 115.603 936.835 L115.603 932.136 Q117.686 933.27 119.908 933.826 Q122.13 934.381 124.607 934.381 Q128.612 934.381 130.95 932.275 Q133.288 930.169 133.288 926.557 Q133.288 922.946 130.95 920.84 Q128.612 918.733 124.607 918.733 Q122.732 918.733 120.857 919.15 Q119.006 919.567 117.061 920.446 L117.061 903.085 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M157.177 906.164 Q153.566 906.164 151.737 909.729 Q149.931 913.27 149.931 920.4 Q149.931 927.507 151.737 931.071 Q153.566 934.613 157.177 934.613 Q160.811 934.613 162.616 931.071 Q164.445 927.507 164.445 920.4 Q164.445 913.27 162.616 909.729 Q160.811 906.164 157.177 906.164 M157.177 902.46 Q162.987 902.46 166.042 907.067 Q169.121 911.65 169.121 920.4 Q169.121 929.127 166.042 933.733 Q162.987 938.317 157.177 938.317 Q151.366 938.317 148.288 933.733 Q145.232 929.127 145.232 920.4 Q145.232 911.65 148.288 907.067 Q151.366 902.46 157.177 902.46 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M187.338 906.164 Q183.727 906.164 181.899 909.729 Q180.093 913.27 180.093 920.4 Q180.093 927.507 181.899 931.071 Q183.727 934.613 187.338 934.613 Q190.973 934.613 192.778 931.071 Q194.607 927.507 194.607 920.4 Q194.607 913.27 192.778 909.729 Q190.973 906.164 187.338 906.164 M187.338 902.46 Q193.149 902.46 196.204 907.067 Q199.283 911.65 199.283 920.4 Q199.283 929.127 196.204 933.733 Q193.149 938.317 187.338 938.317 Q181.528 938.317 178.45 933.733 Q175.394 929.127 175.394 920.4 Q175.394 911.65 178.45 907.067 Q181.528 902.46 187.338 902.46 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M127.593 729.346 Q124.445 729.346 122.593 731.498 Q120.765 733.651 120.765 737.401 Q120.765 741.128 122.593 743.304 Q124.445 745.457 127.593 745.457 Q130.742 745.457 132.57 743.304 Q134.422 741.128 134.422 737.401 Q134.422 733.651 132.57 731.498 Q130.742 729.346 127.593 729.346 M136.876 714.693 L136.876 718.952 Q135.117 718.119 133.311 717.679 Q131.529 717.239 129.769 717.239 Q125.14 717.239 122.686 720.364 Q120.255 723.489 119.908 729.809 Q121.274 727.795 123.334 726.73 Q125.394 725.642 127.871 725.642 Q133.08 725.642 136.089 728.813 Q139.121 731.961 139.121 737.401 Q139.121 742.725 135.973 745.943 Q132.825 749.16 127.593 749.16 Q121.598 749.16 118.427 744.577 Q115.256 739.97 115.256 731.244 Q115.256 723.049 119.144 718.188 Q123.033 713.304 129.584 713.304 Q131.343 713.304 133.126 713.651 Q134.931 713.998 136.876 714.693 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M157.177 717.008 Q153.566 717.008 151.737 720.572 Q149.931 724.114 149.931 731.244 Q149.931 738.35 151.737 741.915 Q153.566 745.457 157.177 745.457 Q160.811 745.457 162.616 741.915 Q164.445 738.35 164.445 731.244 Q164.445 724.114 162.616 720.572 Q160.811 717.008 157.177 717.008 M157.177 713.304 Q162.987 713.304 166.042 717.91 Q169.121 722.494 169.121 731.244 Q169.121 739.97 166.042 744.577 Q162.987 749.16 157.177 749.16 Q151.366 749.16 148.288 744.577 Q145.232 739.97 145.232 731.244 Q145.232 722.494 148.288 717.91 Q151.366 713.304 157.177 713.304 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M187.338 717.008 Q183.727 717.008 181.899 720.572 Q180.093 724.114 180.093 731.244 Q180.093 738.35 181.899 741.915 Q183.727 745.457 187.338 745.457 Q190.973 745.457 192.778 741.915 Q194.607 738.35 194.607 731.244 Q194.607 724.114 192.778 720.572 Q190.973 717.008 187.338 717.008 M187.338 713.304 Q193.149 713.304 196.204 717.91 Q199.283 722.494 199.283 731.244 Q199.283 739.97 196.204 744.577 Q193.149 749.16 187.338 749.16 Q181.528 749.16 178.45 744.577 Q175.394 739.97 175.394 731.244 Q175.394 722.494 178.45 717.91 Q181.528 713.304 187.338 713.304 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M115.834 524.773 L138.056 524.773 L138.056 526.763 L125.51 559.333 L120.626 559.333 L132.431 528.708 L115.834 528.708 L115.834 524.773 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M157.177 527.851 Q153.566 527.851 151.737 531.416 Q149.931 534.958 149.931 542.087 Q149.931 549.194 151.737 552.759 Q153.566 556.3 157.177 556.3 Q160.811 556.3 162.616 552.759 Q164.445 549.194 164.445 542.087 Q164.445 534.958 162.616 531.416 Q160.811 527.851 157.177 527.851 M157.177 524.148 Q162.987 524.148 166.042 528.754 Q169.121 533.337 169.121 542.087 Q169.121 550.814 166.042 555.421 Q162.987 560.004 157.177 560.004 Q151.366 560.004 148.288 555.421 Q145.232 550.814 145.232 542.087 Q145.232 533.337 148.288 528.754 Q151.366 524.148 157.177 524.148 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M187.338 527.851 Q183.727 527.851 181.899 531.416 Q180.093 534.958 180.093 542.087 Q180.093 549.194 181.899 552.759 Q183.727 556.3 187.338 556.3 Q190.973 556.3 192.778 552.759 Q194.607 549.194 194.607 542.087 Q194.607 534.958 192.778 531.416 Q190.973 527.851 187.338 527.851 M187.338 524.148 Q193.149 524.148 196.204 528.754 Q199.283 533.337 199.283 542.087 Q199.283 550.814 196.204 555.421 Q193.149 560.004 187.338 560.004 Q181.528 560.004 178.45 555.421 Q175.394 550.814 175.394 542.087 Q175.394 533.337 178.45 528.754 Q181.528 524.148 187.338 524.148 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M127.015 353.764 Q123.681 353.764 121.76 355.547 Q119.862 357.329 119.862 360.454 Q119.862 363.579 121.76 365.361 Q123.681 367.144 127.015 367.144 Q130.348 367.144 132.269 365.361 Q134.191 363.556 134.191 360.454 Q134.191 357.329 132.269 355.547 Q130.371 353.764 127.015 353.764 M122.339 351.774 Q119.33 351.033 117.64 348.973 Q115.973 346.912 115.973 343.949 Q115.973 339.806 118.913 337.399 Q121.876 334.991 127.015 334.991 Q132.177 334.991 135.117 337.399 Q138.056 339.806 138.056 343.949 Q138.056 346.912 136.367 348.973 Q134.7 351.033 131.714 351.774 Q135.093 352.561 136.968 354.852 Q138.867 357.144 138.867 360.454 Q138.867 365.477 135.788 368.162 Q132.732 370.847 127.015 370.847 Q121.297 370.847 118.218 368.162 Q115.163 365.477 115.163 360.454 Q115.163 357.144 117.061 354.852 Q118.959 352.561 122.339 351.774 M120.626 344.389 Q120.626 347.074 122.293 348.579 Q123.982 350.084 127.015 350.084 Q130.024 350.084 131.714 348.579 Q133.427 347.074 133.427 344.389 Q133.427 341.704 131.714 340.199 Q130.024 338.695 127.015 338.695 Q123.982 338.695 122.293 340.199 Q120.626 341.704 120.626 344.389 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M157.177 338.695 Q153.566 338.695 151.737 342.26 Q149.931 345.801 149.931 352.931 Q149.931 360.037 151.737 363.602 Q153.566 367.144 157.177 367.144 Q160.811 367.144 162.616 363.602 Q164.445 360.037 164.445 352.931 Q164.445 345.801 162.616 342.26 Q160.811 338.695 157.177 338.695 M157.177 334.991 Q162.987 334.991 166.042 339.598 Q169.121 344.181 169.121 352.931 Q169.121 361.658 166.042 366.264 Q162.987 370.847 157.177 370.847 Q151.366 370.847 148.288 366.264 Q145.232 361.658 145.232 352.931 Q145.232 344.181 148.288 339.598 Q151.366 334.991 157.177 334.991 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M187.338 338.695 Q183.727 338.695 181.899 342.26 Q180.093 345.801 180.093 352.931 Q180.093 360.037 181.899 363.602 Q183.727 367.144 187.338 367.144 Q190.973 367.144 192.778 363.602 Q194.607 360.037 194.607 352.931 Q194.607 345.801 192.778 342.26 Q190.973 338.695 187.338 338.695 M187.338 334.991 Q193.149 334.991 196.204 339.598 Q199.283 344.181 199.283 352.931 Q199.283 361.658 196.204 366.264 Q193.149 370.847 187.338 370.847 Q181.528 370.847 178.45 366.264 Q175.394 361.658 175.394 352.931 Q175.394 344.181 178.45 339.598 Q181.528 334.991 187.338 334.991 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M117.154 180.302 L117.154 176.043 Q118.913 176.876 120.718 177.316 Q122.524 177.756 124.26 177.756 Q128.89 177.756 131.32 174.654 Q133.774 171.529 134.121 165.187 Q132.779 167.177 130.718 168.242 Q128.658 169.307 126.158 169.307 Q120.973 169.307 117.941 166.182 Q114.931 163.034 114.931 157.594 Q114.931 152.27 118.08 149.052 Q121.228 145.835 126.459 145.835 Q132.455 145.835 135.603 150.441 Q138.774 155.025 138.774 163.775 Q138.774 171.946 134.885 176.83 Q131.019 181.691 124.468 181.691 Q122.709 181.691 120.904 181.344 Q119.098 180.997 117.154 180.302 M126.459 165.65 Q129.607 165.65 131.436 163.497 Q133.288 161.344 133.288 157.594 Q133.288 153.867 131.436 151.714 Q129.607 149.538 126.459 149.538 Q123.311 149.538 121.459 151.714 Q119.63 153.867 119.63 157.594 Q119.63 161.344 121.459 163.497 Q123.311 165.65 126.459 165.65 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M157.177 149.538 Q153.566 149.538 151.737 153.103 Q149.931 156.645 149.931 163.775 Q149.931 170.881 151.737 174.446 Q153.566 177.987 157.177 177.987 Q160.811 177.987 162.616 174.446 Q164.445 170.881 164.445 163.775 Q164.445 156.645 162.616 153.103 Q160.811 149.538 157.177 149.538 M157.177 145.835 Q162.987 145.835 166.042 150.441 Q169.121 155.025 169.121 163.775 Q169.121 172.501 166.042 177.108 Q162.987 181.691 157.177 181.691 Q151.366 181.691 148.288 177.108 Q145.232 172.501 145.232 163.775 Q145.232 155.025 148.288 150.441 Q151.366 145.835 157.177 145.835 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M187.338 149.538 Q183.727 149.538 181.899 153.103 Q180.093 156.645 180.093 163.775 Q180.093 170.881 181.899 174.446 Q183.727 177.987 187.338 177.987 Q190.973 177.987 192.778 174.446 Q194.607 170.881 194.607 163.775 Q194.607 156.645 192.778 153.103 Q190.973 149.538 187.338 149.538 M187.338 145.835 Q193.149 145.835 196.204 150.441 Q199.283 155.025 199.283 163.775 Q199.283 172.501 196.204 177.108 Q193.149 181.691 187.338 181.691 Q181.528 181.691 178.45 177.108 Q175.394 172.501 175.394 163.775 Q175.394 155.025 178.45 150.441 Q181.528 145.835 187.338 145.835 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M16.4842 809.579 L16.4842 769.38 L21.895 769.38 L21.895 786.249 L64.0042 786.249 L64.0042 792.71 L21.895 792.71 L21.895 809.579 L16.4842 809.579 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M14.479 743.249 L14.479 729.753 L19.0304 729.753 L19.0304 737.392 L68.0464 737.392 L68.0464 729.753 L72.5979 729.753 L72.5979 743.249 L14.479 743.249 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M16.4842 717.022 L16.4842 710.593 L36.568 710.593 L16.4842 689.267 L16.4842 680.992 L38.6368 704.577 L64.0042 679.305 L64.0042 687.772 L41.1194 710.593 L64.0042 710.593 L64.0042 717.022 L16.4842 717.022 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M14.479 660.845 L72.5979 660.845 L72.5979 674.34 L68.0464 674.34 L68.0464 666.733 L19.0304 666.733 L19.0304 674.34 L14.479 674.34 L14.479 660.845 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><polyline clip-path="url(#clip712)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:0.5; fill:none" stroke-dasharray="16, 10" points="586.203,1311.92 586.203,903.97 "/>
<polyline clip-path="url(#clip712)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="586.203,1311.92 682.887,859.604 "/>
<polyline clip-path="url(#clip712)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="682.887,859.604 721.495,841.379 759.494,823.154 796.905,804.928 833.75,786.703 870.05,768.477 905.823,750.252 941.088,732.026 975.862,713.801 1010.16,695.575 1044,677.35 1077.39,659.125 1110.36,640.899 1142.9,622.674 1175.04,604.448 1206.78,586.223 1238.14,567.997 1269.14,549.772 1299.76,531.547 1330.04,513.321 1359.98,495.096 1389.58,476.87 1418.86,458.645 1447.82,440.419 1476.47,422.194 1504.82,403.968 "/>
<polyline clip-path="url(#clip712)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:0.5; fill:none" stroke-dasharray="16, 10" points="1504.82,403.968 1504.82,1006.61 "/>
<polyline clip-path="url(#clip712)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1504.82,403.968 1652.72,944.51 "/>
<polyline clip-path="url(#clip712)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1652.72,944.51 1609.95,962.88 1566.37,981.25 1521.95,999.621 1476.65,1017.99 1430.42,1036.36 1383.23,1054.73 1335.03,1073.1 1285.75,1091.47 1235.36,1109.84 1183.79,1128.21 1130.97,1146.58 1076.84,1164.96 1021.32,1183.33 964.339,1201.7 905.803,1220.07 845.619,1238.44 783.685,1256.81 719.888,1275.18 654.105,1293.55 586.203,1311.92 "/>
<polyline clip-path="url(#clip712)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:0.4; fill:none" points="295.211,1384.24 373.495,1365.76 448.947,1347.29 521.769,1328.81 592.146,1310.33 660.243,1291.86 726.207,1273.38 790.177,1254.91 852.274,1236.43 912.613,1217.96 971.296,1199.48 1028.42,1181 1084.07,1162.53 1138.33,1144.05 1191.27,1125.58 1242.96,1107.1 1293.47,1088.62 1342.85,1070.15 1391.16,1051.67 1438.46,1033.2 1484.78,1014.72 1530.18,996.245 1574.69,977.769 1618.36,959.293 1661.22,940.817 1703.31,922.341 1744.65,903.865 1785.29,885.389 1825.24,866.913 1864.54,848.437 1903.2,829.962 1941.26,811.486 1978.73,793.01 2015.64,774.534 2052.01,756.058 2087.85,737.582 2123.19,719.106 2158.03,700.63 2192.41,682.154 2226.32,663.679 2259.79,645.203 2292.83,626.727 "/>
<polyline clip-path="url(#clip712)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:0.4; fill:none" points="523.894,931.612 566.423,912.825 608.194,894.038 649.238,875.251 689.586,856.463 729.264,837.676 768.3,818.889 806.717,800.101 844.538,781.314 881.786,762.527 918.481,743.74 954.642,724.952 990.288,706.165 1025.44,687.378 1060.1,668.591 1094.3,649.803 1128.05,631.016 1161.37,612.229 1194.26,593.442 1226.73,574.654 1258.81,555.867 1290.5,537.08 1321.82,518.293 1352.77,499.505 1383.36,480.718 1413.6,461.931 1443.51,443.144 1473.09,424.356 1502.35,405.569 1531.29,386.782 1559.93,367.995 1588.27,349.207 1616.32,330.42 1644.08,311.633 1671.57,292.846 1698.79,274.058 1725.74,255.271 1752.43,236.484 1778.86,217.696 1805.05,198.909 1830.99,180.122 1856.69,161.335 1882.16,142.547 1907.4,123.76 1932.41,104.973 1957.2,86.1857 "/>
<path clip-path="url(#clip710)" d="M517.265 1348.33 L517.265 1287.92 L563.995 1287.92 L563.995 1348.33 L517.265 1348.33 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M562.838 1348.33 L562.838 1287.92 L609.568 1287.92 L609.568 1348.33 L562.838 1348.33 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M608.411 1348.33 L608.411 1287.92 L655.141 1287.92 L655.141 1348.33 L608.411 1348.33 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M561.654 1304.04 L561.654 1308.06 Q559.849 1307.14 557.904 1306.68 Q555.96 1306.21 553.877 1306.21 Q550.705 1306.21 549.108 1307.19 Q547.534 1308.16 547.534 1310.1 Q547.534 1311.58 548.668 1312.44 Q549.803 1313.27 553.229 1314.04 L554.687 1314.36 Q559.224 1315.33 561.122 1317.12 Q563.043 1318.88 563.043 1322.05 Q563.043 1325.66 560.173 1327.76 Q557.326 1329.87 552.326 1329.87 Q550.242 1329.87 547.974 1329.45 Q545.729 1329.06 543.229 1328.25 L543.229 1323.85 Q545.59 1325.08 547.881 1325.7 Q550.173 1326.31 552.418 1326.31 Q555.428 1326.31 557.048 1325.29 Q558.668 1324.25 558.668 1322.37 Q558.668 1320.63 557.488 1319.71 Q556.33 1318.78 552.372 1317.93 L550.891 1317.58 Q546.932 1316.75 545.173 1315.03 Q543.414 1313.3 543.414 1310.29 Q543.414 1306.63 546.006 1304.64 Q548.599 1302.65 553.367 1302.65 Q555.728 1302.65 557.812 1303 Q559.895 1303.34 561.654 1304.04 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M574.039 1295.91 L574.039 1303.27 L582.812 1303.27 L582.812 1306.58 L574.039 1306.58 L574.039 1320.66 Q574.039 1323.83 574.895 1324.73 Q575.775 1325.63 578.437 1325.63 L582.812 1325.63 L582.812 1329.2 L578.437 1329.2 Q573.506 1329.2 571.631 1327.37 Q569.756 1325.52 569.756 1320.66 L569.756 1306.58 L566.631 1306.58 L566.631 1303.27 L569.756 1303.27 L569.756 1295.91 L574.039 1295.91 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M589.826 1325.26 L597.464 1325.26 L597.464 1298.9 L589.154 1300.56 L589.154 1296.31 L597.418 1294.64 L602.094 1294.64 L602.094 1325.26 L609.733 1325.26 L609.733 1329.2 L589.826 1329.2 L589.826 1325.26 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M636.736 896.019 L636.736 835.603 L683.466 835.603 L683.466 896.019 L636.736 896.019 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M682.308 896.019 L682.308 835.603 L729.038 835.603 L729.038 896.019 L682.308 896.019 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M668.246 851.723 L668.246 855.75 Q666.44 854.824 664.496 854.361 Q662.552 853.898 660.468 853.898 Q657.297 853.898 655.7 854.871 Q654.126 855.843 654.126 857.787 Q654.126 859.269 655.26 860.125 Q656.394 860.959 659.82 861.723 L661.278 862.047 Q665.815 863.019 667.714 864.801 Q669.635 866.56 669.635 869.732 Q669.635 873.343 666.765 875.449 Q663.917 877.556 658.917 877.556 Q656.834 877.556 654.566 877.139 Q652.32 876.746 649.82 875.935 L649.82 871.537 Q652.181 872.764 654.473 873.389 Q656.765 873.991 659.01 873.991 Q662.019 873.991 663.64 872.972 Q665.26 871.931 665.26 870.056 Q665.26 868.32 664.079 867.394 Q662.922 866.468 658.964 865.611 L657.482 865.264 Q653.524 864.431 651.765 862.718 Q650.005 860.982 650.005 857.973 Q650.005 854.315 652.598 852.324 Q655.191 850.334 659.959 850.334 Q662.32 850.334 664.403 850.681 Q666.487 851.028 668.246 851.723 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M680.63 843.598 L680.63 850.959 L689.403 850.959 L689.403 854.269 L680.63 854.269 L680.63 868.343 Q680.63 871.514 681.487 872.417 Q682.366 873.32 685.028 873.32 L689.403 873.32 L689.403 876.884 L685.028 876.884 Q680.098 876.884 678.223 875.056 Q676.348 873.204 676.348 868.343 L676.348 854.269 L673.223 854.269 L673.223 850.959 L676.348 850.959 L676.348 843.598 L680.63 843.598 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M699.635 872.949 L715.954 872.949 L715.954 876.884 L694.01 876.884 L694.01 872.949 Q696.672 870.195 701.255 865.565 Q705.862 860.912 707.042 859.57 Q709.287 857.047 710.167 855.311 Q711.07 853.551 711.07 851.861 Q711.07 849.107 709.125 847.371 Q707.204 845.635 704.102 845.635 Q701.903 845.635 699.45 846.399 Q697.019 847.162 694.241 848.713 L694.241 843.991 Q697.065 842.857 699.519 842.278 Q701.973 841.699 704.01 841.699 Q709.38 841.699 712.574 844.385 Q715.769 847.07 715.769 851.561 Q715.769 853.69 714.959 855.611 Q714.172 857.51 712.065 860.102 Q711.487 860.773 708.385 863.991 Q705.283 867.185 699.635 872.949 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M1458.67 440.383 L1458.67 379.967 L1505.4 379.967 L1505.4 440.383 L1458.67 440.383 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M1504.25 440.383 L1504.25 379.967 L1550.98 379.967 L1550.98 440.383 L1504.25 440.383 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M1489.71 396.087 L1489.71 400.114 Q1487.9 399.188 1485.96 398.725 Q1484.01 398.262 1481.93 398.262 Q1478.76 398.262 1477.16 399.235 Q1475.59 400.207 1475.59 402.151 Q1475.59 403.633 1476.72 404.489 Q1477.86 405.323 1481.28 406.086 L1482.74 406.411 Q1487.28 407.383 1489.18 409.165 Q1491.1 410.924 1491.1 414.096 Q1491.1 417.707 1488.23 419.813 Q1485.38 421.92 1480.38 421.92 Q1478.3 421.92 1476.03 421.503 Q1473.78 421.11 1471.28 420.299 L1471.28 415.901 Q1473.64 417.128 1475.94 417.753 Q1478.23 418.355 1480.47 418.355 Q1483.48 418.355 1485.1 417.336 Q1486.72 416.295 1486.72 414.42 Q1486.72 412.684 1485.54 411.758 Q1484.38 410.832 1480.43 409.975 L1478.94 409.628 Q1474.99 408.795 1473.23 407.082 Q1471.47 405.346 1471.47 402.336 Q1471.47 398.679 1474.06 396.688 Q1476.65 394.698 1481.42 394.698 Q1483.78 394.698 1485.87 395.045 Q1487.95 395.392 1489.71 396.087 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M1502.09 387.962 L1502.09 395.323 L1510.87 395.323 L1510.87 398.633 L1502.09 398.633 L1502.09 412.707 Q1502.09 415.878 1502.95 416.781 Q1503.83 417.684 1506.49 417.684 L1510.87 417.684 L1510.87 421.248 L1506.49 421.248 Q1501.56 421.248 1499.69 419.42 Q1497.81 417.568 1497.81 412.707 L1497.81 398.633 L1494.69 398.633 L1494.69 395.323 L1497.81 395.323 L1497.81 387.962 L1502.09 387.962 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M1531.24 402.614 Q1534.59 403.332 1536.47 405.6 Q1538.37 407.869 1538.37 411.202 Q1538.37 416.318 1534.85 419.119 Q1531.33 421.92 1524.85 421.92 Q1522.67 421.92 1520.36 421.48 Q1518.06 421.063 1515.61 420.207 L1515.61 415.693 Q1517.56 416.827 1519.87 417.406 Q1522.18 417.985 1524.71 417.985 Q1529.11 417.985 1531.4 416.248 Q1533.71 414.512 1533.71 411.202 Q1533.71 408.147 1531.56 406.434 Q1529.43 404.698 1525.61 404.698 L1521.58 404.698 L1521.58 400.855 L1525.8 400.855 Q1529.25 400.855 1531.07 399.489 Q1532.9 398.1 1532.9 395.508 Q1532.9 392.846 1531 391.434 Q1529.13 389.999 1525.61 389.999 Q1523.69 389.999 1521.49 390.415 Q1519.29 390.832 1516.65 391.712 L1516.65 387.545 Q1519.31 386.804 1521.63 386.434 Q1523.97 386.063 1526.03 386.063 Q1531.35 386.063 1534.45 388.494 Q1537.56 390.901 1537.56 395.022 Q1537.56 397.892 1535.91 399.883 Q1534.27 401.85 1531.24 402.614 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M1606.57 980.924 L1606.57 920.508 L1653.3 920.508 L1653.3 980.924 L1606.57 980.924 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M1652.14 980.924 L1652.14 920.508 L1698.87 920.508 L1698.87 980.924 L1652.14 980.924 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M1637.04 936.628 L1637.04 940.655 Q1635.23 939.729 1633.29 939.266 Q1631.34 938.804 1629.26 938.804 Q1626.09 938.804 1624.49 939.776 Q1622.92 940.748 1622.92 942.692 Q1622.92 944.174 1624.05 945.03 Q1625.18 945.864 1628.61 946.628 L1630.07 946.952 Q1634.61 947.924 1636.5 949.706 Q1638.42 951.465 1638.42 954.637 Q1638.42 958.248 1635.55 960.354 Q1632.71 962.461 1627.71 962.461 Q1625.62 962.461 1623.36 962.044 Q1621.11 961.651 1618.61 960.84 L1618.61 956.442 Q1620.97 957.669 1623.26 958.294 Q1625.55 958.896 1627.8 958.896 Q1630.81 958.896 1632.43 957.877 Q1634.05 956.836 1634.05 954.961 Q1634.05 953.225 1632.87 952.299 Q1631.71 951.373 1627.75 950.516 L1626.27 950.169 Q1622.31 949.336 1620.55 947.623 Q1618.8 945.887 1618.8 942.878 Q1618.8 939.22 1621.39 937.229 Q1623.98 935.239 1628.75 935.239 Q1631.11 935.239 1633.19 935.586 Q1635.28 935.933 1637.04 936.628 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M1649.42 928.503 L1649.42 935.864 L1658.19 935.864 L1658.19 939.174 L1649.42 939.174 L1649.42 953.248 Q1649.42 956.419 1650.28 957.322 Q1651.16 958.225 1653.82 958.225 L1658.19 958.225 L1658.19 961.79 L1653.82 961.79 Q1648.89 961.79 1647.01 959.961 Q1645.14 958.109 1645.14 953.248 L1645.14 939.174 L1642.01 939.174 L1642.01 935.864 L1645.14 935.864 L1645.14 928.503 L1649.42 928.503 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip710)" d="M1677.24 931.304 L1665.44 949.753 L1677.24 949.753 L1677.24 931.304 M1676.02 927.23 L1681.9 927.23 L1681.9 949.753 L1686.83 949.753 L1686.83 953.641 L1681.9 953.641 L1681.9 961.79 L1677.24 961.79 L1677.24 953.641 L1661.64 953.641 L1661.64 949.128 L1676.02 927.23 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /></svg>
</div><div style=' border: 1px solid;'><h3 style='text-align: center;margin: 8px;'>Cycle Properties:</h3><div style='display: flex; justify-content: space-around;'><div style = "display: inline-block; border: 1px solid #666666;"><!DOCTYPE html>
<html>
<meta charset="UTF-8">
<style>
  table, td, th {
      border-collapse: collapse; color: black;
      font-family: sans-serif;
  }

  td, th {
      border-bottom: 0;
      padding: 4px
  }

  tr:nth-child(odd) {
      background: #eee;
  }

  tr:nth-child(even) {
      background: #fff;
  }

  tr.header {
      background: #fff !important;
      font-weight: bold;
  }

  tr.subheader {
      background: #fff !important;
      color: dimgray;
  }

  tr.headerLastRow {
      border-bottom: 2px solid black;
  }

  th.rowNumber, td.rowNumber {
      text-align: right;
  }

</style>
<body>
<table>
  <thead>
    <tr class = "header headerLastRow">
      <th style = "color: black; text-align: center; padding: 11px; font-size: 130%;"></th>
      <th style = "color: black; text-align: center; padding: 11px; font-size: 130%;">Total</th>
      <th style = "color: black; text-align: center; padding: 11px; font-size: 130%;">Component</th>
      <th style = "color: black; text-align: center; padding: 11px; font-size: 130%;">Value</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">qin<BR>Q̇in</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">256.6365 kJ/kg<BR>0.0 kW</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">combustion_chamber:<BR>   st2 &gt;&gt; st3</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">256.6365 kJ/kg<BR></td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">qout<BR>Q̇out</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">197.0086 kJ/kg<BR>0.0 kW</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">combustion_chamber:<BR>   st4 &gt;&gt; st1</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">197.0086 kJ/kg<BR></td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">win<BR>Ẇin</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">243.1014 kJ/kg<BR>0.0 kW</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">compressor:<BR>   st1 &gt;&gt; st2</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">243.1014 kJ/kg<BR></td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">wout<BR>Ẇout</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">302.7293 kJ/kg<BR>0.0 kW</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">turbine:<BR>   st3 &gt;&gt; st4</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">302.7293 kJ/kg<BR></td>
    </tr>
  </tbody>
</table>
</body>
</html>
</div></div><h3 style='text-align: center; border: 2px solid #666666; padding: 15px; margin: 10px;'>Thermal efficiency (n) = 23.2344 %</h3></div>
</div></br></div>

```
