# Refrigeration cycle

!!! note "Cycle data"
    > ![](./assets/ex5.png) 

    !!! ukw "Known properties"
        - Refrigerant-134a is used as working fluid;
        - Pressure at the compressor inlet 300 kPa;
        - Pressure at the compressor outlet 1500 kPa;
        - The compressor has an isentropic efficiency of 90%.


!!! compat "Input code"
    ```julia
    using CycleSolver
    
    @solve begin
        st1.p = 300
        st2.p = 1500
        newRefrigerationCycle[R134a]
            compressor(st1, st2, 90)
            condenser(st2, st3)
            expansion_valve(st3, st4)
            evaporator(st4, st1)
    end

    PrintResults()
    ```
#### Output:

```@raw html
<div style='display: inline-block; margin: 1px; text-align: center;
    border: 0.5px solid #666666;'><div style='display: inline-block; padding: 15px; margin: 20px;
        border: 2px solid #666666;'>
<h1 style='display: block; text-align: center; border: 1px solid #666666;margin: -17px; margin-bottom: 20px; padding: 10px'>1- REFRIGERATION  CYCLE [R134a]</h1><div style='display: flex; justify-content: space-around;'><div style = "display: inline-block; border: 1px solid #666666;"><!DOCTYPE html>
<html>
<meta charset="UTF-8">
<style>
  table, td, th {
      border-collapse: collapse; color: black;
      font-family: sans-serif;
  }

  td, th {
      border-bottom: 0;
      padding: 4px
  }

  tr:nth-child(odd) {
      background: #eee;
  }

  tr:nth-child(even) {
      background: #fff;
  }

  tr.header {
      background: #fff !important;
      font-weight: bold;
  }

  tr.subheader {
      background: #fff !important;
      color: dimgray;
  }

  tr.headerLastRow {
      border-bottom: 2px solid black;
  }

  th.rowNumber, td.rowNumber {
      text-align: right;
  }

</style>
<body>
<table>
  <thead>
    <tr class = "header headerLastRow">
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">State<br>Name</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">T [K]</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">P [kPa]</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">h [kJ/kg]</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">s [kJ/kg.K]</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">x</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">ṁ [kg/s]</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">Mass-flux<br>fraction</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">st1</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">273.822</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">300.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">250.851</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">0.9311</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;"></td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1.0</td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">st2</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">337.097</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1500.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">288.025</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">0.9422</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;"></td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;"></td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1.0</td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">st3</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">328.383</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1500.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">131.695</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">0.4665</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">0.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;"></td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1.0</td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">st4</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">273.822</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">300.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">131.695</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">0.4959</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">0.3985</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;"></td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1.0</td>
    </tr>
  </tbody>
</table>
</body>
</html>
</div></div><div style='display: flex; justify-content: space-around;
        padding: 10px; margin: 10px;'><?xml version="1.0" encoding="utf-8"?>
<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="600" height="400" viewBox="0 0 2400 1600">
<defs>
  <clipPath id="clip750">
    <rect x="0" y="0" width="2400" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip750)" d="M0 1600 L2400 1600 L2400 0 L0 0  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip751">
    <rect x="480" y="0" width="1681" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip750)" d="M234.125 1423.18 L2352.76 1423.18 L2352.76 47.2441 L234.125 47.2441  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip752">
    <rect x="234" y="47" width="2120" height="1377"/>
  </clipPath>
</defs>
<polyline clip-path="url(#clip750)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="234.125,1423.18 2352.76,1423.18 "/>
<polyline clip-path="url(#clip750)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="548.818,1423.18 548.818,1404.28 "/>
<polyline clip-path="url(#clip750)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="976.424,1423.18 976.424,1404.28 "/>
<polyline clip-path="url(#clip750)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1404.03,1423.18 1404.03,1404.28 "/>
<polyline clip-path="url(#clip750)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1831.64,1423.18 1831.64,1404.28 "/>
<polyline clip-path="url(#clip750)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2259.24,1423.18 2259.24,1404.28 "/>
<path clip-path="url(#clip750)" d="M527.001 1454.1 Q523.39 1454.1 521.561 1457.66 Q519.756 1461.2 519.756 1468.33 Q519.756 1475.44 521.561 1479.01 Q523.39 1482.55 527.001 1482.55 Q530.635 1482.55 532.441 1479.01 Q534.269 1475.44 534.269 1468.33 Q534.269 1461.2 532.441 1457.66 Q530.635 1454.1 527.001 1454.1 M527.001 1450.39 Q532.811 1450.39 535.867 1455 Q538.945 1459.58 538.945 1468.33 Q538.945 1477.06 535.867 1481.67 Q532.811 1486.25 527.001 1486.25 Q521.191 1486.25 518.112 1481.67 Q515.057 1477.06 515.057 1468.33 Q515.057 1459.58 518.112 1455 Q521.191 1450.39 527.001 1450.39 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M547.163 1479.7 L552.047 1479.7 L552.047 1485.58 L547.163 1485.58 L547.163 1479.7 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M566.26 1481.64 L582.579 1481.64 L582.579 1485.58 L560.635 1485.58 L560.635 1481.64 Q563.297 1478.89 567.88 1474.26 Q572.487 1469.61 573.667 1468.27 Q575.913 1465.74 576.792 1464.01 Q577.695 1462.25 577.695 1460.56 Q577.695 1457.8 575.751 1456.07 Q573.829 1454.33 570.728 1454.33 Q568.529 1454.33 566.075 1455.09 Q563.644 1455.86 560.867 1457.41 L560.867 1452.69 Q563.691 1451.55 566.144 1450.97 Q568.598 1450.39 570.635 1450.39 Q576.005 1450.39 579.2 1453.08 Q582.394 1455.77 582.394 1460.26 Q582.394 1462.39 581.584 1464.31 Q580.797 1466.2 578.691 1468.8 Q578.112 1469.47 575.01 1472.69 Q571.908 1475.88 566.26 1481.64 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M953.565 1454.1 Q949.954 1454.1 948.126 1457.66 Q946.32 1461.2 946.32 1468.33 Q946.32 1475.44 948.126 1479.01 Q949.954 1482.55 953.565 1482.55 Q957.2 1482.55 959.005 1479.01 Q960.834 1475.44 960.834 1468.33 Q960.834 1461.2 959.005 1457.66 Q957.2 1454.1 953.565 1454.1 M953.565 1450.39 Q959.376 1450.39 962.431 1455 Q965.51 1459.58 965.51 1468.33 Q965.51 1477.06 962.431 1481.67 Q959.376 1486.25 953.565 1486.25 Q947.755 1486.25 944.677 1481.67 Q941.621 1477.06 941.621 1468.33 Q941.621 1459.58 944.677 1455 Q947.755 1450.39 953.565 1450.39 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M973.727 1479.7 L978.612 1479.7 L978.612 1485.58 L973.727 1485.58 L973.727 1479.7 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M1001.64 1455.09 L989.838 1473.54 L1001.64 1473.54 L1001.64 1455.09 M1000.42 1451.02 L1006.3 1451.02 L1006.3 1473.54 L1011.23 1473.54 L1011.23 1477.43 L1006.3 1477.43 L1006.3 1485.58 L1001.64 1485.58 L1001.64 1477.43 L986.042 1477.43 L986.042 1472.92 L1000.42 1451.02 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M1381.33 1454.1 Q1377.72 1454.1 1375.89 1457.66 Q1374.09 1461.2 1374.09 1468.33 Q1374.09 1475.44 1375.89 1479.01 Q1377.72 1482.55 1381.33 1482.55 Q1384.97 1482.55 1386.77 1479.01 Q1388.6 1475.44 1388.6 1468.33 Q1388.6 1461.2 1386.77 1457.66 Q1384.97 1454.1 1381.33 1454.1 M1381.33 1450.39 Q1387.14 1450.39 1390.2 1455 Q1393.28 1459.58 1393.28 1468.33 Q1393.28 1477.06 1390.2 1481.67 Q1387.14 1486.25 1381.33 1486.25 Q1375.52 1486.25 1372.44 1481.67 Q1369.39 1477.06 1369.39 1468.33 Q1369.39 1459.58 1372.44 1455 Q1375.52 1450.39 1381.33 1450.39 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M1401.5 1479.7 L1406.38 1479.7 L1406.38 1485.58 L1401.5 1485.58 L1401.5 1479.7 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M1427.14 1466.44 Q1424 1466.44 1422.14 1468.59 Q1420.31 1470.74 1420.31 1474.49 Q1420.31 1478.22 1422.14 1480.39 Q1424 1482.55 1427.14 1482.55 Q1430.29 1482.55 1432.12 1480.39 Q1433.97 1478.22 1433.97 1474.49 Q1433.97 1470.74 1432.12 1468.59 Q1430.29 1466.44 1427.14 1466.44 M1436.43 1451.78 L1436.43 1456.04 Q1434.67 1455.21 1432.86 1454.77 Q1431.08 1454.33 1429.32 1454.33 Q1424.69 1454.33 1422.24 1457.45 Q1419.81 1460.58 1419.46 1466.9 Q1420.82 1464.89 1422.88 1463.82 Q1424.94 1462.73 1427.42 1462.73 Q1432.63 1462.73 1435.64 1465.9 Q1438.67 1469.05 1438.67 1474.49 Q1438.67 1479.82 1435.52 1483.03 Q1432.37 1486.25 1427.14 1486.25 Q1421.15 1486.25 1417.98 1481.67 Q1414.81 1477.06 1414.81 1468.33 Q1414.81 1460.14 1418.69 1455.28 Q1422.58 1450.39 1429.13 1450.39 Q1430.89 1450.39 1432.68 1450.74 Q1434.48 1451.09 1436.43 1451.78 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M1809.07 1454.1 Q1805.46 1454.1 1803.63 1457.66 Q1801.82 1461.2 1801.82 1468.33 Q1801.82 1475.44 1803.63 1479.01 Q1805.46 1482.55 1809.07 1482.55 Q1812.7 1482.55 1814.51 1479.01 Q1816.34 1475.44 1816.34 1468.33 Q1816.34 1461.2 1814.51 1457.66 Q1812.7 1454.1 1809.07 1454.1 M1809.07 1450.39 Q1814.88 1450.39 1817.93 1455 Q1821.01 1459.58 1821.01 1468.33 Q1821.01 1477.06 1817.93 1481.67 Q1814.88 1486.25 1809.07 1486.25 Q1803.26 1486.25 1800.18 1481.67 Q1797.12 1477.06 1797.12 1468.33 Q1797.12 1459.58 1800.18 1455 Q1803.26 1450.39 1809.07 1450.39 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M1829.23 1479.7 L1834.11 1479.7 L1834.11 1485.58 L1829.23 1485.58 L1829.23 1479.7 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M1854.3 1469.17 Q1850.96 1469.17 1849.04 1470.95 Q1847.15 1472.73 1847.15 1475.86 Q1847.15 1478.98 1849.04 1480.77 Q1850.96 1482.55 1854.3 1482.55 Q1857.63 1482.55 1859.55 1480.77 Q1861.47 1478.96 1861.47 1475.86 Q1861.47 1472.73 1859.55 1470.95 Q1857.65 1469.17 1854.3 1469.17 M1849.62 1467.18 Q1846.61 1466.44 1844.92 1464.38 Q1843.26 1462.32 1843.26 1459.35 Q1843.26 1455.21 1846.2 1452.8 Q1849.16 1450.39 1854.3 1450.39 Q1859.46 1450.39 1862.4 1452.8 Q1865.34 1455.21 1865.34 1459.35 Q1865.34 1462.32 1863.65 1464.38 Q1861.98 1466.44 1859 1467.18 Q1862.38 1467.96 1864.25 1470.26 Q1866.15 1472.55 1866.15 1475.86 Q1866.15 1480.88 1863.07 1483.57 Q1860.02 1486.25 1854.3 1486.25 Q1848.58 1486.25 1845.5 1483.57 Q1842.45 1480.88 1842.45 1475.86 Q1842.45 1472.55 1844.34 1470.26 Q1846.24 1467.96 1849.62 1467.18 M1847.91 1459.79 Q1847.91 1462.48 1849.58 1463.98 Q1851.27 1465.49 1854.3 1465.49 Q1857.31 1465.49 1859 1463.98 Q1860.71 1462.48 1860.71 1459.79 Q1860.71 1457.11 1859 1455.6 Q1857.31 1454.1 1854.3 1454.1 Q1851.27 1454.1 1849.58 1455.6 Q1847.91 1457.11 1847.91 1459.79 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M2226.4 1481.64 L2234.03 1481.64 L2234.03 1455.28 L2225.72 1456.95 L2225.72 1452.69 L2233.99 1451.02 L2238.66 1451.02 L2238.66 1481.64 L2246.3 1481.64 L2246.3 1485.58 L2226.4 1485.58 L2226.4 1481.64 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M2255.75 1479.7 L2260.63 1479.7 L2260.63 1485.58 L2255.75 1485.58 L2255.75 1479.7 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M2280.82 1454.1 Q2277.2 1454.1 2275.38 1457.66 Q2273.57 1461.2 2273.57 1468.33 Q2273.57 1475.44 2275.38 1479.01 Q2277.2 1482.55 2280.82 1482.55 Q2284.45 1482.55 2286.26 1479.01 Q2288.08 1475.44 2288.08 1468.33 Q2288.08 1461.2 2286.26 1457.66 Q2284.45 1454.1 2280.82 1454.1 M2280.82 1450.39 Q2286.63 1450.39 2289.68 1455 Q2292.76 1459.58 2292.76 1468.33 Q2292.76 1477.06 2289.68 1481.67 Q2286.63 1486.25 2280.82 1486.25 Q2275.01 1486.25 2271.93 1481.67 Q2268.87 1477.06 2268.87 1468.33 Q2268.87 1459.58 2271.93 1455 Q2275.01 1450.39 2280.82 1450.39 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M1159.81 1533.45 L1159.81 1538.98 Q1157.33 1537.71 1154.65 1537.07 Q1151.98 1536.44 1149.11 1536.44 Q1144.75 1536.44 1142.56 1537.77 Q1140.39 1539.11 1140.39 1541.79 Q1140.39 1543.82 1141.95 1545 Q1143.51 1546.15 1148.22 1547.2 L1150.23 1547.64 Q1156.47 1548.98 1159.08 1551.43 Q1161.72 1553.85 1161.72 1558.21 Q1161.72 1563.17 1157.77 1566.07 Q1153.86 1568.97 1146.98 1568.97 Q1144.12 1568.97 1141 1568.39 Q1137.91 1567.85 1134.47 1566.74 L1134.47 1560.69 Q1137.72 1562.38 1140.87 1563.24 Q1144.02 1564.07 1147.11 1564.07 Q1151.25 1564.07 1153.47 1562.66 Q1155.7 1561.23 1155.7 1558.65 Q1155.7 1556.27 1154.08 1554.99 Q1152.49 1553.72 1147.05 1552.54 L1145.01 1552.07 Q1139.57 1550.92 1137.15 1548.56 Q1134.73 1546.18 1134.73 1542.04 Q1134.73 1537.01 1138.29 1534.27 Q1141.86 1531.54 1148.41 1531.54 Q1151.66 1531.54 1154.53 1532.01 Q1157.39 1532.49 1159.81 1533.45 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M1191.22 1518.52 L1204.72 1518.52 L1204.72 1523.07 L1197.08 1523.07 L1197.08 1572.09 L1204.72 1572.09 L1204.72 1576.64 L1191.22 1576.64 L1191.22 1518.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M1216.97 1518.52 L1222.86 1518.52 L1222.86 1547.77 L1240.33 1532.4 L1247.81 1532.4 L1228.91 1549.07 L1248.61 1568.04 L1240.97 1568.04 L1222.86 1550.63 L1222.86 1568.04 L1216.97 1568.04 L1216.97 1518.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M1255.2 1520.52 L1261.63 1520.52 L1261.63 1564.73 Q1261.63 1573.33 1258.35 1577.21 Q1255.1 1581.09 1247.88 1581.09 L1245.43 1581.09 L1245.43 1575.68 L1247.43 1575.68 Q1251.7 1575.68 1253.45 1573.3 Q1255.2 1570.91 1255.2 1564.73 L1255.2 1520.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M1284.58 1520.52 L1289.99 1520.52 L1273.44 1574.09 L1268.03 1574.09 L1284.58 1520.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M1295.91 1518.52 L1301.8 1518.52 L1301.8 1547.77 L1319.27 1532.4 L1326.75 1532.4 L1307.84 1549.07 L1327.54 1568.04 L1319.91 1568.04 L1301.8 1550.63 L1301.8 1568.04 L1295.91 1568.04 L1295.91 1518.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M1357.34 1549.81 Q1357.34 1543.44 1354.69 1539.94 Q1352.08 1536.44 1347.34 1536.44 Q1342.63 1536.44 1339.99 1539.94 Q1337.38 1543.44 1337.38 1549.81 Q1337.38 1556.14 1339.99 1559.64 Q1342.63 1563.14 1347.34 1563.14 Q1352.08 1563.14 1354.69 1559.64 Q1357.34 1556.14 1357.34 1549.81 M1363.19 1563.62 Q1363.19 1572.72 1359.15 1577.15 Q1355.11 1581.6 1346.77 1581.6 Q1343.68 1581.6 1340.94 1581.13 Q1338.21 1580.68 1335.63 1579.72 L1335.63 1574.03 Q1338.21 1575.43 1340.72 1576.1 Q1343.24 1576.76 1345.85 1576.76 Q1351.61 1576.76 1354.47 1573.74 Q1357.34 1570.75 1357.34 1564.67 L1357.34 1561.77 Q1355.52 1564.92 1352.69 1566.48 Q1349.86 1568.04 1345.91 1568.04 Q1339.35 1568.04 1335.34 1563.05 Q1331.33 1558.05 1331.33 1549.81 Q1331.33 1541.53 1335.34 1536.53 Q1339.35 1531.54 1345.91 1531.54 Q1349.86 1531.54 1352.69 1533.1 Q1355.52 1534.66 1357.34 1537.81 L1357.34 1532.4 L1363.19 1532.4 L1363.19 1563.62 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M1376.08 1559.96 L1382.8 1559.96 L1382.8 1568.04 L1376.08 1568.04 L1376.08 1559.96 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M1396.23 1520.52 L1402.66 1520.52 L1402.66 1540.61 L1423.99 1520.52 L1432.26 1520.52 L1408.68 1542.68 L1433.95 1568.04 L1425.48 1568.04 L1402.66 1545.16 L1402.66 1568.04 L1396.23 1568.04 L1396.23 1520.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M1452.41 1518.52 L1452.41 1576.64 L1438.91 1576.64 L1438.91 1572.09 L1446.52 1572.09 L1446.52 1523.07 L1438.91 1523.07 L1438.91 1518.52 L1452.41 1518.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><polyline clip-path="url(#clip750)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="234.125,1423.18 234.125,47.2441 "/>
<polyline clip-path="url(#clip750)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="234.125,1265.61 253.023,1265.61 "/>
<polyline clip-path="url(#clip750)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="234.125,1059.07 253.023,1059.07 "/>
<polyline clip-path="url(#clip750)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="234.125,852.536 253.023,852.536 "/>
<polyline clip-path="url(#clip750)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="234.125,646 253.023,646 "/>
<polyline clip-path="url(#clip750)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="234.125,439.465 253.023,439.465 "/>
<polyline clip-path="url(#clip750)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="234.125,232.929 253.023,232.929 "/>
<path clip-path="url(#clip750)" d="M119.885 1278.95 L136.204 1278.95 L136.204 1282.89 L114.26 1282.89 L114.26 1278.95 Q116.922 1276.2 121.505 1271.57 Q126.112 1266.91 127.292 1265.57 Q129.538 1263.05 130.417 1261.31 Q131.32 1259.55 131.32 1257.86 Q131.32 1255.11 129.376 1253.37 Q127.455 1251.64 124.353 1251.64 Q122.154 1251.64 119.7 1252.4 Q117.269 1253.16 114.492 1254.72 L114.492 1249.99 Q117.316 1248.86 119.769 1248.28 Q122.223 1247.7 124.26 1247.7 Q129.63 1247.7 132.825 1250.39 Q136.019 1253.07 136.019 1257.56 Q136.019 1259.69 135.209 1261.61 Q134.422 1263.51 132.316 1266.1 Q131.737 1266.78 128.635 1269.99 Q125.533 1273.19 119.885 1278.95 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M156.598 1263.74 Q153.45 1263.74 151.598 1265.9 Q149.769 1268.05 149.769 1271.8 Q149.769 1275.53 151.598 1277.7 Q153.45 1279.85 156.598 1279.85 Q159.746 1279.85 161.575 1277.7 Q163.427 1275.53 163.427 1271.8 Q163.427 1268.05 161.575 1265.9 Q159.746 1263.74 156.598 1263.74 M165.88 1249.09 L165.88 1253.35 Q164.121 1252.52 162.315 1252.08 Q160.533 1251.64 158.774 1251.64 Q154.144 1251.64 151.691 1254.76 Q149.26 1257.89 148.913 1264.21 Q150.278 1262.19 152.339 1261.13 Q154.399 1260.04 156.876 1260.04 Q162.084 1260.04 165.093 1263.21 Q168.126 1266.36 168.126 1271.8 Q168.126 1277.12 164.977 1280.34 Q161.829 1283.56 156.598 1283.56 Q150.603 1283.56 147.431 1278.97 Q144.26 1274.37 144.26 1265.64 Q144.26 1257.45 148.149 1252.59 Q152.038 1247.7 158.589 1247.7 Q160.348 1247.7 162.13 1248.05 Q163.936 1248.4 165.88 1249.09 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M186.181 1251.41 Q182.57 1251.41 180.741 1254.97 Q178.936 1258.51 178.936 1265.64 Q178.936 1272.75 180.741 1276.31 Q182.57 1279.85 186.181 1279.85 Q189.815 1279.85 191.621 1276.31 Q193.45 1272.75 193.45 1265.64 Q193.45 1258.51 191.621 1254.97 Q189.815 1251.41 186.181 1251.41 M186.181 1247.7 Q191.991 1247.7 195.047 1252.31 Q198.125 1256.89 198.125 1265.64 Q198.125 1274.37 195.047 1278.97 Q191.991 1283.56 186.181 1283.56 Q180.371 1283.56 177.292 1278.97 Q174.237 1274.37 174.237 1265.64 Q174.237 1256.89 177.292 1252.31 Q180.371 1247.7 186.181 1247.7 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M119.885 1072.42 L136.204 1072.42 L136.204 1076.35 L114.26 1076.35 L114.26 1072.42 Q116.922 1069.66 121.505 1065.03 Q126.112 1060.38 127.292 1059.04 Q129.538 1056.51 130.417 1054.78 Q131.32 1053.02 131.32 1051.33 Q131.32 1048.57 129.376 1046.84 Q127.455 1045.1 124.353 1045.1 Q122.154 1045.1 119.7 1045.87 Q117.269 1046.63 114.492 1048.18 L114.492 1043.46 Q117.316 1042.32 119.769 1041.74 Q122.223 1041.17 124.26 1041.17 Q129.63 1041.17 132.825 1043.85 Q136.019 1046.54 136.019 1051.03 Q136.019 1053.16 135.209 1055.08 Q134.422 1056.98 132.316 1059.57 Q131.737 1060.24 128.635 1063.46 Q125.533 1066.65 119.885 1072.42 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M156.019 1059.94 Q152.686 1059.94 150.765 1061.72 Q148.866 1063.5 148.866 1066.63 Q148.866 1069.75 150.765 1071.54 Q152.686 1073.32 156.019 1073.32 Q159.353 1073.32 161.274 1071.54 Q163.195 1069.73 163.195 1066.63 Q163.195 1063.5 161.274 1061.72 Q159.376 1059.94 156.019 1059.94 M151.343 1057.95 Q148.334 1057.21 146.644 1055.15 Q144.978 1053.09 144.978 1050.12 Q144.978 1045.98 147.917 1043.57 Q150.88 1041.17 156.019 1041.17 Q161.181 1041.17 164.121 1043.57 Q167.061 1045.98 167.061 1050.12 Q167.061 1053.09 165.371 1055.15 Q163.704 1057.21 160.718 1057.95 Q164.098 1058.74 165.973 1061.03 Q167.871 1063.32 167.871 1066.63 Q167.871 1071.65 164.792 1074.34 Q161.737 1077.02 156.019 1077.02 Q150.302 1077.02 147.223 1074.34 Q144.167 1071.65 144.167 1066.63 Q144.167 1063.32 146.066 1061.03 Q147.964 1058.74 151.343 1057.95 M149.63 1050.56 Q149.63 1053.25 151.297 1054.75 Q152.987 1056.26 156.019 1056.26 Q159.028 1056.26 160.718 1054.75 Q162.431 1053.25 162.431 1050.56 Q162.431 1047.88 160.718 1046.37 Q159.028 1044.87 156.019 1044.87 Q152.987 1044.87 151.297 1046.37 Q149.63 1047.88 149.63 1050.56 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M186.181 1044.87 Q182.57 1044.87 180.741 1048.43 Q178.936 1051.98 178.936 1059.11 Q178.936 1066.21 180.741 1069.78 Q182.57 1073.32 186.181 1073.32 Q189.815 1073.32 191.621 1069.78 Q193.45 1066.21 193.45 1059.11 Q193.45 1051.98 191.621 1048.43 Q189.815 1044.87 186.181 1044.87 M186.181 1041.17 Q191.991 1041.17 195.047 1045.77 Q198.125 1050.36 198.125 1059.11 Q198.125 1067.83 195.047 1072.44 Q191.991 1077.02 186.181 1077.02 Q180.371 1077.02 177.292 1072.44 Q174.237 1067.83 174.237 1059.11 Q174.237 1050.36 177.292 1045.77 Q180.371 1041.17 186.181 1041.17 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M130.024 851.181 Q133.38 851.899 135.255 854.168 Q137.154 856.436 137.154 859.769 Q137.154 864.885 133.635 867.686 Q130.117 870.487 123.635 870.487 Q121.459 870.487 119.144 870.047 Q116.853 869.63 114.399 868.774 L114.399 864.26 Q116.343 865.394 118.658 865.973 Q120.973 866.552 123.496 866.552 Q127.894 866.552 130.186 864.816 Q132.501 863.08 132.501 859.769 Q132.501 856.714 130.348 855.001 Q128.218 853.265 124.399 853.265 L120.371 853.265 L120.371 849.422 L124.584 849.422 Q128.033 849.422 129.862 848.056 Q131.691 846.668 131.691 844.075 Q131.691 841.413 129.792 840.001 Q127.917 838.566 124.399 838.566 Q122.478 838.566 120.279 838.982 Q118.08 839.399 115.441 840.279 L115.441 836.112 Q118.103 835.371 120.418 835.001 Q122.755 834.631 124.816 834.631 Q130.14 834.631 133.242 837.061 Q136.343 839.469 136.343 843.589 Q136.343 846.459 134.7 848.45 Q133.056 850.418 130.024 851.181 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M156.019 838.334 Q152.408 838.334 150.579 841.899 Q148.774 845.441 148.774 852.57 Q148.774 859.677 150.579 863.242 Q152.408 866.783 156.019 866.783 Q159.653 866.783 161.459 863.242 Q163.288 859.677 163.288 852.57 Q163.288 845.441 161.459 841.899 Q159.653 838.334 156.019 838.334 M156.019 834.631 Q161.829 834.631 164.885 839.237 Q167.964 843.82 167.964 852.57 Q167.964 861.297 164.885 865.904 Q161.829 870.487 156.019 870.487 Q150.209 870.487 147.13 865.904 Q144.075 861.297 144.075 852.57 Q144.075 843.82 147.13 839.237 Q150.209 834.631 156.019 834.631 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M186.181 838.334 Q182.57 838.334 180.741 841.899 Q178.936 845.441 178.936 852.57 Q178.936 859.677 180.741 863.242 Q182.57 866.783 186.181 866.783 Q189.815 866.783 191.621 863.242 Q193.45 859.677 193.45 852.57 Q193.45 845.441 191.621 841.899 Q189.815 838.334 186.181 838.334 M186.181 834.631 Q191.991 834.631 195.047 839.237 Q198.125 843.82 198.125 852.57 Q198.125 861.297 195.047 865.904 Q191.991 870.487 186.181 870.487 Q180.371 870.487 177.292 865.904 Q174.237 861.297 174.237 852.57 Q174.237 843.82 177.292 839.237 Q180.371 834.631 186.181 834.631 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M130.024 644.646 Q133.38 645.364 135.255 647.632 Q137.154 649.901 137.154 653.234 Q137.154 658.35 133.635 661.15 Q130.117 663.951 123.635 663.951 Q121.459 663.951 119.144 663.512 Q116.853 663.095 114.399 662.238 L114.399 657.725 Q116.343 658.859 118.658 659.438 Q120.973 660.016 123.496 660.016 Q127.894 660.016 130.186 658.28 Q132.501 656.544 132.501 653.234 Q132.501 650.178 130.348 648.465 Q128.218 646.729 124.399 646.729 L120.371 646.729 L120.371 642.887 L124.584 642.887 Q128.033 642.887 129.862 641.521 Q131.691 640.132 131.691 637.54 Q131.691 634.877 129.792 633.465 Q127.917 632.03 124.399 632.03 Q122.478 632.03 120.279 632.447 Q118.08 632.864 115.441 633.743 L115.441 629.577 Q118.103 628.836 120.418 628.465 Q122.755 628.095 124.816 628.095 Q130.14 628.095 133.242 630.526 Q136.343 632.933 136.343 637.053 Q136.343 639.924 134.7 641.914 Q133.056 643.882 130.024 644.646 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M150.047 659.345 L166.366 659.345 L166.366 663.28 L144.422 663.28 L144.422 659.345 Q147.084 656.59 151.667 651.961 Q156.274 647.308 157.454 645.965 Q159.7 643.442 160.579 641.706 Q161.482 639.947 161.482 638.257 Q161.482 635.502 159.538 633.766 Q157.616 632.03 154.515 632.03 Q152.316 632.03 149.862 632.794 Q147.431 633.558 144.654 635.109 L144.654 630.387 Q147.478 629.253 149.931 628.674 Q152.385 628.095 154.422 628.095 Q159.792 628.095 162.987 630.78 Q166.181 633.465 166.181 637.956 Q166.181 640.086 165.371 642.007 Q164.584 643.905 162.477 646.498 Q161.899 647.169 158.797 650.387 Q155.695 653.581 150.047 659.345 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M186.181 631.799 Q182.57 631.799 180.741 635.364 Q178.936 638.905 178.936 646.035 Q178.936 653.141 180.741 656.706 Q182.57 660.248 186.181 660.248 Q189.815 660.248 191.621 656.706 Q193.45 653.141 193.45 646.035 Q193.45 638.905 191.621 635.364 Q189.815 631.799 186.181 631.799 M186.181 628.095 Q191.991 628.095 195.047 632.702 Q198.125 637.285 198.125 646.035 Q198.125 654.762 195.047 659.368 Q191.991 663.951 186.181 663.951 Q180.371 663.951 177.292 659.368 Q174.237 654.762 174.237 646.035 Q174.237 637.285 177.292 632.702 Q180.371 628.095 186.181 628.095 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M130.024 438.11 Q133.38 438.828 135.255 441.097 Q137.154 443.365 137.154 446.698 Q137.154 451.814 133.635 454.615 Q130.117 457.416 123.635 457.416 Q121.459 457.416 119.144 456.976 Q116.853 456.559 114.399 455.703 L114.399 451.189 Q116.343 452.323 118.658 452.902 Q120.973 453.481 123.496 453.481 Q127.894 453.481 130.186 451.745 Q132.501 450.009 132.501 446.698 Q132.501 443.643 130.348 441.93 Q128.218 440.194 124.399 440.194 L120.371 440.194 L120.371 436.351 L124.584 436.351 Q128.033 436.351 129.862 434.985 Q131.691 433.597 131.691 431.004 Q131.691 428.342 129.792 426.93 Q127.917 425.495 124.399 425.495 Q122.478 425.495 120.279 425.911 Q118.08 426.328 115.441 427.208 L115.441 423.041 Q118.103 422.3 120.418 421.93 Q122.755 421.56 124.816 421.56 Q130.14 421.56 133.242 423.99 Q136.343 426.398 136.343 430.518 Q136.343 433.388 134.7 435.379 Q133.056 437.347 130.024 438.11 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M158.866 426.259 L147.061 444.708 L158.866 444.708 L158.866 426.259 M157.64 422.185 L163.519 422.185 L163.519 444.708 L168.45 444.708 L168.45 448.597 L163.519 448.597 L163.519 456.745 L158.866 456.745 L158.866 448.597 L143.265 448.597 L143.265 444.083 L157.64 422.185 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M186.181 425.263 Q182.57 425.263 180.741 428.828 Q178.936 432.37 178.936 439.499 Q178.936 446.606 180.741 450.171 Q182.57 453.712 186.181 453.712 Q189.815 453.712 191.621 450.171 Q193.45 446.606 193.45 439.499 Q193.45 432.37 191.621 428.828 Q189.815 425.263 186.181 425.263 M186.181 421.56 Q191.991 421.56 195.047 426.166 Q198.125 430.749 198.125 439.499 Q198.125 448.226 195.047 452.833 Q191.991 457.416 186.181 457.416 Q180.371 457.416 177.292 452.833 Q174.237 448.226 174.237 439.499 Q174.237 430.749 177.292 426.166 Q180.371 421.56 186.181 421.56 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M130.024 231.575 Q133.38 232.293 135.255 234.561 Q137.154 236.83 137.154 240.163 Q137.154 245.279 133.635 248.08 Q130.117 250.88 123.635 250.88 Q121.459 250.88 119.144 250.441 Q116.853 250.024 114.399 249.167 L114.399 244.654 Q116.343 245.788 118.658 246.367 Q120.973 246.945 123.496 246.945 Q127.894 246.945 130.186 245.209 Q132.501 243.473 132.501 240.163 Q132.501 237.107 130.348 235.394 Q128.218 233.658 124.399 233.658 L120.371 233.658 L120.371 229.816 L124.584 229.816 Q128.033 229.816 129.862 228.45 Q131.691 227.061 131.691 224.469 Q131.691 221.807 129.792 220.394 Q127.917 218.959 124.399 218.959 Q122.478 218.959 120.279 219.376 Q118.08 219.793 115.441 220.672 L115.441 216.506 Q118.103 215.765 120.418 215.395 Q122.755 215.024 124.816 215.024 Q130.14 215.024 133.242 217.455 Q136.343 219.862 136.343 223.982 Q136.343 226.853 134.7 228.844 Q133.056 230.811 130.024 231.575 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M156.598 231.066 Q153.45 231.066 151.598 233.218 Q149.769 235.371 149.769 239.121 Q149.769 242.848 151.598 245.024 Q153.45 247.177 156.598 247.177 Q159.746 247.177 161.575 245.024 Q163.427 242.848 163.427 239.121 Q163.427 235.371 161.575 233.218 Q159.746 231.066 156.598 231.066 M165.88 216.413 L165.88 220.672 Q164.121 219.839 162.315 219.399 Q160.533 218.959 158.774 218.959 Q154.144 218.959 151.691 222.084 Q149.26 225.209 148.913 231.529 Q150.278 229.515 152.339 228.45 Q154.399 227.362 156.876 227.362 Q162.084 227.362 165.093 230.533 Q168.126 233.681 168.126 239.121 Q168.126 244.445 164.977 247.663 Q161.829 250.88 156.598 250.88 Q150.603 250.88 147.431 246.297 Q144.26 241.691 144.26 232.964 Q144.26 224.769 148.149 219.908 Q152.038 215.024 158.589 215.024 Q160.348 215.024 162.13 215.371 Q163.936 215.719 165.88 216.413 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M186.181 218.728 Q182.57 218.728 180.741 222.293 Q178.936 225.834 178.936 232.964 Q178.936 240.07 180.741 243.635 Q182.57 247.177 186.181 247.177 Q189.815 247.177 191.621 243.635 Q193.45 240.07 193.45 232.964 Q193.45 225.834 191.621 222.293 Q189.815 218.728 186.181 218.728 M186.181 215.024 Q191.991 215.024 195.047 219.631 Q198.125 224.214 198.125 232.964 Q198.125 241.691 195.047 246.297 Q191.991 250.88 186.181 250.88 Q180.371 250.88 177.292 246.297 Q174.237 241.691 174.237 232.964 Q174.237 224.214 177.292 219.631 Q180.371 215.024 186.181 215.024 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M16.4842 809.579 L16.4842 769.38 L21.895 769.38 L21.895 786.249 L64.0042 786.249 L64.0042 792.71 L21.895 792.71 L21.895 809.579 L16.4842 809.579 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M14.479 743.249 L14.479 729.753 L19.0304 729.753 L19.0304 737.392 L68.0464 737.392 L68.0464 729.753 L72.5979 729.753 L72.5979 743.249 L14.479 743.249 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M16.4842 717.022 L16.4842 710.593 L36.568 710.593 L16.4842 689.267 L16.4842 680.992 L38.6368 704.577 L64.0042 679.305 L64.0042 687.772 L41.1194 710.593 L64.0042 710.593 L64.0042 717.022 L16.4842 717.022 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M14.479 660.845 L72.5979 660.845 L72.5979 674.34 L68.0464 674.34 L68.0464 666.733 L19.0304 666.733 L19.0304 674.34 L14.479 674.34 L14.479 660.845 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><polyline clip-path="url(#clip752)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:0.4; fill:none" points="294.087,1384.24 469.32,1216.93 627.276,1061.17 770.194,916.939 899.829,784.25 1017.57,663.098 1124.54,553.485 1221.64,455.41 1309.6,368.873 1389.06,293.874 1460.62,230.414 1524.91,178.492 1582.74,138.108 1635.49,109.262 1687.44,91.9548 1759.99,86.1857 1821.09,91.9548 1889.63,109.262 1935.8,138.108 1969.37,178.492 1997.15,230.414 2019.92,293.874 2038.31,368.873 2052.99,455.41 2064.7,553.485 2074.41,663.098 2083.29,784.25 2092.91,916.939 2105.41,1061.17 2123.82,1216.93 2152.59,1384.24 "/>
<polyline clip-path="url(#clip752)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:0.5; fill:none" stroke-dasharray="16, 10" points="2111.94,1122.87 2111.94,500.807 "/>
<polyline clip-path="url(#clip752)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2111.94,1122.87 2135.63,469.447 "/>
<polyline clip-path="url(#clip752)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2135.63,469.447 2065.3,559.431 1118.71,559.431 "/>
<polyline clip-path="url(#clip752)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1118.71,559.431 1127.69,749.14 1136.67,847.39 1145.65,921.193 1154.62,982.007 1163.6,1034.45 1172.58,1080.92 1181.56,1122.87 "/>
<polyline clip-path="url(#clip752)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1181.56,1122.87 2111.94,1122.87 "/>
<polyline clip-path="url(#clip752)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:0.4; fill:none" points="565.223,1122.87 2111.94,1122.87 2162.85,1046.64 2212.17,970.404 2260.27,894.171 "/>
<polyline clip-path="url(#clip752)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:0.4; fill:none" points="1118.71,559.431 2065.3,559.431 2127.92,479.761 2185.74,400.09 2240.41,320.419 2292.79,240.749 "/>
<path clip-path="url(#clip750)" d="M2043 1159.28 L2043 1098.87 L2089.73 1098.87 L2089.73 1159.28 L2043 1159.28 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M2088.58 1159.28 L2088.58 1098.87 L2135.31 1098.87 L2135.31 1159.28 L2088.58 1159.28 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M2134.15 1159.28 L2134.15 1098.87 L2180.88 1098.87 L2180.88 1159.28 L2134.15 1159.28 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M2087.39 1114.99 L2087.39 1119.02 Q2085.59 1118.09 2083.64 1117.63 Q2081.7 1117.16 2079.62 1117.16 Q2076.44 1117.16 2074.85 1118.14 Q2073.27 1119.11 2073.27 1121.05 Q2073.27 1122.53 2074.41 1123.39 Q2075.54 1124.22 2078.97 1124.99 L2080.43 1125.31 Q2084.96 1126.28 2086.86 1128.07 Q2088.78 1129.83 2088.78 1133 Q2088.78 1136.61 2085.91 1138.71 Q2083.07 1140.82 2078.07 1140.82 Q2075.98 1140.82 2073.71 1140.4 Q2071.47 1140.01 2068.97 1139.2 L2068.97 1134.8 Q2071.33 1136.03 2073.62 1136.65 Q2075.91 1137.26 2078.16 1137.26 Q2081.17 1137.26 2082.79 1136.24 Q2084.41 1135.2 2084.41 1133.32 Q2084.41 1131.58 2083.23 1130.66 Q2082.07 1129.73 2078.11 1128.88 L2076.63 1128.53 Q2072.67 1127.7 2070.91 1125.98 Q2069.15 1124.25 2069.15 1121.24 Q2069.15 1117.58 2071.75 1115.59 Q2074.34 1113.6 2079.11 1113.6 Q2081.47 1113.6 2083.55 1113.95 Q2085.63 1114.29 2087.39 1114.99 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M2099.78 1106.86 L2099.78 1114.22 L2108.55 1114.22 L2108.55 1117.53 L2099.78 1117.53 L2099.78 1131.61 Q2099.78 1134.78 2100.63 1135.68 Q2101.51 1136.58 2104.18 1136.58 L2108.55 1136.58 L2108.55 1140.15 L2104.18 1140.15 Q2099.25 1140.15 2097.37 1138.32 Q2095.5 1136.47 2095.5 1131.61 L2095.5 1117.53 L2092.37 1117.53 L2092.37 1114.22 L2095.5 1114.22 L2095.5 1106.86 L2099.78 1106.86 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M2115.57 1136.21 L2123.2 1136.21 L2123.2 1109.85 L2114.89 1111.52 L2114.89 1107.26 L2123.16 1105.59 L2127.83 1105.59 L2127.83 1136.21 L2135.47 1136.21 L2135.47 1140.15 L2115.57 1140.15 L2115.57 1136.21 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M2089.48 505.861 L2089.48 445.445 L2136.21 445.445 L2136.21 505.861 L2089.48 505.861 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M2135.05 505.861 L2135.05 445.445 L2181.78 445.445 L2181.78 505.861 L2135.05 505.861 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M2120.99 461.565 L2120.99 465.593 Q2119.18 464.667 2117.24 464.204 Q2115.29 463.741 2113.21 463.741 Q2110.04 463.741 2108.44 464.713 Q2106.87 465.685 2106.87 467.63 Q2106.87 469.111 2108 469.968 Q2109.13 470.801 2112.56 471.565 L2114.02 471.889 Q2118.56 472.861 2120.45 474.643 Q2122.38 476.403 2122.38 479.574 Q2122.38 483.185 2119.5 485.292 Q2116.66 487.398 2111.66 487.398 Q2109.57 487.398 2107.31 486.981 Q2105.06 486.588 2102.56 485.778 L2102.56 481.38 Q2104.92 482.606 2107.21 483.231 Q2109.5 483.833 2111.75 483.833 Q2114.76 483.833 2116.38 482.815 Q2118 481.773 2118 479.898 Q2118 478.162 2116.82 477.236 Q2115.66 476.31 2111.7 475.454 L2110.22 475.106 Q2106.26 474.273 2104.5 472.56 Q2102.75 470.824 2102.75 467.815 Q2102.75 464.157 2105.34 462.167 Q2107.93 460.176 2112.7 460.176 Q2115.06 460.176 2117.14 460.523 Q2119.23 460.87 2120.99 461.565 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M2133.37 453.44 L2133.37 460.801 L2142.14 460.801 L2142.14 464.111 L2133.37 464.111 L2133.37 478.185 Q2133.37 481.356 2134.23 482.259 Q2135.11 483.162 2137.77 483.162 L2142.14 483.162 L2142.14 486.727 L2137.77 486.727 Q2132.84 486.727 2130.96 484.898 Q2129.09 483.046 2129.09 478.185 L2129.09 464.111 L2125.96 464.111 L2125.96 460.801 L2129.09 460.801 L2129.09 453.44 L2133.37 453.44 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M2152.37 482.792 L2168.69 482.792 L2168.69 486.727 L2146.75 486.727 L2146.75 482.792 Q2149.41 480.037 2154 475.407 Q2158.6 470.755 2159.78 469.412 Q2162.03 466.889 2162.91 465.153 Q2163.81 463.393 2163.81 461.704 Q2163.81 458.949 2161.87 457.213 Q2159.94 455.477 2156.84 455.477 Q2154.64 455.477 2152.19 456.241 Q2149.76 457.005 2146.98 458.556 L2146.98 453.833 Q2149.81 452.699 2152.26 452.12 Q2154.71 451.542 2156.75 451.542 Q2162.12 451.542 2165.31 454.227 Q2168.51 456.912 2168.51 461.403 Q2168.51 463.532 2167.7 465.454 Q2166.91 467.352 2164.81 469.944 Q2164.23 470.616 2161.12 473.833 Q2158.02 477.028 2152.37 482.792 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M1072.56 595.846 L1072.56 535.43 L1119.29 535.43 L1119.29 595.846 L1072.56 595.846 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M1118.13 595.846 L1118.13 535.43 L1164.86 535.43 L1164.86 595.846 L1118.13 595.846 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M1103.59 551.55 L1103.59 555.577 Q1101.79 554.651 1099.84 554.188 Q1097.9 553.725 1095.82 553.725 Q1092.65 553.725 1091.05 554.698 Q1089.47 555.67 1089.47 557.614 Q1089.47 559.096 1090.61 559.952 Q1091.74 560.786 1095.17 561.549 L1096.63 561.874 Q1101.16 562.846 1103.06 564.628 Q1104.98 566.387 1104.98 569.559 Q1104.98 573.17 1102.11 575.276 Q1099.27 577.383 1094.27 577.383 Q1092.18 577.383 1089.91 576.966 Q1087.67 576.573 1085.17 575.762 L1085.17 571.364 Q1087.53 572.591 1089.82 573.216 Q1092.11 573.818 1094.36 573.818 Q1097.37 573.818 1098.99 572.799 Q1100.61 571.758 1100.61 569.883 Q1100.61 568.147 1099.43 567.221 Q1098.27 566.295 1094.31 565.438 L1092.83 565.091 Q1088.87 564.258 1087.11 562.545 Q1085.35 560.809 1085.35 557.799 Q1085.35 554.142 1087.95 552.151 Q1090.54 550.161 1095.31 550.161 Q1097.67 550.161 1099.75 550.508 Q1101.83 550.855 1103.59 551.55 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M1115.98 543.425 L1115.98 550.786 L1124.75 550.786 L1124.75 554.096 L1115.98 554.096 L1115.98 568.17 Q1115.98 571.341 1116.83 572.244 Q1117.71 573.147 1120.38 573.147 L1124.75 573.147 L1124.75 576.711 L1120.38 576.711 Q1115.45 576.711 1113.57 574.883 Q1111.7 573.031 1111.7 568.17 L1111.7 554.096 L1108.57 554.096 L1108.57 550.786 L1111.7 550.786 L1111.7 543.425 L1115.98 543.425 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M1145.12 558.077 Q1148.48 558.795 1150.35 561.063 Q1152.25 563.332 1152.25 566.665 Q1152.25 571.781 1148.73 574.582 Q1145.21 577.383 1138.73 577.383 Q1136.56 577.383 1134.24 576.943 Q1131.95 576.526 1129.5 575.67 L1129.5 571.156 Q1131.44 572.29 1133.76 572.869 Q1136.07 573.448 1138.59 573.448 Q1142.99 573.448 1145.28 571.711 Q1147.6 569.975 1147.6 566.665 Q1147.6 563.61 1145.45 561.897 Q1143.32 560.161 1139.5 560.161 L1135.47 560.161 L1135.47 556.318 L1139.68 556.318 Q1143.13 556.318 1144.96 554.952 Q1146.79 553.563 1146.79 550.971 Q1146.79 548.309 1144.89 546.897 Q1143.02 545.462 1139.5 545.462 Q1137.58 545.462 1135.38 545.878 Q1133.18 546.295 1130.54 547.175 L1130.54 543.008 Q1133.2 542.267 1135.52 541.897 Q1137.85 541.526 1139.91 541.526 Q1145.24 541.526 1148.34 543.957 Q1151.44 546.364 1151.44 550.485 Q1151.44 553.355 1149.8 555.346 Q1148.15 557.313 1145.12 558.077 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M1135.41 1159.28 L1135.41 1098.87 L1182.14 1098.87 L1182.14 1159.28 L1135.41 1159.28 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M1180.98 1159.28 L1180.98 1098.87 L1227.71 1098.87 L1227.71 1159.28 L1180.98 1159.28 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M1165.88 1114.99 L1165.88 1119.02 Q1164.07 1118.09 1162.13 1117.63 Q1160.18 1117.16 1158.1 1117.16 Q1154.93 1117.16 1153.33 1118.14 Q1151.76 1119.11 1151.76 1121.05 Q1151.76 1122.53 1152.89 1123.39 Q1154.02 1124.22 1157.45 1124.99 L1158.91 1125.31 Q1163.45 1126.28 1165.34 1128.07 Q1167.27 1129.83 1167.27 1133 Q1167.27 1136.61 1164.39 1138.71 Q1161.55 1140.82 1156.55 1140.82 Q1154.46 1140.82 1152.2 1140.4 Q1149.95 1140.01 1147.45 1139.2 L1147.45 1134.8 Q1149.81 1136.03 1152.1 1136.65 Q1154.39 1137.26 1156.64 1137.26 Q1159.65 1137.26 1161.27 1136.24 Q1162.89 1135.2 1162.89 1133.32 Q1162.89 1131.58 1161.71 1130.66 Q1160.55 1129.73 1156.59 1128.88 L1155.11 1128.53 Q1151.15 1127.7 1149.39 1125.98 Q1147.64 1124.25 1147.64 1121.24 Q1147.64 1117.58 1150.23 1115.59 Q1152.82 1113.6 1157.59 1113.6 Q1159.95 1113.6 1162.03 1113.95 Q1164.12 1114.29 1165.88 1114.99 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M1178.26 1106.86 L1178.26 1114.22 L1187.03 1114.22 L1187.03 1117.53 L1178.26 1117.53 L1178.26 1131.61 Q1178.26 1134.78 1179.12 1135.68 Q1180 1136.58 1182.66 1136.58 L1187.03 1136.58 L1187.03 1140.15 L1182.66 1140.15 Q1177.73 1140.15 1175.85 1138.32 Q1173.98 1136.47 1173.98 1131.61 L1173.98 1117.53 L1170.85 1117.53 L1170.85 1114.22 L1173.98 1114.22 L1173.98 1106.86 L1178.26 1106.86 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip750)" d="M1206.08 1109.66 L1194.28 1128.11 L1206.08 1128.11 L1206.08 1109.66 M1204.86 1105.59 L1210.74 1105.59 L1210.74 1128.11 L1215.67 1128.11 L1215.67 1132 L1210.74 1132 L1210.74 1140.15 L1206.08 1140.15 L1206.08 1132 L1190.48 1132 L1190.48 1127.49 L1204.86 1105.59 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /></svg>
</div><div style=' border: 1px solid;'><h3 style='text-align: center;margin: 8px;'>Cycle Properties:</h3><div style='display: flex; justify-content: space-around;'><div style = "display: inline-block; border: 1px solid #666666;"><!DOCTYPE html>
<html>
<meta charset="UTF-8">
<style>
  table, td, th {
      border-collapse: collapse; color: black;
      font-family: sans-serif;
  }

  td, th {
      border-bottom: 0;
      padding: 4px
  }

  tr:nth-child(odd) {
      background: #eee;
  }

  tr:nth-child(even) {
      background: #fff;
  }

  tr.header {
      background: #fff !important;
      font-weight: bold;
  }

  tr.subheader {
      background: #fff !important;
      color: dimgray;
  }

  tr.headerLastRow {
      border-bottom: 2px solid black;
  }

  th.rowNumber, td.rowNumber {
      text-align: right;
  }

</style>
<body>
<table>
  <thead>
    <tr class = "header headerLastRow">
      <th style = "color: black; text-align: center; padding: 11px; font-size: 130%;"></th>
      <th style = "color: black; text-align: center; padding: 11px; font-size: 130%;">Total</th>
      <th style = "color: black; text-align: center; padding: 11px; font-size: 130%;">Component</th>
      <th style = "color: black; text-align: center; padding: 11px; font-size: 130%;">Value</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">qin<BR>Q̇in</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">119.1562 kJ/kg<BR>0.0 kW</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">evaporator:<BR>   st4 &gt;&gt; st1</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">119.1562 kJ/kg<BR></td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">qout<BR>Q̇out</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">156.3305 kJ/kg<BR>0.0 kW</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">condenser:<BR>   st2 &gt;&gt; st3</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">156.3305 kJ/kg<BR></td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">win<BR>Ẇin</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">37.1743 kJ/kg<BR>0.0 kW</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">compressor:<BR>   st1 &gt;&gt; st2</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">37.1743 kJ/kg<BR></td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">wout<BR>Ẇout</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">0.0 kJ/kg<BR>0.0 kW</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;"></td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;"></td>
    </tr>
  </tbody>
</table>
</body>
</html>
</div></div><h3 style='text-align: center; border: 2px solid #666666; padding: 15px; margin: 10px;'>Coefficient of performance (COP) = 3.2053</h3></div>
</div></br></div>

```
