# Cascade cooling system

!!! note "Cycle data"
    > ![](./assets/ex6.png) 

    !!! ukw "Known properties"
        - Refrigerant-134a is used as working fluid in both cycles;
        - The lower cycle has a mass flow of 2.5 kg/s;
        - The pressure at the inlet of the lower compressor is 250 kPa, and 600 kPa at its outlet;
        - The pressure at the inlet of the upper compressor is 500 kPa, and 1500 kPa at its outlet;
        - The upper compressor has an isentropic efficiency of 80%, and the lower one of 90%.


!!! compat "Input code"
    ```julia
    using CycleSolver

    @solve begin

        evaporator_condenser([stD, st2], [stA, st3])

        stA.p = 500
        stB.p = 1500
        newRefrigerationCycle[R134a]
            compressor(stA, stB, 80)
            condenser(stB, stC)
            expansion_valve(stC, stD)
            
        st1.p = 250
        st2.p = 600
        newRefrigerationCycle[R134a: 2.5]
            compressor(st1, st2, 90)
            expansion_valve(st3, st4)
            evaporator(st4, st1)
            
    end

    PrintResults()
    ```
#### Output:

```@raw html
<div style='display: inline-block; margin: 1px; text-align: center;
    border: 0.5px solid #666666;'><div style='display: inline-block; padding: 15px; margin: 20px;
        border: 2px solid #666666;'>
<h1 style='display: block; text-align: center; border: 1px solid #666666;margin: -17px; margin-bottom: 20px; padding: 10px'>1- REFRIGERATION  CYCLE [R134a]</h1><div style='display: flex; justify-content: space-around;'><div style = "display: inline-block; border: 1px solid #666666;"><!DOCTYPE html>
<html>
<meta charset="UTF-8">
<style>
  table, td, th {
      border-collapse: collapse; color: black;
      font-family: sans-serif;
  }

  td, th {
      border-bottom: 0;
      padding: 4px
  }

  tr:nth-child(odd) {
      background: #eee;
  }

  tr:nth-child(even) {
      background: #fff;
  }

  tr.header {
      background: #fff !important;
      font-weight: bold;
  }

  tr.subheader {
      background: #fff !important;
      color: dimgray;
  }

  tr.headerLastRow {
      border-bottom: 2px solid black;
  }

  th.rowNumber, td.rowNumber {
      text-align: right;
  }

</style>
<body>
<table>
  <thead>
    <tr class = "header headerLastRow">
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">State<br>Name</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">T [K]</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">P [kPa]</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">h [kJ/kg]</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">s [kJ/kg.K]</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">x</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">ṁ [kg/s]</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">Mass-flux<br>fraction</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">stD</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">288.885</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">500.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">131.695</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">0.4823</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">0.3137</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">3.653</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1.0</td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">stA</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">288.885</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">500.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">259.327</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">0.9241</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">3.653</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1.0</td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">stB</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">336.769</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1500.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">287.628</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">0.941</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;"></td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">3.653</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1.0</td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">stC</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">328.383</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1500.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">131.695</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">0.4665</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">0.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">3.653</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1.0</td>
    </tr>
  </tbody>
</table>
</body>
</html>
</div></div><div style='display: flex; justify-content: space-around;
        padding: 10px; margin: 10px;'><?xml version="1.0" encoding="utf-8"?>
<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="600" height="400" viewBox="0 0 2400 1600">
<defs>
  <clipPath id="clip790">
    <rect x="0" y="0" width="2400" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip790)" d="M0 1600 L2400 1600 L2400 0 L0 0  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip791">
    <rect x="480" y="0" width="1681" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip790)" d="M234.125 1423.18 L2352.76 1423.18 L2352.76 47.2441 L234.125 47.2441  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip792">
    <rect x="234" y="47" width="2120" height="1377"/>
  </clipPath>
</defs>
<polyline clip-path="url(#clip790)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="234.125,1423.18 2352.76,1423.18 "/>
<polyline clip-path="url(#clip790)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="324.626,1423.18 324.626,1404.28 "/>
<polyline clip-path="url(#clip790)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="818.127,1423.18 818.127,1404.28 "/>
<polyline clip-path="url(#clip790)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1311.63,1423.18 1311.63,1404.28 "/>
<polyline clip-path="url(#clip790)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1805.13,1423.18 1805.13,1404.28 "/>
<polyline clip-path="url(#clip790)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2298.63,1423.18 2298.63,1404.28 "/>
<path clip-path="url(#clip790)" d="M302.809 1454.1 Q299.198 1454.1 297.369 1457.66 Q295.564 1461.2 295.564 1468.33 Q295.564 1475.44 297.369 1479.01 Q299.198 1482.55 302.809 1482.55 Q306.443 1482.55 308.249 1479.01 Q310.078 1475.44 310.078 1468.33 Q310.078 1461.2 308.249 1457.66 Q306.443 1454.1 302.809 1454.1 M302.809 1450.39 Q308.619 1450.39 311.675 1455 Q314.754 1459.58 314.754 1468.33 Q314.754 1477.06 311.675 1481.67 Q308.619 1486.25 302.809 1486.25 Q296.999 1486.25 293.92 1481.67 Q290.865 1477.06 290.865 1468.33 Q290.865 1459.58 293.92 1455 Q296.999 1450.39 302.809 1450.39 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M322.971 1479.7 L327.855 1479.7 L327.855 1485.58 L322.971 1485.58 L322.971 1479.7 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M342.068 1481.64 L358.388 1481.64 L358.388 1485.58 L336.443 1485.58 L336.443 1481.64 Q339.105 1478.89 343.689 1474.26 Q348.295 1469.61 349.476 1468.27 Q351.721 1465.74 352.601 1464.01 Q353.503 1462.25 353.503 1460.56 Q353.503 1457.8 351.559 1456.07 Q349.638 1454.33 346.536 1454.33 Q344.337 1454.33 341.883 1455.09 Q339.453 1455.86 336.675 1457.41 L336.675 1452.69 Q339.499 1451.55 341.953 1450.97 Q344.406 1450.39 346.443 1450.39 Q351.814 1450.39 355.008 1453.08 Q358.202 1455.77 358.202 1460.26 Q358.202 1462.39 357.392 1464.31 Q356.605 1466.2 354.499 1468.8 Q353.92 1469.47 350.818 1472.69 Q347.716 1475.88 342.068 1481.64 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M795.269 1454.1 Q791.658 1454.1 789.829 1457.66 Q788.023 1461.2 788.023 1468.33 Q788.023 1475.44 789.829 1479.01 Q791.658 1482.55 795.269 1482.55 Q798.903 1482.55 800.708 1479.01 Q802.537 1475.44 802.537 1468.33 Q802.537 1461.2 800.708 1457.66 Q798.903 1454.1 795.269 1454.1 M795.269 1450.39 Q801.079 1450.39 804.134 1455 Q807.213 1459.58 807.213 1468.33 Q807.213 1477.06 804.134 1481.67 Q801.079 1486.25 795.269 1486.25 Q789.459 1486.25 786.38 1481.67 Q783.324 1477.06 783.324 1468.33 Q783.324 1459.58 786.38 1455 Q789.459 1450.39 795.269 1450.39 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M815.431 1479.7 L820.315 1479.7 L820.315 1485.58 L815.431 1485.58 L815.431 1479.7 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M843.347 1455.09 L831.542 1473.54 L843.347 1473.54 L843.347 1455.09 M842.12 1451.02 L848 1451.02 L848 1473.54 L852.93 1473.54 L852.93 1477.43 L848 1477.43 L848 1485.58 L843.347 1485.58 L843.347 1477.43 L827.745 1477.43 L827.745 1472.92 L842.12 1451.02 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M1288.93 1454.1 Q1285.32 1454.1 1283.49 1457.66 Q1281.69 1461.2 1281.69 1468.33 Q1281.69 1475.44 1283.49 1479.01 Q1285.32 1482.55 1288.93 1482.55 Q1292.57 1482.55 1294.37 1479.01 Q1296.2 1475.44 1296.2 1468.33 Q1296.2 1461.2 1294.37 1457.66 Q1292.57 1454.1 1288.93 1454.1 M1288.93 1450.39 Q1294.74 1450.39 1297.8 1455 Q1300.88 1459.58 1300.88 1468.33 Q1300.88 1477.06 1297.8 1481.67 Q1294.74 1486.25 1288.93 1486.25 Q1283.12 1486.25 1280.04 1481.67 Q1276.99 1477.06 1276.99 1468.33 Q1276.99 1459.58 1280.04 1455 Q1283.12 1450.39 1288.93 1450.39 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M1309.09 1479.7 L1313.98 1479.7 L1313.98 1485.58 L1309.09 1485.58 L1309.09 1479.7 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M1334.74 1466.44 Q1331.59 1466.44 1329.74 1468.59 Q1327.91 1470.74 1327.91 1474.49 Q1327.91 1478.22 1329.74 1480.39 Q1331.59 1482.55 1334.74 1482.55 Q1337.89 1482.55 1339.72 1480.39 Q1341.57 1478.22 1341.57 1474.49 Q1341.57 1470.74 1339.72 1468.59 Q1337.89 1466.44 1334.74 1466.44 M1344.02 1451.78 L1344.02 1456.04 Q1342.26 1455.21 1340.46 1454.77 Q1338.68 1454.33 1336.92 1454.33 Q1332.29 1454.33 1329.83 1457.45 Q1327.4 1460.58 1327.06 1466.9 Q1328.42 1464.89 1330.48 1463.82 Q1332.54 1462.73 1335.02 1462.73 Q1340.23 1462.73 1343.24 1465.9 Q1346.27 1469.05 1346.27 1474.49 Q1346.27 1479.82 1343.12 1483.03 Q1339.97 1486.25 1334.74 1486.25 Q1328.75 1486.25 1325.58 1481.67 Q1322.4 1477.06 1322.4 1468.33 Q1322.4 1460.14 1326.29 1455.28 Q1330.18 1450.39 1336.73 1450.39 Q1338.49 1450.39 1340.27 1450.74 Q1342.08 1451.09 1344.02 1451.78 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M1782.56 1454.1 Q1778.95 1454.1 1777.12 1457.66 Q1775.31 1461.2 1775.31 1468.33 Q1775.31 1475.44 1777.12 1479.01 Q1778.95 1482.55 1782.56 1482.55 Q1786.19 1482.55 1788 1479.01 Q1789.83 1475.44 1789.83 1468.33 Q1789.83 1461.2 1788 1457.66 Q1786.19 1454.1 1782.56 1454.1 M1782.56 1450.39 Q1788.37 1450.39 1791.43 1455 Q1794.5 1459.58 1794.5 1468.33 Q1794.5 1477.06 1791.43 1481.67 Q1788.37 1486.25 1782.56 1486.25 Q1776.75 1486.25 1773.67 1481.67 Q1770.62 1477.06 1770.62 1468.33 Q1770.62 1459.58 1773.67 1455 Q1776.75 1450.39 1782.56 1450.39 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M1802.72 1479.7 L1807.61 1479.7 L1807.61 1485.58 L1802.72 1485.58 L1802.72 1479.7 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M1827.79 1469.17 Q1824.46 1469.17 1822.54 1470.95 Q1820.64 1472.73 1820.64 1475.86 Q1820.64 1478.98 1822.54 1480.77 Q1824.46 1482.55 1827.79 1482.55 Q1831.12 1482.55 1833.05 1480.77 Q1834.97 1478.96 1834.97 1475.86 Q1834.97 1472.73 1833.05 1470.95 Q1831.15 1469.17 1827.79 1469.17 M1823.12 1467.18 Q1820.11 1466.44 1818.42 1464.38 Q1816.75 1462.32 1816.75 1459.35 Q1816.75 1455.21 1819.69 1452.8 Q1822.65 1450.39 1827.79 1450.39 Q1832.95 1450.39 1835.89 1452.8 Q1838.83 1455.21 1838.83 1459.35 Q1838.83 1462.32 1837.14 1464.38 Q1835.48 1466.44 1832.49 1467.18 Q1835.87 1467.96 1837.75 1470.26 Q1839.64 1472.55 1839.64 1475.86 Q1839.64 1480.88 1836.56 1483.57 Q1833.51 1486.25 1827.79 1486.25 Q1822.07 1486.25 1819 1483.57 Q1815.94 1480.88 1815.94 1475.86 Q1815.94 1472.55 1817.84 1470.26 Q1819.74 1467.96 1823.12 1467.18 M1821.4 1459.79 Q1821.4 1462.48 1823.07 1463.98 Q1824.76 1465.49 1827.79 1465.49 Q1830.8 1465.49 1832.49 1463.98 Q1834.2 1462.48 1834.2 1459.79 Q1834.2 1457.11 1832.49 1455.6 Q1830.8 1454.1 1827.79 1454.1 Q1824.76 1454.1 1823.07 1455.6 Q1821.4 1457.11 1821.4 1459.79 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M2265.78 1481.64 L2273.42 1481.64 L2273.42 1455.28 L2265.11 1456.95 L2265.11 1452.69 L2273.38 1451.02 L2278.05 1451.02 L2278.05 1481.64 L2285.69 1481.64 L2285.69 1485.58 L2265.78 1485.58 L2265.78 1481.64 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M2295.14 1479.7 L2300.02 1479.7 L2300.02 1485.58 L2295.14 1485.58 L2295.14 1479.7 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M2320.2 1454.1 Q2316.59 1454.1 2314.76 1457.66 Q2312.96 1461.2 2312.96 1468.33 Q2312.96 1475.44 2314.76 1479.01 Q2316.59 1482.55 2320.2 1482.55 Q2323.84 1482.55 2325.64 1479.01 Q2327.47 1475.44 2327.47 1468.33 Q2327.47 1461.2 2325.64 1457.66 Q2323.84 1454.1 2320.2 1454.1 M2320.2 1450.39 Q2326.01 1450.39 2329.07 1455 Q2332.15 1459.58 2332.15 1468.33 Q2332.15 1477.06 2329.07 1481.67 Q2326.01 1486.25 2320.2 1486.25 Q2314.39 1486.25 2311.32 1481.67 Q2308.26 1477.06 2308.26 1468.33 Q2308.26 1459.58 2311.32 1455 Q2314.39 1450.39 2320.2 1450.39 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M1159.81 1533.45 L1159.81 1538.98 Q1157.33 1537.71 1154.65 1537.07 Q1151.98 1536.44 1149.11 1536.44 Q1144.75 1536.44 1142.56 1537.77 Q1140.39 1539.11 1140.39 1541.79 Q1140.39 1543.82 1141.95 1545 Q1143.51 1546.15 1148.22 1547.2 L1150.23 1547.64 Q1156.47 1548.98 1159.08 1551.43 Q1161.72 1553.85 1161.72 1558.21 Q1161.72 1563.17 1157.77 1566.07 Q1153.86 1568.97 1146.98 1568.97 Q1144.12 1568.97 1141 1568.39 Q1137.91 1567.85 1134.47 1566.74 L1134.47 1560.69 Q1137.72 1562.38 1140.87 1563.24 Q1144.02 1564.07 1147.11 1564.07 Q1151.25 1564.07 1153.47 1562.66 Q1155.7 1561.23 1155.7 1558.65 Q1155.7 1556.27 1154.08 1554.99 Q1152.49 1553.72 1147.05 1552.54 L1145.01 1552.07 Q1139.57 1550.92 1137.15 1548.56 Q1134.73 1546.18 1134.73 1542.04 Q1134.73 1537.01 1138.29 1534.27 Q1141.86 1531.54 1148.41 1531.54 Q1151.66 1531.54 1154.53 1532.01 Q1157.39 1532.49 1159.81 1533.45 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M1191.22 1518.52 L1204.72 1518.52 L1204.72 1523.07 L1197.08 1523.07 L1197.08 1572.09 L1204.72 1572.09 L1204.72 1576.64 L1191.22 1576.64 L1191.22 1518.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M1216.97 1518.52 L1222.86 1518.52 L1222.86 1547.77 L1240.33 1532.4 L1247.81 1532.4 L1228.91 1549.07 L1248.61 1568.04 L1240.97 1568.04 L1222.86 1550.63 L1222.86 1568.04 L1216.97 1568.04 L1216.97 1518.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M1255.2 1520.52 L1261.63 1520.52 L1261.63 1564.73 Q1261.63 1573.33 1258.35 1577.21 Q1255.1 1581.09 1247.88 1581.09 L1245.43 1581.09 L1245.43 1575.68 L1247.43 1575.68 Q1251.7 1575.68 1253.45 1573.3 Q1255.2 1570.91 1255.2 1564.73 L1255.2 1520.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M1284.58 1520.52 L1289.99 1520.52 L1273.44 1574.09 L1268.03 1574.09 L1284.58 1520.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M1295.91 1518.52 L1301.8 1518.52 L1301.8 1547.77 L1319.27 1532.4 L1326.75 1532.4 L1307.84 1549.07 L1327.54 1568.04 L1319.91 1568.04 L1301.8 1550.63 L1301.8 1568.04 L1295.91 1568.04 L1295.91 1518.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M1357.34 1549.81 Q1357.34 1543.44 1354.69 1539.94 Q1352.08 1536.44 1347.34 1536.44 Q1342.63 1536.44 1339.99 1539.94 Q1337.38 1543.44 1337.38 1549.81 Q1337.38 1556.14 1339.99 1559.64 Q1342.63 1563.14 1347.34 1563.14 Q1352.08 1563.14 1354.69 1559.64 Q1357.34 1556.14 1357.34 1549.81 M1363.19 1563.62 Q1363.19 1572.72 1359.15 1577.15 Q1355.11 1581.6 1346.77 1581.6 Q1343.68 1581.6 1340.94 1581.13 Q1338.21 1580.68 1335.63 1579.72 L1335.63 1574.03 Q1338.21 1575.43 1340.72 1576.1 Q1343.24 1576.76 1345.85 1576.76 Q1351.61 1576.76 1354.47 1573.74 Q1357.34 1570.75 1357.34 1564.67 L1357.34 1561.77 Q1355.52 1564.92 1352.69 1566.48 Q1349.86 1568.04 1345.91 1568.04 Q1339.35 1568.04 1335.34 1563.05 Q1331.33 1558.05 1331.33 1549.81 Q1331.33 1541.53 1335.34 1536.53 Q1339.35 1531.54 1345.91 1531.54 Q1349.86 1531.54 1352.69 1533.1 Q1355.52 1534.66 1357.34 1537.81 L1357.34 1532.4 L1363.19 1532.4 L1363.19 1563.62 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M1376.08 1559.96 L1382.8 1559.96 L1382.8 1568.04 L1376.08 1568.04 L1376.08 1559.96 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M1396.23 1520.52 L1402.66 1520.52 L1402.66 1540.61 L1423.99 1520.52 L1432.26 1520.52 L1408.68 1542.68 L1433.95 1568.04 L1425.48 1568.04 L1402.66 1545.16 L1402.66 1568.04 L1396.23 1568.04 L1396.23 1520.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M1452.41 1518.52 L1452.41 1576.64 L1438.91 1576.64 L1438.91 1572.09 L1446.52 1572.09 L1446.52 1523.07 L1438.91 1523.07 L1438.91 1518.52 L1452.41 1518.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><polyline clip-path="url(#clip790)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="234.125,1423.18 234.125,47.2441 "/>
<polyline clip-path="url(#clip790)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="234.125,1256.66 253.023,1256.66 "/>
<polyline clip-path="url(#clip790)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="234.125,1008.17 253.023,1008.17 "/>
<polyline clip-path="url(#clip790)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="234.125,759.693 253.023,759.693 "/>
<polyline clip-path="url(#clip790)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="234.125,511.212 253.023,511.212 "/>
<polyline clip-path="url(#clip790)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="234.125,262.731 253.023,262.731 "/>
<path clip-path="url(#clip790)" d="M119.885 1270 L136.204 1270 L136.204 1273.94 L114.26 1273.94 L114.26 1270 Q116.922 1267.25 121.505 1262.62 Q126.112 1257.96 127.292 1256.62 Q129.538 1254.1 130.417 1252.36 Q131.32 1250.6 131.32 1248.91 Q131.32 1246.16 129.376 1244.42 Q127.455 1242.69 124.353 1242.69 Q122.154 1242.69 119.7 1243.45 Q117.269 1244.21 114.492 1245.76 L114.492 1241.04 Q117.316 1239.91 119.769 1239.33 Q122.223 1238.75 124.26 1238.75 Q129.63 1238.75 132.825 1241.44 Q136.019 1244.12 136.019 1248.61 Q136.019 1250.74 135.209 1252.66 Q134.422 1254.56 132.316 1257.15 Q131.737 1257.82 128.635 1261.04 Q125.533 1264.24 119.885 1270 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M156.019 1257.52 Q152.686 1257.52 150.765 1259.31 Q148.866 1261.09 148.866 1264.21 Q148.866 1267.34 150.765 1269.12 Q152.686 1270.9 156.019 1270.9 Q159.353 1270.9 161.274 1269.12 Q163.195 1267.31 163.195 1264.21 Q163.195 1261.09 161.274 1259.31 Q159.376 1257.52 156.019 1257.52 M151.343 1255.53 Q148.334 1254.79 146.644 1252.73 Q144.978 1250.67 144.978 1247.71 Q144.978 1243.56 147.917 1241.16 Q150.88 1238.75 156.019 1238.75 Q161.181 1238.75 164.121 1241.16 Q167.061 1243.56 167.061 1247.71 Q167.061 1250.67 165.371 1252.73 Q163.704 1254.79 160.718 1255.53 Q164.098 1256.32 165.973 1258.61 Q167.871 1260.9 167.871 1264.21 Q167.871 1269.24 164.792 1271.92 Q161.737 1274.61 156.019 1274.61 Q150.302 1274.61 147.223 1271.92 Q144.167 1269.24 144.167 1264.21 Q144.167 1260.9 146.066 1258.61 Q147.964 1256.32 151.343 1255.53 M149.63 1248.15 Q149.63 1250.83 151.297 1252.34 Q152.987 1253.84 156.019 1253.84 Q159.028 1253.84 160.718 1252.34 Q162.431 1250.83 162.431 1248.15 Q162.431 1245.46 160.718 1243.96 Q159.028 1242.45 156.019 1242.45 Q152.987 1242.45 151.297 1243.96 Q149.63 1245.46 149.63 1248.15 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M186.181 1242.45 Q182.57 1242.45 180.741 1246.02 Q178.936 1249.56 178.936 1256.69 Q178.936 1263.8 180.741 1267.36 Q182.57 1270.9 186.181 1270.9 Q189.815 1270.9 191.621 1267.36 Q193.45 1263.8 193.45 1256.69 Q193.45 1249.56 191.621 1246.02 Q189.815 1242.45 186.181 1242.45 M186.181 1238.75 Q191.991 1238.75 195.047 1243.36 Q198.125 1247.94 198.125 1256.69 Q198.125 1265.42 195.047 1270.02 Q191.991 1274.61 186.181 1274.61 Q180.371 1274.61 177.292 1270.02 Q174.237 1265.42 174.237 1256.69 Q174.237 1247.94 177.292 1243.36 Q180.371 1238.75 186.181 1238.75 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M130.024 1006.82 Q133.38 1007.54 135.255 1009.81 Q137.154 1012.07 137.154 1015.41 Q137.154 1020.52 133.635 1023.32 Q130.117 1026.13 123.635 1026.13 Q121.459 1026.13 119.144 1025.69 Q116.853 1025.27 114.399 1024.41 L114.399 1019.9 Q116.343 1021.03 118.658 1021.61 Q120.973 1022.19 123.496 1022.19 Q127.894 1022.19 130.186 1020.45 Q132.501 1018.72 132.501 1015.41 Q132.501 1012.35 130.348 1010.64 Q128.218 1008.9 124.399 1008.9 L120.371 1008.9 L120.371 1005.06 L124.584 1005.06 Q128.033 1005.06 129.862 1003.69 Q131.691 1002.31 131.691 999.714 Q131.691 997.051 129.792 995.639 Q127.917 994.204 124.399 994.204 Q122.478 994.204 120.279 994.621 Q118.08 995.038 115.441 995.917 L115.441 991.751 Q118.103 991.01 120.418 990.639 Q122.755 990.269 124.816 990.269 Q130.14 990.269 133.242 992.7 Q136.343 995.107 136.343 999.227 Q136.343 1002.1 134.7 1004.09 Q133.056 1006.06 130.024 1006.82 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M156.019 993.973 Q152.408 993.973 150.579 997.538 Q148.774 1001.08 148.774 1008.21 Q148.774 1015.32 150.579 1018.88 Q152.408 1022.42 156.019 1022.42 Q159.653 1022.42 161.459 1018.88 Q163.288 1015.32 163.288 1008.21 Q163.288 1001.08 161.459 997.538 Q159.653 993.973 156.019 993.973 M156.019 990.269 Q161.829 990.269 164.885 994.876 Q167.964 999.459 167.964 1008.21 Q167.964 1016.94 164.885 1021.54 Q161.829 1026.13 156.019 1026.13 Q150.209 1026.13 147.13 1021.54 Q144.075 1016.94 144.075 1008.21 Q144.075 999.459 147.13 994.876 Q150.209 990.269 156.019 990.269 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M186.181 993.973 Q182.57 993.973 180.741 997.538 Q178.936 1001.08 178.936 1008.21 Q178.936 1015.32 180.741 1018.88 Q182.57 1022.42 186.181 1022.42 Q189.815 1022.42 191.621 1018.88 Q193.45 1015.32 193.45 1008.21 Q193.45 1001.08 191.621 997.538 Q189.815 993.973 186.181 993.973 M186.181 990.269 Q191.991 990.269 195.047 994.876 Q198.125 999.459 198.125 1008.21 Q198.125 1016.94 195.047 1021.54 Q191.991 1026.13 186.181 1026.13 Q180.371 1026.13 177.292 1021.54 Q174.237 1016.94 174.237 1008.21 Q174.237 999.459 177.292 994.876 Q180.371 990.269 186.181 990.269 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M130.024 758.339 Q133.38 759.057 135.255 761.325 Q137.154 763.594 137.154 766.927 Q137.154 772.043 133.635 774.844 Q130.117 777.644 123.635 777.644 Q121.459 777.644 119.144 777.205 Q116.853 776.788 114.399 775.932 L114.399 771.418 Q116.343 772.552 118.658 773.131 Q120.973 773.709 123.496 773.709 Q127.894 773.709 130.186 771.973 Q132.501 770.237 132.501 766.927 Q132.501 763.871 130.348 762.158 Q128.218 760.422 124.399 760.422 L120.371 760.422 L120.371 756.58 L124.584 756.58 Q128.033 756.58 129.862 755.214 Q131.691 753.825 131.691 751.233 Q131.691 748.571 129.792 747.159 Q127.917 745.723 124.399 745.723 Q122.478 745.723 120.279 746.14 Q118.08 746.557 115.441 747.436 L115.441 743.27 Q118.103 742.529 120.418 742.159 Q122.755 741.788 124.816 741.788 Q130.14 741.788 133.242 744.219 Q136.343 746.626 136.343 750.746 Q136.343 753.617 134.7 755.608 Q133.056 757.575 130.024 758.339 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M150.047 773.038 L166.366 773.038 L166.366 776.973 L144.422 776.973 L144.422 773.038 Q147.084 770.283 151.667 765.654 Q156.274 761.001 157.454 759.658 Q159.7 757.135 160.579 755.399 Q161.482 753.64 161.482 751.95 Q161.482 749.196 159.538 747.459 Q157.616 745.723 154.515 745.723 Q152.316 745.723 149.862 746.487 Q147.431 747.251 144.654 748.802 L144.654 744.08 Q147.478 742.946 149.931 742.367 Q152.385 741.788 154.422 741.788 Q159.792 741.788 162.987 744.473 Q166.181 747.159 166.181 751.649 Q166.181 753.779 165.371 755.7 Q164.584 757.598 162.477 760.191 Q161.899 760.862 158.797 764.08 Q155.695 767.274 150.047 773.038 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M186.181 745.492 Q182.57 745.492 180.741 749.057 Q178.936 752.598 178.936 759.728 Q178.936 766.834 180.741 770.399 Q182.57 773.941 186.181 773.941 Q189.815 773.941 191.621 770.399 Q193.45 766.834 193.45 759.728 Q193.45 752.598 191.621 749.057 Q189.815 745.492 186.181 745.492 M186.181 741.788 Q191.991 741.788 195.047 746.395 Q198.125 750.978 198.125 759.728 Q198.125 768.455 195.047 773.061 Q191.991 777.644 186.181 777.644 Q180.371 777.644 177.292 773.061 Q174.237 768.455 174.237 759.728 Q174.237 750.978 177.292 746.395 Q180.371 741.788 186.181 741.788 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M130.024 509.858 Q133.38 510.576 135.255 512.844 Q137.154 515.113 137.154 518.446 Q137.154 523.562 133.635 526.363 Q130.117 529.164 123.635 529.164 Q121.459 529.164 119.144 528.724 Q116.853 528.307 114.399 527.451 L114.399 522.937 Q116.343 524.071 118.658 524.65 Q120.973 525.228 123.496 525.228 Q127.894 525.228 130.186 523.492 Q132.501 521.756 132.501 518.446 Q132.501 515.39 130.348 513.678 Q128.218 511.941 124.399 511.941 L120.371 511.941 L120.371 508.099 L124.584 508.099 Q128.033 508.099 129.862 506.733 Q131.691 505.344 131.691 502.752 Q131.691 500.09 129.792 498.678 Q127.917 497.242 124.399 497.242 Q122.478 497.242 120.279 497.659 Q118.08 498.076 115.441 498.955 L115.441 494.789 Q118.103 494.048 120.418 493.678 Q122.755 493.307 124.816 493.307 Q130.14 493.307 133.242 495.738 Q136.343 498.145 136.343 502.266 Q136.343 505.136 134.7 507.127 Q133.056 509.094 130.024 509.858 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M158.866 498.006 L147.061 516.455 L158.866 516.455 L158.866 498.006 M157.64 493.932 L163.519 493.932 L163.519 516.455 L168.45 516.455 L168.45 520.344 L163.519 520.344 L163.519 528.492 L158.866 528.492 L158.866 520.344 L143.265 520.344 L143.265 515.83 L157.64 493.932 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M186.181 497.011 Q182.57 497.011 180.741 500.576 Q178.936 504.117 178.936 511.247 Q178.936 518.353 180.741 521.918 Q182.57 525.46 186.181 525.46 Q189.815 525.46 191.621 521.918 Q193.45 518.353 193.45 511.247 Q193.45 504.117 191.621 500.576 Q189.815 497.011 186.181 497.011 M186.181 493.307 Q191.991 493.307 195.047 497.914 Q198.125 502.497 198.125 511.247 Q198.125 519.974 195.047 524.58 Q191.991 529.164 186.181 529.164 Q180.371 529.164 177.292 524.58 Q174.237 519.974 174.237 511.247 Q174.237 502.497 177.292 497.914 Q180.371 493.307 186.181 493.307 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M130.024 261.377 Q133.38 262.095 135.255 264.363 Q137.154 266.632 137.154 269.965 Q137.154 275.081 133.635 277.882 Q130.117 280.683 123.635 280.683 Q121.459 280.683 119.144 280.243 Q116.853 279.826 114.399 278.97 L114.399 274.456 Q116.343 275.59 118.658 276.169 Q120.973 276.747 123.496 276.747 Q127.894 276.747 130.186 275.011 Q132.501 273.275 132.501 269.965 Q132.501 266.91 130.348 265.197 Q128.218 263.461 124.399 263.461 L120.371 263.461 L120.371 259.618 L124.584 259.618 Q128.033 259.618 129.862 258.252 Q131.691 256.863 131.691 254.271 Q131.691 251.609 129.792 250.197 Q127.917 248.762 124.399 248.762 Q122.478 248.762 120.279 249.178 Q118.08 249.595 115.441 250.474 L115.441 246.308 Q118.103 245.567 120.418 245.197 Q122.755 244.826 124.816 244.826 Q130.14 244.826 133.242 247.257 Q136.343 249.664 136.343 253.785 Q136.343 256.655 134.7 258.646 Q133.056 260.613 130.024 261.377 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M156.598 260.868 Q153.45 260.868 151.598 263.021 Q149.769 265.173 149.769 268.923 Q149.769 272.65 151.598 274.826 Q153.45 276.979 156.598 276.979 Q159.746 276.979 161.575 274.826 Q163.427 272.65 163.427 268.923 Q163.427 265.173 161.575 263.021 Q159.746 260.868 156.598 260.868 M165.88 246.215 L165.88 250.474 Q164.121 249.641 162.315 249.201 Q160.533 248.762 158.774 248.762 Q154.144 248.762 151.691 251.887 Q149.26 255.011 148.913 261.331 Q150.278 259.317 152.339 258.252 Q154.399 257.164 156.876 257.164 Q162.084 257.164 165.093 260.336 Q168.126 263.484 168.126 268.923 Q168.126 274.248 164.977 277.465 Q161.829 280.683 156.598 280.683 Q150.603 280.683 147.431 276.099 Q144.26 271.493 144.26 262.766 Q144.26 254.572 148.149 249.711 Q152.038 244.826 158.589 244.826 Q160.348 244.826 162.13 245.174 Q163.936 245.521 165.88 246.215 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M186.181 248.53 Q182.57 248.53 180.741 252.095 Q178.936 255.636 178.936 262.766 Q178.936 269.873 180.741 273.437 Q182.57 276.979 186.181 276.979 Q189.815 276.979 191.621 273.437 Q193.45 269.873 193.45 262.766 Q193.45 255.636 191.621 252.095 Q189.815 248.53 186.181 248.53 M186.181 244.826 Q191.991 244.826 195.047 249.433 Q198.125 254.016 198.125 262.766 Q198.125 271.493 195.047 276.099 Q191.991 280.683 186.181 280.683 Q180.371 280.683 177.292 276.099 Q174.237 271.493 174.237 262.766 Q174.237 254.016 177.292 249.433 Q180.371 244.826 186.181 244.826 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M16.4842 809.579 L16.4842 769.38 L21.895 769.38 L21.895 786.249 L64.0042 786.249 L64.0042 792.71 L21.895 792.71 L21.895 809.579 L16.4842 809.579 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M14.479 743.249 L14.479 729.753 L19.0304 729.753 L19.0304 737.392 L68.0464 737.392 L68.0464 729.753 L72.5979 729.753 L72.5979 743.249 L14.479 743.249 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M16.4842 717.022 L16.4842 710.593 L36.568 710.593 L16.4842 689.267 L16.4842 680.992 L38.6368 704.577 L64.0042 679.305 L64.0042 687.772 L41.1194 710.593 L64.0042 710.593 L64.0042 717.022 L16.4842 717.022 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M14.479 660.845 L72.5979 660.845 L72.5979 674.34 L68.0464 674.34 L68.0464 666.733 L19.0304 666.733 L19.0304 674.34 L14.479 674.34 L14.479 660.845 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><polyline clip-path="url(#clip792)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:0.4; fill:none" points="294.087,1384.24 455.622,1216.93 603.172,1061.17 738.202,916.939 861.9,784.25 975.237,663.098 1079.01,553.485 1173.89,455.41 1260.44,368.873 1339.2,293.874 1410.69,230.414 1475.5,178.492 1534.48,138.108 1589.16,109.262 1644.34,91.9548 1722.44,86.1857 1786.46,91.9548 1857.21,109.262 1913.78,138.108 1951.22,178.492 1982.75,230.414 2009.18,293.874 2031.09,368.873 2049.04,455.41 2063.61,553.485 2075.52,663.098 2085.61,784.25 2094.94,916.939 2104.88,1061.17 2117.22,1216.93 2134.42,1384.24 "/>
<polyline clip-path="url(#clip792)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1021.13,1146.27 2111.3,1146.27 "/>
<polyline clip-path="url(#clip792)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:0.5; fill:none" stroke-dasharray="16, 10" points="2111.3,1146.27 2111.3,608.3 "/>
<polyline clip-path="url(#clip792)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2111.3,1146.27 2153.06,551.356 "/>
<polyline clip-path="url(#clip792)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2153.06,551.356 2074.8,655.543 982.34,655.543 "/>
<polyline clip-path="url(#clip792)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="982.34,655.543 992.036,874.412 1001.73,988.932 1011.43,1075.14 1021.13,1146.27 "/>
<polyline clip-path="url(#clip792)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:0.4; fill:none" points="522.84,1146.27 2111.3,1146.27 2179.35,1042.16 2244.59,938.051 "/>
<polyline clip-path="url(#clip792)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:0.4; fill:none" points="982.34,655.543 2074.8,655.543 2153.02,551.407 2224.93,447.271 2292.79,343.135 "/>
<path clip-path="url(#clip790)" d="M952.19 1182.69 L952.19 1122.27 L998.92 1122.27 L998.92 1182.69 L952.19 1182.69 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M997.762 1182.69 L997.762 1122.27 L1044.49 1122.27 L1044.49 1182.69 L997.762 1182.69 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M1043.33 1182.69 L1043.33 1122.27 L1090.06 1122.27 L1090.06 1182.69 L1043.33 1182.69 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M993.407 1138.39 L993.407 1142.42 Q991.602 1141.49 989.658 1141.03 Q987.713 1140.57 985.63 1140.57 Q982.458 1140.57 980.861 1141.54 Q979.287 1142.51 979.287 1144.45 Q979.287 1145.94 980.421 1146.79 Q981.556 1147.63 984.982 1148.39 L986.44 1148.71 Q990.977 1149.69 992.875 1151.47 Q994.796 1153.23 994.796 1156.4 Q994.796 1160.01 991.926 1162.12 Q989.079 1164.22 984.079 1164.22 Q981.996 1164.22 979.727 1163.81 Q977.482 1163.41 974.982 1162.6 L974.982 1158.2 Q977.343 1159.43 979.634 1160.06 Q981.926 1160.66 984.171 1160.66 Q987.181 1160.66 988.801 1159.64 Q990.421 1158.6 990.421 1156.72 Q990.421 1154.99 989.241 1154.06 Q988.083 1153.14 984.125 1152.28 L982.644 1151.93 Q978.685 1151.1 976.926 1149.39 Q975.167 1147.65 975.167 1144.64 Q975.167 1140.98 977.759 1138.99 Q980.352 1137 985.121 1137 Q987.482 1137 989.565 1137.35 Q991.648 1137.7 993.407 1138.39 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M1005.79 1130.26 L1005.79 1137.63 L1014.56 1137.63 L1014.56 1140.94 L1005.79 1140.94 L1005.79 1155.01 Q1005.79 1158.18 1006.65 1159.08 Q1007.53 1159.99 1010.19 1159.99 L1014.56 1159.99 L1014.56 1163.55 L1010.19 1163.55 Q1005.26 1163.55 1003.38 1161.72 Q1001.51 1159.87 1001.51 1155.01 L1001.51 1140.94 L998.384 1140.94 L998.384 1137.63 L1001.51 1137.63 L1001.51 1130.26 L1005.79 1130.26 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M1025.03 1132.83 L1025.03 1159.71 L1030.68 1159.71 Q1037.83 1159.71 1041.14 1156.47 Q1044.47 1153.23 1044.47 1146.24 Q1044.47 1139.29 1041.14 1136.08 Q1037.83 1132.83 1030.68 1132.83 L1025.03 1132.83 M1020.35 1128.99 L1029.96 1128.99 Q1040 1128.99 1044.7 1133.18 Q1049.4 1137.35 1049.4 1146.24 Q1049.4 1155.17 1044.68 1159.36 Q1039.96 1163.55 1029.96 1163.55 L1020.35 1163.55 L1020.35 1128.99 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M2065.15 1182.69 L2065.15 1122.27 L2111.88 1122.27 L2111.88 1182.69 L2065.15 1182.69 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M2110.72 1182.69 L2110.72 1122.27 L2157.45 1122.27 L2157.45 1182.69 L2110.72 1182.69 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M2093.35 1138.39 L2093.35 1142.42 Q2091.54 1141.49 2089.6 1141.03 Q2087.65 1140.57 2085.57 1140.57 Q2082.4 1140.57 2080.8 1141.54 Q2079.23 1142.51 2079.23 1144.45 Q2079.23 1145.94 2080.36 1146.79 Q2081.49 1147.63 2084.92 1148.39 L2086.38 1148.71 Q2090.92 1149.69 2092.81 1151.47 Q2094.74 1153.23 2094.74 1156.4 Q2094.74 1160.01 2091.87 1162.12 Q2089.02 1164.22 2084.02 1164.22 Q2081.93 1164.22 2079.67 1163.81 Q2077.42 1163.41 2074.92 1162.6 L2074.92 1158.2 Q2077.28 1159.43 2079.57 1160.06 Q2081.87 1160.66 2084.11 1160.66 Q2087.12 1160.66 2088.74 1159.64 Q2090.36 1158.6 2090.36 1156.72 Q2090.36 1154.99 2089.18 1154.06 Q2088.02 1153.14 2084.06 1152.28 L2082.58 1151.93 Q2078.62 1151.1 2076.87 1149.39 Q2075.11 1147.65 2075.11 1144.64 Q2075.11 1140.98 2077.7 1138.99 Q2080.29 1137 2085.06 1137 Q2087.42 1137 2089.5 1137.35 Q2091.59 1137.7 2093.35 1138.39 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M2105.73 1130.26 L2105.73 1137.63 L2114.5 1137.63 L2114.5 1140.94 L2105.73 1140.94 L2105.73 1155.01 Q2105.73 1158.18 2106.59 1159.08 Q2107.47 1159.99 2110.13 1159.99 L2114.5 1159.99 L2114.5 1163.55 L2110.13 1163.55 Q2105.2 1163.55 2103.32 1161.72 Q2101.45 1159.87 2101.45 1155.01 L2101.45 1140.94 L2098.32 1140.94 L2098.32 1137.63 L2101.45 1137.63 L2101.45 1130.26 L2105.73 1130.26 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M2131.84 1133.6 L2125.5 1150.8 L2138.21 1150.8 L2131.84 1133.6 M2129.2 1128.99 L2134.5 1128.99 L2147.68 1163.55 L2142.81 1163.55 L2139.67 1154.69 L2124.09 1154.69 L2120.94 1163.55 L2116.01 1163.55 L2129.2 1128.99 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M2106.91 587.771 L2106.91 527.354 L2153.64 527.354 L2153.64 587.771 L2106.91 587.771 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M2152.48 587.771 L2152.48 527.354 L2199.21 527.354 L2199.21 587.771 L2152.48 587.771 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M2136.54 543.474 L2136.54 547.502 Q2134.73 546.576 2132.79 546.113 Q2130.85 545.65 2128.76 545.65 Q2125.59 545.65 2123.99 546.622 Q2122.42 547.594 2122.42 549.539 Q2122.42 551.02 2123.55 551.877 Q2124.69 552.71 2128.11 553.474 L2129.57 553.798 Q2134.11 554.77 2136.01 556.553 Q2137.93 558.312 2137.93 561.483 Q2137.93 565.094 2135.06 567.201 Q2132.21 569.307 2127.21 569.307 Q2125.13 569.307 2122.86 568.89 Q2120.61 568.497 2118.11 567.687 L2118.11 563.289 Q2120.48 564.515 2122.77 565.14 Q2125.06 565.742 2127.3 565.742 Q2130.31 565.742 2131.93 564.724 Q2133.55 563.682 2133.55 561.807 Q2133.55 560.071 2132.37 559.145 Q2131.22 558.219 2127.26 557.363 L2125.78 557.016 Q2121.82 556.182 2120.06 554.469 Q2118.3 552.733 2118.3 549.724 Q2118.3 546.066 2120.89 544.076 Q2123.49 542.085 2128.25 542.085 Q2130.61 542.085 2132.7 542.432 Q2134.78 542.779 2136.54 543.474 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M2148.92 535.349 L2148.92 542.71 L2157.7 542.71 L2157.7 546.02 L2148.92 546.02 L2148.92 560.094 Q2148.92 563.265 2149.78 564.168 Q2150.66 565.071 2153.32 565.071 L2157.7 565.071 L2157.7 568.636 L2153.32 568.636 Q2148.39 568.636 2146.52 566.807 Q2144.64 564.955 2144.64 560.094 L2144.64 546.02 L2141.52 546.02 L2141.52 542.71 L2144.64 542.71 L2144.64 535.349 L2148.92 535.349 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M2168.16 552.131 L2168.16 564.793 L2175.66 564.793 Q2179.43 564.793 2181.24 563.242 Q2183.07 561.668 2183.07 558.451 Q2183.07 555.21 2181.24 553.682 Q2179.43 552.131 2175.66 552.131 L2168.16 552.131 M2168.16 537.918 L2168.16 548.335 L2175.08 548.335 Q2178.51 548.335 2180.17 547.062 Q2181.86 545.766 2181.86 543.127 Q2181.86 540.511 2180.17 539.215 Q2178.51 537.918 2175.08 537.918 L2168.16 537.918 M2163.48 534.076 L2175.43 534.076 Q2180.78 534.076 2183.67 536.298 Q2186.56 538.52 2186.56 542.617 Q2186.56 545.789 2185.08 547.664 Q2183.6 549.539 2180.73 550.002 Q2184.18 550.742 2186.08 553.103 Q2188 555.441 2188 558.96 Q2188 563.59 2184.85 566.113 Q2181.7 568.636 2175.89 568.636 L2163.48 568.636 L2163.48 534.076 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M936.188 691.958 L936.188 631.542 L982.918 631.542 L982.918 691.958 L936.188 691.958 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M981.761 691.958 L981.761 631.542 L1028.49 631.542 L1028.49 691.958 L981.761 691.958 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M965.141 647.661 L965.141 651.689 Q963.335 650.763 961.391 650.3 Q959.446 649.837 957.363 649.837 Q954.192 649.837 952.594 650.809 Q951.02 651.782 951.02 653.726 Q951.02 655.208 952.155 656.064 Q953.289 656.897 956.715 657.661 L958.173 657.985 Q962.71 658.958 964.608 660.74 Q966.529 662.499 966.529 665.67 Q966.529 669.282 963.659 671.388 Q960.812 673.494 955.812 673.494 Q953.729 673.494 951.46 673.078 Q949.215 672.684 946.715 671.874 L946.715 667.476 Q949.076 668.703 951.368 669.328 Q953.659 669.93 955.905 669.93 Q958.914 669.93 960.534 668.911 Q962.154 667.87 962.154 665.995 Q962.154 664.258 960.974 663.333 Q959.817 662.407 955.858 661.55 L954.377 661.203 Q950.418 660.37 948.659 658.657 Q946.9 656.92 946.9 653.911 Q946.9 650.254 949.493 648.263 Q952.085 646.272 956.854 646.272 Q959.215 646.272 961.298 646.62 Q963.381 646.967 965.141 647.661 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M977.525 639.536 L977.525 646.897 L986.298 646.897 L986.298 650.208 L977.525 650.208 L977.525 664.282 Q977.525 667.453 978.381 668.356 Q979.261 669.258 981.923 669.258 L986.298 669.258 L986.298 672.823 L981.923 672.823 Q976.992 672.823 975.117 670.994 Q973.242 669.143 973.242 664.282 L973.242 650.208 L970.117 650.208 L970.117 646.897 L973.242 646.897 L973.242 639.536 L977.525 639.536 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip790)" d="M1017.96 640.925 L1017.96 645.856 Q1015.6 643.657 1012.92 642.569 Q1010.26 641.481 1007.25 641.481 Q1001.32 641.481 998.173 645.115 Q995.025 648.726 995.025 655.578 Q995.025 662.407 998.173 666.041 Q1001.32 669.652 1007.25 669.652 Q1010.26 669.652 1012.92 668.564 Q1015.6 667.476 1017.96 665.277 L1017.96 670.161 Q1015.51 671.828 1012.76 672.661 Q1010.02 673.494 1006.97 673.494 Q999.122 673.494 994.608 668.703 Q990.094 663.888 990.094 655.578 Q990.094 647.245 994.608 642.453 Q999.122 637.638 1006.97 637.638 Q1010.07 637.638 1012.8 638.472 Q1015.56 639.282 1017.96 640.925 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /></svg>
</div><div style=' border: 1px solid;'><h3 style='text-align: center;margin: 8px;'>Cycle Properties:</h3><div style='display: flex; justify-content: space-around;'><div style = "display: inline-block; border: 1px solid #666666;"><!DOCTYPE html>
<html>
<meta charset="UTF-8">
<style>
  table, td, th {
      border-collapse: collapse; color: black;
      font-family: sans-serif;
  }

  td, th {
      border-bottom: 0;
      padding: 4px
  }

  tr:nth-child(odd) {
      background: #eee;
  }

  tr:nth-child(even) {
      background: #fff;
  }

  tr.header {
      background: #fff !important;
      font-weight: bold;
  }

  tr.subheader {
      background: #fff !important;
      color: dimgray;
  }

  tr.headerLastRow {
      border-bottom: 2px solid black;
  }

  th.rowNumber, td.rowNumber {
      text-align: right;
  }

</style>
<body>
<table>
  <thead>
    <tr class = "header headerLastRow">
      <th style = "color: black; text-align: center; padding: 11px; font-size: 130%;"></th>
      <th style = "color: black; text-align: center; padding: 11px; font-size: 130%;">Total</th>
      <th style = "color: black; text-align: center; padding: 11px; font-size: 130%;">Component</th>
      <th style = "color: black; text-align: center; padding: 11px; font-size: 130%;">Value</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">qin<BR>Q̇in</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">127.6324 kJ/kg<BR>466.2367 kW</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">evaporator_condenser:<BR>   [stD, st2] &gt;&gt; [stA, st3]</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">127.6324 kJ/kg<BR>466.2367 kW</td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">qout<BR>Q̇out</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">155.9332 kJ/kg<BR>569.6185 kW</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">condenser:<BR>   stB &gt;&gt; stC</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">155.9332 kJ/kg<BR>569.6185 kW</td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">win<BR>Ẇin</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">28.3008 kJ/kg<BR>103.3818 kW</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">compressor:<BR>   stA &gt;&gt; stB</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">28.3008 kJ/kg<BR>103.3818 kW</td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">wout<BR>Ẇout</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">0.0 kJ/kg<BR>0.0 kW</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;"></td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;"></td>
    </tr>
  </tbody>
</table>
</body>
</html>
</div></div><h3 style='text-align: center; border: 2px solid #666666; padding: 15px; margin: 10px;'>Coefficient of performance (COP) = 4.5099</h3></div>
</div></br><div style='display: inline-block; padding: 15px; margin: 20px;
        border: 2px solid #666666;'>
<h1 style='display: block; text-align: center; border: 1px solid #666666;margin: -17px; margin-bottom: 20px; padding: 10px'>2- REFRIGERATION  CYCLE [R134a]</h1><div style='display: flex; justify-content: space-around;'><div style = "display: inline-block; border: 1px solid #666666;"><!DOCTYPE html>
<html>
<meta charset="UTF-8">
<style>
  table, td, th {
      border-collapse: collapse; color: black;
      font-family: sans-serif;
  }

  td, th {
      border-bottom: 0;
      padding: 4px
  }

  tr:nth-child(odd) {
      background: #eee;
  }

  tr:nth-child(even) {
      background: #fff;
  }

  tr.header {
      background: #fff !important;
      font-weight: bold;
  }

  tr.subheader {
      background: #fff !important;
      color: dimgray;
  }

  tr.headerLastRow {
      border-bottom: 2px solid black;
  }

  th.rowNumber, td.rowNumber {
      text-align: right;
  }

</style>
<body>
<table>
  <thead>
    <tr class = "header headerLastRow">
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">State<br>Name</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">T [K]</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">P [kPa]</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">h [kJ/kg]</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">s [kJ/kg.K]</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">x</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">ṁ [kg/s]</th>
      <th style = "color: black; text-align: center; padding: 8px; font-size: 130%;">Mass-flux<br>fraction</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">st2</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">300.331</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">600.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">268.033</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">0.9407</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;"></td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">2.5</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1.0</td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">st3</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">294.722</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">600.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">81.5384</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">0.3081</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">0.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">2.5</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1.0</td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">st1</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">268.866</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">250.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">247.94</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">0.934</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">2.5</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1.0</td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">st4</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">268.866</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">250.0</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">81.5384</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">0.3151</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">0.1755</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">2.5</td>
      <td style = "text-align: left; padding: 8px; font-size: 130%;">1.0</td>
    </tr>
  </tbody>
</table>
</body>
</html>
</div></div><div style='display: flex; justify-content: space-around;
        padding: 10px; margin: 10px;'><?xml version="1.0" encoding="utf-8"?>
<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="600" height="400" viewBox="0 0 2400 1600">
<defs>
  <clipPath id="clip830">
    <rect x="0" y="0" width="2400" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip830)" d="M0 1600 L2400 1600 L2400 0 L0 0  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip831">
    <rect x="480" y="0" width="1681" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip830)" d="M233.987 1423.18 L2352.76 1423.18 L2352.76 47.2441 L233.987 47.2441  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip832">
    <rect x="233" y="47" width="2120" height="1377"/>
  </clipPath>
</defs>
<polyline clip-path="url(#clip830)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="233.987,1423.18 2352.76,1423.18 "/>
<polyline clip-path="url(#clip830)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="479.624,1423.18 479.624,1404.28 "/>
<polyline clip-path="url(#clip830)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="946.942,1423.18 946.942,1404.28 "/>
<polyline clip-path="url(#clip830)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1414.26,1423.18 1414.26,1404.28 "/>
<polyline clip-path="url(#clip830)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1881.58,1423.18 1881.58,1404.28 "/>
<polyline clip-path="url(#clip830)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2348.9,1423.18 2348.9,1404.28 "/>
<path clip-path="url(#clip830)" d="M457.807 1454.1 Q454.196 1454.1 452.367 1457.66 Q450.562 1461.2 450.562 1468.33 Q450.562 1475.44 452.367 1479.01 Q454.196 1482.55 457.807 1482.55 Q461.441 1482.55 463.247 1479.01 Q465.076 1475.44 465.076 1468.33 Q465.076 1461.2 463.247 1457.66 Q461.441 1454.1 457.807 1454.1 M457.807 1450.39 Q463.617 1450.39 466.673 1455 Q469.752 1459.58 469.752 1468.33 Q469.752 1477.06 466.673 1481.67 Q463.617 1486.25 457.807 1486.25 Q451.997 1486.25 448.918 1481.67 Q445.863 1477.06 445.863 1468.33 Q445.863 1459.58 448.918 1455 Q451.997 1450.39 457.807 1450.39 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M477.969 1479.7 L482.853 1479.7 L482.853 1485.58 L477.969 1485.58 L477.969 1479.7 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M497.066 1481.64 L513.386 1481.64 L513.386 1485.58 L491.441 1485.58 L491.441 1481.64 Q494.103 1478.89 498.687 1474.26 Q503.293 1469.61 504.474 1468.27 Q506.719 1465.74 507.599 1464.01 Q508.501 1462.25 508.501 1460.56 Q508.501 1457.8 506.557 1456.07 Q504.636 1454.33 501.534 1454.33 Q499.335 1454.33 496.881 1455.09 Q494.45 1455.86 491.673 1457.41 L491.673 1452.69 Q494.497 1451.55 496.95 1450.97 Q499.404 1450.39 501.441 1450.39 Q506.812 1450.39 510.006 1453.08 Q513.2 1455.77 513.2 1460.26 Q513.2 1462.39 512.39 1464.31 Q511.603 1466.2 509.497 1468.8 Q508.918 1469.47 505.816 1472.69 Q502.714 1475.88 497.066 1481.64 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M924.084 1454.1 Q920.473 1454.1 918.644 1457.66 Q916.838 1461.2 916.838 1468.33 Q916.838 1475.44 918.644 1479.01 Q920.473 1482.55 924.084 1482.55 Q927.718 1482.55 929.524 1479.01 Q931.352 1475.44 931.352 1468.33 Q931.352 1461.2 929.524 1457.66 Q927.718 1454.1 924.084 1454.1 M924.084 1450.39 Q929.894 1450.39 932.949 1455 Q936.028 1459.58 936.028 1468.33 Q936.028 1477.06 932.949 1481.67 Q929.894 1486.25 924.084 1486.25 Q918.274 1486.25 915.195 1481.67 Q912.139 1477.06 912.139 1468.33 Q912.139 1459.58 915.195 1455 Q918.274 1450.39 924.084 1450.39 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M944.246 1479.7 L949.13 1479.7 L949.13 1485.58 L944.246 1485.58 L944.246 1479.7 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M972.162 1455.09 L960.357 1473.54 L972.162 1473.54 L972.162 1455.09 M970.935 1451.02 L976.815 1451.02 L976.815 1473.54 L981.745 1473.54 L981.745 1477.43 L976.815 1477.43 L976.815 1485.58 L972.162 1485.58 L972.162 1477.43 L956.56 1477.43 L956.56 1472.92 L970.935 1451.02 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M1391.56 1454.1 Q1387.95 1454.1 1386.12 1457.66 Q1384.32 1461.2 1384.32 1468.33 Q1384.32 1475.44 1386.12 1479.01 Q1387.95 1482.55 1391.56 1482.55 Q1395.2 1482.55 1397 1479.01 Q1398.83 1475.44 1398.83 1468.33 Q1398.83 1461.2 1397 1457.66 Q1395.2 1454.1 1391.56 1454.1 M1391.56 1450.39 Q1397.37 1450.39 1400.43 1455 Q1403.51 1459.58 1403.51 1468.33 Q1403.51 1477.06 1400.43 1481.67 Q1397.37 1486.25 1391.56 1486.25 Q1385.75 1486.25 1382.68 1481.67 Q1379.62 1477.06 1379.62 1468.33 Q1379.62 1459.58 1382.68 1455 Q1385.75 1450.39 1391.56 1450.39 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M1411.73 1479.7 L1416.61 1479.7 L1416.61 1485.58 L1411.73 1485.58 L1411.73 1479.7 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M1437.37 1466.44 Q1434.23 1466.44 1432.37 1468.59 Q1430.55 1470.74 1430.55 1474.49 Q1430.55 1478.22 1432.37 1480.39 Q1434.23 1482.55 1437.37 1482.55 Q1440.52 1482.55 1442.35 1480.39 Q1444.2 1478.22 1444.2 1474.49 Q1444.2 1470.74 1442.35 1468.59 Q1440.52 1466.44 1437.37 1466.44 M1446.66 1451.78 L1446.66 1456.04 Q1444.9 1455.21 1443.09 1454.77 Q1441.31 1454.33 1439.55 1454.33 Q1434.92 1454.33 1432.47 1457.45 Q1430.04 1460.58 1429.69 1466.9 Q1431.05 1464.89 1433.11 1463.82 Q1435.17 1462.73 1437.65 1462.73 Q1442.86 1462.73 1445.87 1465.9 Q1448.9 1469.05 1448.9 1474.49 Q1448.9 1479.82 1445.75 1483.03 Q1442.61 1486.25 1437.37 1486.25 Q1431.38 1486.25 1428.21 1481.67 Q1425.04 1477.06 1425.04 1468.33 Q1425.04 1460.14 1428.92 1455.28 Q1432.81 1450.39 1439.36 1450.39 Q1441.12 1450.39 1442.91 1450.74 Q1444.71 1451.09 1446.66 1451.78 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M1859.01 1454.1 Q1855.4 1454.1 1853.57 1457.66 Q1851.76 1461.2 1851.76 1468.33 Q1851.76 1475.44 1853.57 1479.01 Q1855.4 1482.55 1859.01 1482.55 Q1862.64 1482.55 1864.45 1479.01 Q1866.28 1475.44 1866.28 1468.33 Q1866.28 1461.2 1864.45 1457.66 Q1862.64 1454.1 1859.01 1454.1 M1859.01 1450.39 Q1864.82 1450.39 1867.88 1455 Q1870.95 1459.58 1870.95 1468.33 Q1870.95 1477.06 1867.88 1481.67 Q1864.82 1486.25 1859.01 1486.25 Q1853.2 1486.25 1850.12 1481.67 Q1847.07 1477.06 1847.07 1468.33 Q1847.07 1459.58 1850.12 1455 Q1853.2 1450.39 1859.01 1450.39 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M1879.17 1479.7 L1884.06 1479.7 L1884.06 1485.58 L1879.17 1485.58 L1879.17 1479.7 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M1904.24 1469.17 Q1900.91 1469.17 1898.99 1470.95 Q1897.09 1472.73 1897.09 1475.86 Q1897.09 1478.98 1898.99 1480.77 Q1900.91 1482.55 1904.24 1482.55 Q1907.57 1482.55 1909.5 1480.77 Q1911.42 1478.96 1911.42 1475.86 Q1911.42 1472.73 1909.5 1470.95 Q1907.6 1469.17 1904.24 1469.17 M1899.56 1467.18 Q1896.56 1466.44 1894.87 1464.38 Q1893.2 1462.32 1893.2 1459.35 Q1893.2 1455.21 1896.14 1452.8 Q1899.1 1450.39 1904.24 1450.39 Q1909.4 1450.39 1912.34 1452.8 Q1915.28 1455.21 1915.28 1459.35 Q1915.28 1462.32 1913.59 1464.38 Q1911.93 1466.44 1908.94 1467.18 Q1912.32 1467.96 1914.19 1470.26 Q1916.09 1472.55 1916.09 1475.86 Q1916.09 1480.88 1913.01 1483.57 Q1909.96 1486.25 1904.24 1486.25 Q1898.52 1486.25 1895.44 1483.57 Q1892.39 1480.88 1892.39 1475.86 Q1892.39 1472.55 1894.29 1470.26 Q1896.19 1467.96 1899.56 1467.18 M1897.85 1459.79 Q1897.85 1462.48 1899.52 1463.98 Q1901.21 1465.49 1904.24 1465.49 Q1907.25 1465.49 1908.94 1463.98 Q1910.65 1462.48 1910.65 1459.79 Q1910.65 1457.11 1908.94 1455.6 Q1907.25 1454.1 1904.24 1454.1 Q1901.21 1454.1 1899.52 1455.6 Q1897.85 1457.11 1897.85 1459.79 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M2316.05 1481.64 L2323.69 1481.64 L2323.69 1455.28 L2315.38 1456.95 L2315.38 1452.69 L2323.64 1451.02 L2328.32 1451.02 L2328.32 1481.64 L2335.96 1481.64 L2335.96 1485.58 L2316.05 1485.58 L2316.05 1481.64 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M2345.4 1479.7 L2350.29 1479.7 L2350.29 1485.58 L2345.4 1485.58 L2345.4 1479.7 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M2370.47 1454.1 Q2366.86 1454.1 2365.03 1457.66 Q2363.23 1461.2 2363.23 1468.33 Q2363.23 1475.44 2365.03 1479.01 Q2366.86 1482.55 2370.47 1482.55 Q2374.11 1482.55 2375.91 1479.01 Q2377.74 1475.44 2377.74 1468.33 Q2377.74 1461.2 2375.91 1457.66 Q2374.11 1454.1 2370.47 1454.1 M2370.47 1450.39 Q2376.28 1450.39 2379.34 1455 Q2382.42 1459.58 2382.42 1468.33 Q2382.42 1477.06 2379.34 1481.67 Q2376.28 1486.25 2370.47 1486.25 Q2364.66 1486.25 2361.58 1481.67 Q2358.53 1477.06 2358.53 1468.33 Q2358.53 1459.58 2361.58 1455 Q2364.66 1450.39 2370.47 1450.39 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M1159.74 1533.45 L1159.74 1538.98 Q1157.26 1537.71 1154.58 1537.07 Q1151.91 1536.44 1149.04 1536.44 Q1144.68 1536.44 1142.49 1537.77 Q1140.32 1539.11 1140.32 1541.79 Q1140.32 1543.82 1141.88 1545 Q1143.44 1546.15 1148.15 1547.2 L1150.16 1547.64 Q1156.4 1548.98 1159.01 1551.43 Q1161.65 1553.85 1161.65 1558.21 Q1161.65 1563.17 1157.7 1566.07 Q1153.79 1568.97 1146.91 1568.97 Q1144.05 1568.97 1140.93 1568.39 Q1137.84 1567.85 1134.4 1566.74 L1134.4 1560.69 Q1137.65 1562.38 1140.8 1563.24 Q1143.95 1564.07 1147.04 1564.07 Q1151.18 1564.07 1153.41 1562.66 Q1155.63 1561.23 1155.63 1558.65 Q1155.63 1556.27 1154.01 1554.99 Q1152.42 1553.72 1146.98 1552.54 L1144.94 1552.07 Q1139.5 1550.92 1137.08 1548.56 Q1134.66 1546.18 1134.66 1542.04 Q1134.66 1537.01 1138.22 1534.27 Q1141.79 1531.54 1148.34 1531.54 Q1151.59 1531.54 1154.46 1532.01 Q1157.32 1532.49 1159.74 1533.45 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M1191.15 1518.52 L1204.65 1518.52 L1204.65 1523.07 L1197.01 1523.07 L1197.01 1572.09 L1204.65 1572.09 L1204.65 1576.64 L1191.15 1576.64 L1191.15 1518.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M1216.9 1518.52 L1222.79 1518.52 L1222.79 1547.77 L1240.27 1532.4 L1247.75 1532.4 L1228.84 1549.07 L1248.54 1568.04 L1240.9 1568.04 L1222.79 1550.63 L1222.79 1568.04 L1216.9 1568.04 L1216.9 1518.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M1255.13 1520.52 L1261.56 1520.52 L1261.56 1564.73 Q1261.56 1573.33 1258.28 1577.21 Q1255.03 1581.09 1247.81 1581.09 L1245.36 1581.09 L1245.36 1575.68 L1247.36 1575.68 Q1251.63 1575.68 1253.38 1573.3 Q1255.13 1570.91 1255.13 1564.73 L1255.13 1520.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M1284.51 1520.52 L1289.92 1520.52 L1273.37 1574.09 L1267.96 1574.09 L1284.51 1520.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M1295.84 1518.52 L1301.73 1518.52 L1301.73 1547.77 L1319.2 1532.4 L1326.68 1532.4 L1307.77 1549.07 L1327.48 1568.04 L1319.84 1568.04 L1301.73 1550.63 L1301.73 1568.04 L1295.84 1568.04 L1295.84 1518.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M1357.27 1549.81 Q1357.27 1543.44 1354.63 1539.94 Q1352.02 1536.44 1347.27 1536.44 Q1342.56 1536.44 1339.92 1539.94 Q1337.31 1543.44 1337.31 1549.81 Q1337.31 1556.14 1339.92 1559.64 Q1342.56 1563.14 1347.27 1563.14 Q1352.02 1563.14 1354.63 1559.64 Q1357.27 1556.14 1357.27 1549.81 M1363.12 1563.62 Q1363.12 1572.72 1359.08 1577.15 Q1355.04 1581.6 1346.7 1581.6 Q1343.61 1581.6 1340.88 1581.13 Q1338.14 1580.68 1335.56 1579.72 L1335.56 1574.03 Q1338.14 1575.43 1340.65 1576.1 Q1343.17 1576.76 1345.78 1576.76 Q1351.54 1576.76 1354.4 1573.74 Q1357.27 1570.75 1357.27 1564.67 L1357.27 1561.77 Q1355.45 1564.92 1352.62 1566.48 Q1349.79 1568.04 1345.84 1568.04 Q1339.28 1568.04 1335.27 1563.05 Q1331.26 1558.05 1331.26 1549.81 Q1331.26 1541.53 1335.27 1536.53 Q1339.28 1531.54 1345.84 1531.54 Q1349.79 1531.54 1352.62 1533.1 Q1355.45 1534.66 1357.27 1537.81 L1357.27 1532.4 L1363.12 1532.4 L1363.12 1563.62 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M1376.01 1559.96 L1382.73 1559.96 L1382.73 1568.04 L1376.01 1568.04 L1376.01 1559.96 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M1396.16 1520.52 L1402.59 1520.52 L1402.59 1540.61 L1423.92 1520.52 L1432.19 1520.52 L1408.61 1542.68 L1433.88 1568.04 L1425.41 1568.04 L1402.59 1545.16 L1402.59 1568.04 L1396.16 1568.04 L1396.16 1520.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M1452.34 1518.52 L1452.34 1576.64 L1438.84 1576.64 L1438.84 1572.09 L1446.45 1572.09 L1446.45 1523.07 L1438.84 1523.07 L1438.84 1518.52 L1452.34 1518.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><polyline clip-path="url(#clip830)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="233.987,1423.18 233.987,47.2441 "/>
<polyline clip-path="url(#clip830)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="233.987,1178.19 252.884,1178.19 "/>
<polyline clip-path="url(#clip830)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="233.987,903.017 252.884,903.017 "/>
<polyline clip-path="url(#clip830)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="233.987,627.842 252.884,627.842 "/>
<polyline clip-path="url(#clip830)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="233.987,352.666 252.884,352.666 "/>
<polyline clip-path="url(#clip830)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="233.987,77.4901 252.884,77.4901 "/>
<path clip-path="url(#clip830)" d="M120.742 1191.54 L137.061 1191.54 L137.061 1195.47 L115.117 1195.47 L115.117 1191.54 Q117.779 1188.78 122.362 1184.15 Q126.968 1179.5 128.149 1178.16 Q130.394 1175.64 131.274 1173.9 Q132.177 1172.14 132.177 1170.45 Q132.177 1167.7 130.232 1165.96 Q128.311 1164.22 125.209 1164.22 Q123.01 1164.22 120.556 1164.99 Q118.126 1165.75 115.348 1167.3 L115.348 1162.58 Q118.172 1161.45 120.626 1160.87 Q123.08 1160.29 125.117 1160.29 Q130.487 1160.29 133.681 1162.97 Q136.876 1165.66 136.876 1170.15 Q136.876 1172.28 136.066 1174.2 Q135.279 1176.1 133.172 1178.69 Q132.593 1179.36 129.492 1182.58 Q126.39 1185.77 120.742 1191.54 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M145.695 1160.91 L167.917 1160.91 L167.917 1162.9 L155.371 1195.47 L150.487 1195.47 L162.292 1164.85 L145.695 1164.85 L145.695 1160.91 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M177.084 1160.91 L195.44 1160.91 L195.44 1164.85 L181.366 1164.85 L181.366 1173.32 Q182.385 1172.97 183.403 1172.81 Q184.422 1172.63 185.44 1172.63 Q191.227 1172.63 194.607 1175.8 Q197.987 1178.97 197.987 1184.39 Q197.987 1189.96 194.514 1193.07 Q191.042 1196.14 184.723 1196.14 Q182.547 1196.14 180.278 1195.77 Q178.033 1195.4 175.626 1194.66 L175.626 1189.96 Q177.709 1191.1 179.931 1191.65 Q182.153 1192.21 184.63 1192.21 Q188.635 1192.21 190.973 1190.1 Q193.311 1188 193.311 1184.39 Q193.311 1180.77 190.973 1178.67 Q188.635 1176.56 184.63 1176.56 Q182.755 1176.56 180.88 1176.98 Q179.028 1177.39 177.084 1178.27 L177.084 1160.91 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M129.885 901.663 Q133.242 902.381 135.117 904.649 Q137.015 906.918 137.015 910.251 Q137.015 915.367 133.496 918.168 Q129.978 920.969 123.496 920.969 Q121.32 920.969 119.006 920.529 Q116.714 920.112 114.26 919.256 L114.26 914.742 Q116.205 915.876 118.519 916.455 Q120.834 917.033 123.357 917.033 Q127.755 917.033 130.047 915.297 Q132.362 913.561 132.362 910.251 Q132.362 907.195 130.209 905.482 Q128.08 903.746 124.26 903.746 L120.232 903.746 L120.232 899.904 L124.445 899.904 Q127.894 899.904 129.723 898.538 Q131.552 897.149 131.552 894.557 Q131.552 891.895 129.654 890.483 Q127.779 889.047 124.26 889.047 Q122.339 889.047 120.14 889.464 Q117.941 889.881 115.302 890.76 L115.302 886.594 Q117.964 885.853 120.279 885.483 Q122.617 885.112 124.677 885.112 Q130.001 885.112 133.103 887.543 Q136.204 889.95 136.204 894.071 Q136.204 896.941 134.561 898.932 Q132.917 900.899 129.885 901.663 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M155.88 888.816 Q152.269 888.816 150.441 892.381 Q148.635 895.922 148.635 903.052 Q148.635 910.158 150.441 913.723 Q152.269 917.265 155.88 917.265 Q159.515 917.265 161.32 913.723 Q163.149 910.158 163.149 903.052 Q163.149 895.922 161.32 892.381 Q159.515 888.816 155.88 888.816 M155.88 885.112 Q161.69 885.112 164.746 889.719 Q167.825 894.302 167.825 903.052 Q167.825 911.779 164.746 916.385 Q161.69 920.969 155.88 920.969 Q150.07 920.969 146.991 916.385 Q143.936 911.779 143.936 903.052 Q143.936 894.302 146.991 889.719 Q150.07 885.112 155.88 885.112 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M186.042 888.816 Q182.431 888.816 180.602 892.381 Q178.797 895.922 178.797 903.052 Q178.797 910.158 180.602 913.723 Q182.431 917.265 186.042 917.265 Q189.676 917.265 191.482 913.723 Q193.311 910.158 193.311 903.052 Q193.311 895.922 191.482 892.381 Q189.676 888.816 186.042 888.816 M186.042 885.112 Q191.852 885.112 194.908 889.719 Q197.987 894.302 197.987 903.052 Q197.987 911.779 194.908 916.385 Q191.852 920.969 186.042 920.969 Q180.232 920.969 177.153 916.385 Q174.098 911.779 174.098 903.052 Q174.098 894.302 177.153 889.719 Q180.232 885.112 186.042 885.112 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M130.88 626.487 Q134.237 627.205 136.112 629.473 Q138.01 631.742 138.01 635.075 Q138.01 640.191 134.492 642.992 Q130.973 645.793 124.492 645.793 Q122.316 645.793 120.001 645.353 Q117.709 644.936 115.256 644.08 L115.256 639.566 Q117.2 640.7 119.515 641.279 Q121.83 641.858 124.353 641.858 Q128.751 641.858 131.042 640.122 Q133.357 638.385 133.357 635.075 Q133.357 632.02 131.205 630.307 Q129.075 628.571 125.255 628.571 L121.228 628.571 L121.228 624.728 L125.441 624.728 Q128.89 624.728 130.718 623.362 Q132.547 621.973 132.547 619.381 Q132.547 616.719 130.649 615.307 Q128.774 613.872 125.255 613.872 Q123.334 613.872 121.135 614.288 Q118.936 614.705 116.297 615.585 L116.297 611.418 Q118.959 610.677 121.274 610.307 Q123.612 609.937 125.672 609.937 Q130.996 609.937 134.098 612.367 Q137.2 614.774 137.2 618.895 Q137.2 621.765 135.556 623.756 Q133.913 625.723 130.88 626.487 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M150.903 641.186 L167.223 641.186 L167.223 645.122 L145.279 645.122 L145.279 641.186 Q147.941 638.432 152.524 633.802 Q157.13 629.149 158.311 627.807 Q160.556 625.284 161.436 623.548 Q162.339 621.788 162.339 620.099 Q162.339 617.344 160.394 615.608 Q158.473 613.872 155.371 613.872 Q153.172 613.872 150.718 614.636 Q148.288 615.399 145.51 616.95 L145.51 612.228 Q148.334 611.094 150.788 610.515 Q153.241 609.937 155.278 609.937 Q160.649 609.937 163.843 612.622 Q167.038 615.307 167.038 619.798 Q167.038 621.927 166.227 623.848 Q165.44 625.747 163.334 628.339 Q162.755 629.01 159.653 632.228 Q156.552 635.422 150.903 641.186 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M177.084 610.562 L195.44 610.562 L195.44 614.497 L181.366 614.497 L181.366 622.969 Q182.385 622.622 183.403 622.46 Q184.422 622.274 185.44 622.274 Q191.227 622.274 194.607 625.446 Q197.987 628.617 197.987 634.034 Q197.987 639.612 194.514 642.714 Q191.042 645.793 184.723 645.793 Q182.547 645.793 180.278 645.422 Q178.033 645.052 175.626 644.311 L175.626 639.612 Q177.709 640.747 179.931 641.302 Q182.153 641.858 184.63 641.858 Q188.635 641.858 190.973 639.751 Q193.311 637.645 193.311 634.034 Q193.311 630.423 190.973 628.316 Q188.635 626.21 184.63 626.21 Q182.755 626.21 180.88 626.626 Q179.028 627.043 177.084 627.923 L177.084 610.562 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M129.885 351.312 Q133.242 352.029 135.117 354.298 Q137.015 356.566 137.015 359.9 Q137.015 365.015 133.496 367.816 Q129.978 370.617 123.496 370.617 Q121.32 370.617 119.006 370.177 Q116.714 369.761 114.26 368.904 L114.26 364.39 Q116.205 365.525 118.519 366.103 Q120.834 366.682 123.357 366.682 Q127.755 366.682 130.047 364.946 Q132.362 363.21 132.362 359.9 Q132.362 356.844 130.209 355.131 Q128.08 353.395 124.26 353.395 L120.232 353.395 L120.232 349.552 L124.445 349.552 Q127.894 349.552 129.723 348.187 Q131.552 346.798 131.552 344.205 Q131.552 341.543 129.654 340.131 Q127.779 338.696 124.26 338.696 Q122.339 338.696 120.14 339.113 Q117.941 339.529 115.302 340.409 L115.302 336.242 Q117.964 335.502 120.279 335.131 Q122.617 334.761 124.677 334.761 Q130.001 334.761 133.103 337.191 Q136.204 339.599 136.204 343.719 Q136.204 346.589 134.561 348.58 Q132.917 350.548 129.885 351.312 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M145.927 335.386 L164.283 335.386 L164.283 339.321 L150.209 339.321 L150.209 347.793 Q151.228 347.446 152.246 347.284 Q153.265 347.099 154.283 347.099 Q160.07 347.099 163.45 350.27 Q166.829 353.441 166.829 358.858 Q166.829 364.437 163.357 367.538 Q159.885 370.617 153.566 370.617 Q151.39 370.617 149.121 370.247 Q146.876 369.876 144.468 369.136 L144.468 364.437 Q146.552 365.571 148.774 366.126 Q150.996 366.682 153.473 366.682 Q157.478 366.682 159.815 364.575 Q162.153 362.469 162.153 358.858 Q162.153 355.247 159.815 353.14 Q157.478 351.034 153.473 351.034 Q151.598 351.034 149.723 351.451 Q147.871 351.867 145.927 352.747 L145.927 335.386 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M186.042 338.465 Q182.431 338.465 180.602 342.029 Q178.797 345.571 178.797 352.701 Q178.797 359.807 180.602 363.372 Q182.431 366.913 186.042 366.913 Q189.676 366.913 191.482 363.372 Q193.311 359.807 193.311 352.701 Q193.311 345.571 191.482 342.029 Q189.676 338.465 186.042 338.465 M186.042 334.761 Q191.852 334.761 194.908 339.367 Q197.987 343.951 197.987 352.701 Q197.987 361.427 194.908 366.034 Q191.852 370.617 186.042 370.617 Q180.232 370.617 177.153 366.034 Q174.098 361.427 174.098 352.701 Q174.098 343.951 177.153 339.367 Q180.232 334.761 186.042 334.761 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M130.88 76.136 Q134.237 76.8535 136.112 79.1221 Q138.01 81.3906 138.01 84.7239 Q138.01 89.8396 134.492 92.6405 Q130.973 95.4414 124.492 95.4414 Q122.316 95.4414 120.001 95.0016 Q117.709 94.5849 115.256 93.7285 L115.256 89.2146 Q117.2 90.3488 119.515 90.9275 Q121.83 91.5062 124.353 91.5062 Q128.751 91.5062 131.042 89.7701 Q133.357 88.034 133.357 84.7239 Q133.357 81.6683 131.205 79.9554 Q129.075 78.2193 125.255 78.2193 L121.228 78.2193 L121.228 74.3767 L125.441 74.3767 Q128.89 74.3767 130.718 73.011 Q132.547 71.6221 132.547 69.0295 Q132.547 66.3675 130.649 64.9555 Q128.774 63.5203 125.255 63.5203 Q123.334 63.5203 121.135 63.937 Q118.936 64.3536 116.297 65.2332 L116.297 61.0666 Q118.959 60.3259 121.274 59.9555 Q123.612 59.5851 125.672 59.5851 Q130.996 59.5851 134.098 62.0157 Q137.2 64.4231 137.2 68.5434 Q137.2 71.4138 135.556 73.4045 Q133.913 75.3721 130.88 76.136 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M145.695 60.2101 L167.917 60.2101 L167.917 62.2009 L155.371 94.7701 L150.487 94.7701 L162.292 64.1453 L145.695 64.1453 L145.695 60.2101 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M177.084 60.2101 L195.44 60.2101 L195.44 64.1453 L181.366 64.1453 L181.366 72.6175 Q182.385 72.2702 183.403 72.1082 Q184.422 71.923 185.44 71.923 Q191.227 71.923 194.607 75.0943 Q197.987 78.2656 197.987 83.6822 Q197.987 89.2609 194.514 92.3627 Q191.042 95.4414 184.723 95.4414 Q182.547 95.4414 180.278 95.071 Q178.033 94.7007 175.626 93.9599 L175.626 89.2609 Q177.709 90.3951 179.931 90.9507 Q182.153 91.5062 184.63 91.5062 Q188.635 91.5062 190.973 89.3998 Q193.311 87.2933 193.311 83.6822 Q193.311 80.0711 190.973 77.9647 Q188.635 75.8582 184.63 75.8582 Q182.755 75.8582 180.88 76.2748 Q179.028 76.6915 177.084 77.5711 L177.084 60.2101 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M16.4842 809.579 L16.4842 769.38 L21.895 769.38 L21.895 786.249 L64.0042 786.249 L64.0042 792.71 L21.895 792.71 L21.895 809.579 L16.4842 809.579 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M14.479 743.249 L14.479 729.753 L19.0304 729.753 L19.0304 737.392 L68.0464 737.392 L68.0464 729.753 L72.5979 729.753 L72.5979 743.249 L14.479 743.249 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M16.4842 717.022 L16.4842 710.593 L36.568 710.593 L16.4842 689.267 L16.4842 680.992 L38.6368 704.577 L64.0042 679.305 L64.0042 687.772 L41.1194 710.593 L64.0042 710.593 L64.0042 717.022 L16.4842 717.022 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M14.479 660.845 L72.5979 660.845 L72.5979 674.34 L68.0464 674.34 L68.0464 666.733 L19.0304 666.733 L19.0304 674.34 L14.479 674.34 L14.479 660.845 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><polyline clip-path="url(#clip832)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:0.4; fill:none" points="293.952,1384.24 470.781,1216.93 630.979,1061.17 776.546,916.939 909.072,784.25 1029.83,663.098 1139.85,553.485 1239.98,455.41 1330.91,368.873 1413.27,293.874 1487.64,230.414 1554.67,178.492 1615.2,138.108 1670.72,109.262 1725.87,91.9548 1803.28,86.1857 1867.86,91.9548 1939.91,109.262 1991.59,138.108 2027.86,178.492 2058.08,230.414 2083.05,293.874 2103.41,368.873 2119.8,455.41 2132.95,553.485 2143.73,663.098 2153.25,784.25 2162.93,916.939 2174.64,1061.17 2190.99,1216.93 2215.72,1384.24 "/>
<polyline clip-path="url(#clip832)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2210.32,899.379 2166.29,961.116 732.178,961.116 "/>
<polyline clip-path="url(#clip832)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:0.5; fill:none" stroke-dasharray="16, 10" points="2194.63,1245.71 2194.63,921.643 "/>
<polyline clip-path="url(#clip832)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2194.63,1245.71 2210.32,899.379 "/>
<polyline clip-path="url(#clip832)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="732.178,961.116 740.346,1156.99 748.514,1245.71 "/>
<polyline clip-path="url(#clip832)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="748.514,1245.71 2194.63,1245.71 "/>
<polyline clip-path="url(#clip832)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:0.4; fill:none" points="732.178,961.116 2166.29,961.116 2230.98,869.64 2292.79,778.164 "/>
<polyline clip-path="url(#clip832)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:0.4; fill:none" points="440.758,1245.71 2194.63,1245.71 2236.08,1185.1 2276.56,1124.49 "/>
<path clip-path="url(#clip830)" d="M2141.38 935.793 L2141.38 875.377 L2188.11 875.377 L2188.11 935.793 L2141.38 935.793 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M2186.95 935.793 L2186.95 875.377 L2233.68 875.377 L2233.68 935.793 L2186.95 935.793 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M2232.52 935.793 L2232.52 875.377 L2279.25 875.377 L2279.25 935.793 L2232.52 935.793 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M2185.77 891.497 L2185.77 895.524 Q2183.96 894.599 2182.02 894.136 Q2180.07 893.673 2177.99 893.673 Q2174.82 893.673 2173.22 894.645 Q2171.65 895.617 2171.65 897.561 Q2171.65 899.043 2172.78 899.899 Q2173.92 900.733 2177.34 901.497 L2178.8 901.821 Q2183.34 902.793 2185.23 904.575 Q2187.16 906.335 2187.16 909.506 Q2187.16 913.117 2184.29 915.223 Q2181.44 917.33 2176.44 917.33 Q2174.36 917.33 2172.09 916.913 Q2169.84 916.52 2167.34 915.71 L2167.34 911.311 Q2169.7 912.538 2171.99 913.163 Q2174.29 913.765 2176.53 913.765 Q2179.54 913.765 2181.16 912.747 Q2182.78 911.705 2182.78 909.83 Q2182.78 908.094 2181.6 907.168 Q2180.44 906.242 2176.48 905.386 L2175 905.038 Q2171.05 904.205 2169.29 902.492 Q2167.53 900.756 2167.53 897.747 Q2167.53 894.089 2170.12 892.099 Q2172.71 890.108 2177.48 890.108 Q2179.84 890.108 2181.92 890.455 Q2184.01 890.802 2185.77 891.497 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M2198.15 883.372 L2198.15 890.733 L2206.92 890.733 L2206.92 894.043 L2198.15 894.043 L2198.15 908.117 Q2198.15 911.288 2199.01 912.191 Q2199.89 913.094 2202.55 913.094 L2206.92 913.094 L2206.92 916.659 L2202.55 916.659 Q2197.62 916.659 2195.74 914.83 Q2193.87 912.978 2193.87 908.117 L2193.87 894.043 L2190.74 894.043 L2190.74 890.733 L2193.87 890.733 L2193.87 883.372 L2198.15 883.372 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M2217.16 912.723 L2233.48 912.723 L2233.48 916.659 L2211.53 916.659 L2211.53 912.723 Q2214.19 909.969 2218.78 905.339 Q2223.38 900.686 2224.56 899.344 Q2226.81 896.821 2227.69 895.085 Q2228.59 893.325 2228.59 891.636 Q2228.59 888.881 2226.65 887.145 Q2224.73 885.409 2221.62 885.409 Q2219.42 885.409 2216.97 886.173 Q2214.54 886.937 2211.76 888.487 L2211.76 883.765 Q2214.59 882.631 2217.04 882.052 Q2219.49 881.474 2221.53 881.474 Q2226.9 881.474 2230.1 884.159 Q2233.29 886.844 2233.29 891.335 Q2233.29 893.464 2232.48 895.386 Q2231.69 897.284 2229.59 899.876 Q2229.01 900.548 2225.91 903.765 Q2222.8 906.96 2217.16 912.723 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M686.027 997.531 L686.027 937.114 L732.757 937.114 L732.757 997.531 L686.027 997.531 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M731.599 997.531 L731.599 937.114 L778.329 937.114 L778.329 997.531 L731.599 997.531 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M717.062 953.234 L717.062 957.262 Q715.257 956.336 713.312 955.873 Q711.368 955.41 709.285 955.41 Q706.113 955.41 704.516 956.382 Q702.942 957.355 702.942 959.299 Q702.942 960.78 704.076 961.637 Q705.211 962.47 708.637 963.234 L710.095 963.558 Q714.632 964.53 716.53 966.313 Q718.451 968.072 718.451 971.243 Q718.451 974.854 715.581 976.961 Q712.734 979.067 707.734 979.067 Q705.65 979.067 703.382 978.651 Q701.137 978.257 698.637 977.447 L698.637 973.049 Q700.998 974.276 703.289 974.901 Q705.581 975.503 707.826 975.503 Q710.836 975.503 712.456 974.484 Q714.076 973.442 714.076 971.567 Q714.076 969.831 712.896 968.905 Q711.738 967.979 707.78 967.123 L706.299 966.776 Q702.34 965.942 700.581 964.229 Q698.822 962.493 698.822 959.484 Q698.822 955.827 701.414 953.836 Q704.007 951.845 708.775 951.845 Q711.137 951.845 713.22 952.193 Q715.303 952.54 717.062 953.234 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M729.447 945.109 L729.447 952.47 L738.22 952.47 L738.22 955.78 L729.447 955.78 L729.447 969.854 Q729.447 973.026 730.303 973.928 Q731.183 974.831 733.845 974.831 L738.22 974.831 L738.22 978.396 L733.845 978.396 Q728.914 978.396 727.039 976.567 Q725.164 974.716 725.164 969.854 L725.164 955.78 L722.039 955.78 L722.039 952.47 L725.164 952.47 L725.164 945.109 L729.447 945.109 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M758.59 959.762 Q761.946 960.479 763.821 962.748 Q765.72 965.017 765.72 968.35 Q765.72 973.466 762.201 976.266 Q758.683 979.067 752.201 979.067 Q750.025 979.067 747.71 978.628 Q745.419 978.211 742.965 977.354 L742.965 972.841 Q744.909 973.975 747.224 974.553 Q749.539 975.132 752.062 975.132 Q756.46 975.132 758.752 973.396 Q761.067 971.66 761.067 968.35 Q761.067 965.294 758.914 963.581 Q756.784 961.845 752.965 961.845 L748.937 961.845 L748.937 958.003 L753.15 958.003 Q756.599 958.003 758.428 956.637 Q760.257 955.248 760.257 952.655 Q760.257 949.993 758.358 948.581 Q756.484 947.146 752.965 947.146 Q751.044 947.146 748.845 947.563 Q746.646 947.98 744.007 948.859 L744.007 944.693 Q746.669 943.952 748.984 943.581 Q751.321 943.211 753.382 943.211 Q758.706 943.211 761.808 945.642 Q764.909 948.049 764.909 952.169 Q764.909 955.04 763.266 957.03 Q761.622 958.998 758.59 959.762 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M2148.48 1282.12 L2148.48 1221.71 L2195.21 1221.71 L2195.21 1282.12 L2148.48 1282.12 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M2194.05 1282.12 L2194.05 1221.71 L2240.78 1221.71 L2240.78 1282.12 L2194.05 1282.12 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M2179.8 1237.83 L2179.8 1241.85 Q2178 1240.93 2176.05 1240.46 Q2174.11 1240 2172.03 1240 Q2168.85 1240 2167.26 1240.97 Q2165.68 1241.95 2165.68 1243.89 Q2165.68 1245.37 2166.82 1246.23 Q2167.95 1247.06 2171.38 1247.82 L2172.84 1248.15 Q2177.37 1249.12 2179.27 1250.9 Q2181.19 1252.66 2181.19 1255.83 Q2181.19 1259.45 2178.32 1261.55 Q2175.47 1263.66 2170.47 1263.66 Q2168.39 1263.66 2166.12 1263.24 Q2163.88 1262.85 2161.38 1262.04 L2161.38 1257.64 Q2163.74 1258.87 2166.03 1259.49 Q2168.32 1260.09 2170.57 1260.09 Q2173.58 1260.09 2175.2 1259.07 Q2176.82 1258.03 2176.82 1256.16 Q2176.82 1254.42 2175.64 1253.5 Q2174.48 1252.57 2170.52 1251.71 L2169.04 1251.37 Q2165.08 1250.53 2163.32 1248.82 Q2161.56 1247.08 2161.56 1244.07 Q2161.56 1240.42 2164.16 1238.43 Q2166.75 1236.44 2171.52 1236.44 Q2173.88 1236.44 2175.96 1236.78 Q2178.04 1237.13 2179.8 1237.83 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M2192.19 1229.7 L2192.19 1237.06 L2200.96 1237.06 L2200.96 1240.37 L2192.19 1240.37 L2192.19 1254.45 Q2192.19 1257.62 2193.04 1258.52 Q2193.92 1259.42 2196.59 1259.42 L2200.96 1259.42 L2200.96 1262.99 L2196.59 1262.99 Q2191.66 1262.99 2189.78 1261.16 Q2187.91 1259.31 2187.91 1254.45 L2187.91 1240.37 L2184.78 1240.37 L2184.78 1237.06 L2187.91 1237.06 L2187.91 1229.7 L2192.19 1229.7 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M2207.97 1259.05 L2215.61 1259.05 L2215.61 1232.69 L2207.3 1234.35 L2207.3 1230.09 L2215.57 1228.43 L2220.24 1228.43 L2220.24 1259.05 L2227.88 1259.05 L2227.88 1262.99 L2207.97 1262.99 L2207.97 1259.05 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M702.362 1282.12 L702.362 1221.71 L749.092 1221.71 L749.092 1282.12 L702.362 1282.12 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M747.935 1282.12 L747.935 1221.71 L794.665 1221.71 L794.665 1282.12 L747.935 1282.12 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M732.831 1237.83 L732.831 1241.85 Q731.025 1240.93 729.081 1240.46 Q727.137 1240 725.053 1240 Q721.882 1240 720.285 1240.97 Q718.711 1241.95 718.711 1243.89 Q718.711 1245.37 719.845 1246.23 Q720.979 1247.06 724.405 1247.82 L725.863 1248.15 Q730.4 1249.12 732.299 1250.9 Q734.22 1252.66 734.22 1255.83 Q734.22 1259.45 731.35 1261.55 Q728.502 1263.66 723.502 1263.66 Q721.419 1263.66 719.151 1263.24 Q716.905 1262.85 714.405 1262.04 L714.405 1257.64 Q716.766 1258.87 719.058 1259.49 Q721.35 1260.09 723.595 1260.09 Q726.604 1260.09 728.225 1259.07 Q729.845 1258.03 729.845 1256.16 Q729.845 1254.42 728.664 1253.5 Q727.507 1252.57 723.549 1251.71 L722.067 1251.37 Q718.109 1250.53 716.35 1248.82 Q714.59 1247.08 714.59 1244.07 Q714.59 1240.42 717.183 1238.43 Q719.776 1236.44 724.544 1236.44 Q726.905 1236.44 728.988 1236.78 Q731.072 1237.13 732.831 1237.83 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M745.215 1229.7 L745.215 1237.06 L753.988 1237.06 L753.988 1240.37 L745.215 1240.37 L745.215 1254.45 Q745.215 1257.62 746.072 1258.52 Q746.951 1259.42 749.613 1259.42 L753.988 1259.42 L753.988 1262.99 L749.613 1262.99 Q744.683 1262.99 742.808 1261.16 Q740.933 1259.31 740.933 1254.45 L740.933 1240.37 L737.808 1240.37 L737.808 1237.06 L740.933 1237.06 L740.933 1229.7 L745.215 1229.7 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip830)" d="M773.039 1232.5 L761.234 1250.95 L773.039 1250.95 L773.039 1232.5 M771.812 1228.43 L777.692 1228.43 L777.692 1250.95 L782.622 1250.95 L782.622 1254.84 L777.692 1254.84 L777.692 1262.99 L773.039 1262.99 L773.039 1254.84 L757.437 1254.84 L757.437 1250.32 L771.812 1228.43 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /></svg>
</div><div style=' border: 1px solid;'><h3 style='text-align: center;margin: 8px;'>Cycle Properties:</h3><div style='display: flex; justify-content: space-around;'><div style = "display: inline-block; border: 1px solid #666666;"><!DOCTYPE html>
<html>
<meta charset="UTF-8">
<style>
  table, td, th {
      border-collapse: collapse; color: black;
      font-family: sans-serif;
  }

  td, th {
      border-bottom: 0;
      padding: 4px
  }

  tr:nth-child(odd) {
      background: #eee;
  }

  tr:nth-child(even) {
      background: #fff;
  }

  tr.header {
      background: #fff !important;
      font-weight: bold;
  }

  tr.subheader {
      background: #fff !important;
      color: dimgray;
  }

  tr.headerLastRow {
      border-bottom: 2px solid black;
  }

  th.rowNumber, td.rowNumber {
      text-align: right;
  }

</style>
<body>
<table>
  <thead>
    <tr class = "header headerLastRow">
      <th style = "color: black; text-align: center; padding: 11px; font-size: 130%;"></th>
      <th style = "color: black; text-align: center; padding: 11px; font-size: 130%;">Total</th>
      <th style = "color: black; text-align: center; padding: 11px; font-size: 130%;">Component</th>
      <th style = "color: black; text-align: center; padding: 11px; font-size: 130%;">Value</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">qin<BR>Q̇in</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">166.4013 kJ/kg<BR>416.0033 kW</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">evaporator:<BR>   st4 &gt;&gt; st1</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">166.4013 kJ/kg<BR>416.0033 kW</td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">qout<BR>Q̇out</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">186.4947 kJ/kg<BR>466.2367 kW</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">evaporator_condenser:<BR>   [stD, st2] &gt;&gt; [stA, st3]</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">186.4947 kJ/kg<BR>466.2367 kW</td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">win<BR>Ẇin</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">20.0934 kJ/kg<BR>50.2334 kW</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">compressor:<BR>   st1 &gt;&gt; st2</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">20.0934 kJ/kg<BR>50.2334 kW</td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">wout<BR>Ẇout</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;">0.0 kJ/kg<BR>0.0 kW</td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;"></td>
      <td style = "text-align: left; padding: 11px; font-size: 130%;"></td>
    </tr>
  </tbody>
</table>
</body>
</html>
</div></div><h3 style='text-align: center; border: 2px solid #666666; padding: 15px; margin: 10px;'>Coefficient of performance (COP) = 8.2814</h3></div>
</div></br><div style="display: inline-block; padding: 15px; margin: 20px;border: 2px solid;"><h1 style="text-align: center;
                    margin: -8px;">SYSTEM PROPERTIES</h1><div style='display: flex; justify-content: space-around;
                    padding: 10px; margin: 10px;'><?xml version="1.0" encoding="utf-8"?>
<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="600" height="400" viewBox="0 0 2400 1600">
<defs>
  <clipPath id="clip870">
    <rect x="0" y="0" width="2400" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip870)" d="M0 1600 L2400 1600 L2400 0 L0 0  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip871">
    <rect x="480" y="0" width="1681" height="1600"/>
  </clipPath>
</defs>
<path clip-path="url(#clip870)" d="M233.987 1423.18 L2352.76 1423.18 L2352.76 47.2441 L233.987 47.2441  Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1"/>
<defs>
  <clipPath id="clip872">
    <rect x="233" y="47" width="2120" height="1377"/>
  </clipPath>
</defs>
<polyline clip-path="url(#clip870)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="233.987,1423.18 2352.76,1423.18 "/>
<polyline clip-path="url(#clip870)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="487.07,1423.18 487.07,1404.28 "/>
<polyline clip-path="url(#clip870)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="973.128,1423.18 973.128,1404.28 "/>
<polyline clip-path="url(#clip870)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1459.19,1423.18 1459.19,1404.28 "/>
<polyline clip-path="url(#clip870)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1945.24,1423.18 1945.24,1404.28 "/>
<path clip-path="url(#clip870)" d="M465.253 1454.1 Q461.642 1454.1 459.813 1457.66 Q458.008 1461.2 458.008 1468.33 Q458.008 1475.44 459.813 1479.01 Q461.642 1482.55 465.253 1482.55 Q468.887 1482.55 470.693 1479.01 Q472.521 1475.44 472.521 1468.33 Q472.521 1461.2 470.693 1457.66 Q468.887 1454.1 465.253 1454.1 M465.253 1450.39 Q471.063 1450.39 474.119 1455 Q477.197 1459.58 477.197 1468.33 Q477.197 1477.06 474.119 1481.67 Q471.063 1486.25 465.253 1486.25 Q459.443 1486.25 456.364 1481.67 Q453.309 1477.06 453.309 1468.33 Q453.309 1459.58 456.364 1455 Q459.443 1450.39 465.253 1450.39 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M485.415 1479.7 L490.299 1479.7 L490.299 1485.58 L485.415 1485.58 L485.415 1479.7 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M504.512 1481.64 L520.831 1481.64 L520.831 1485.58 L498.887 1485.58 L498.887 1481.64 Q501.549 1478.89 506.132 1474.26 Q510.739 1469.61 511.919 1468.27 Q514.165 1465.74 515.044 1464.01 Q515.947 1462.25 515.947 1460.56 Q515.947 1457.8 514.003 1456.07 Q512.081 1454.33 508.98 1454.33 Q506.78 1454.33 504.327 1455.09 Q501.896 1455.86 499.118 1457.41 L499.118 1452.69 Q501.943 1451.55 504.396 1450.97 Q506.85 1450.39 508.887 1450.39 Q514.257 1450.39 517.452 1453.08 Q520.646 1455.77 520.646 1460.26 Q520.646 1462.39 519.836 1464.31 Q519.049 1466.2 516.942 1468.8 Q516.364 1469.47 513.262 1472.69 Q510.16 1475.88 504.512 1481.64 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M950.27 1454.1 Q946.658 1454.1 944.83 1457.66 Q943.024 1461.2 943.024 1468.33 Q943.024 1475.44 944.83 1479.01 Q946.658 1482.55 950.27 1482.55 Q953.904 1482.55 955.709 1479.01 Q957.538 1475.44 957.538 1468.33 Q957.538 1461.2 955.709 1457.66 Q953.904 1454.1 950.27 1454.1 M950.27 1450.39 Q956.08 1450.39 959.135 1455 Q962.214 1459.58 962.214 1468.33 Q962.214 1477.06 959.135 1481.67 Q956.08 1486.25 950.27 1486.25 Q944.459 1486.25 941.381 1481.67 Q938.325 1477.06 938.325 1468.33 Q938.325 1459.58 941.381 1455 Q944.459 1450.39 950.27 1450.39 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M970.432 1479.7 L975.316 1479.7 L975.316 1485.58 L970.432 1485.58 L970.432 1479.7 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M998.348 1455.09 L986.543 1473.54 L998.348 1473.54 L998.348 1455.09 M997.121 1451.02 L1003 1451.02 L1003 1473.54 L1007.93 1473.54 L1007.93 1477.43 L1003 1477.43 L1003 1485.58 L998.348 1485.58 L998.348 1477.43 L982.746 1477.43 L982.746 1472.92 L997.121 1451.02 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M1436.49 1454.1 Q1432.88 1454.1 1431.05 1457.66 Q1429.24 1461.2 1429.24 1468.33 Q1429.24 1475.44 1431.05 1479.01 Q1432.88 1482.55 1436.49 1482.55 Q1440.12 1482.55 1441.93 1479.01 Q1443.76 1475.44 1443.76 1468.33 Q1443.76 1461.2 1441.93 1457.66 Q1440.12 1454.1 1436.49 1454.1 M1436.49 1450.39 Q1442.3 1450.39 1445.36 1455 Q1448.43 1459.58 1448.43 1468.33 Q1448.43 1477.06 1445.36 1481.67 Q1442.3 1486.25 1436.49 1486.25 Q1430.68 1486.25 1427.6 1481.67 Q1424.55 1477.06 1424.55 1468.33 Q1424.55 1459.58 1427.6 1455 Q1430.68 1450.39 1436.49 1450.39 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M1456.65 1479.7 L1461.54 1479.7 L1461.54 1485.58 L1456.65 1485.58 L1456.65 1479.7 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M1482.3 1466.44 Q1479.15 1466.44 1477.3 1468.59 Q1475.47 1470.74 1475.47 1474.49 Q1475.47 1478.22 1477.3 1480.39 Q1479.15 1482.55 1482.3 1482.55 Q1485.45 1482.55 1487.28 1480.39 Q1489.13 1478.22 1489.13 1474.49 Q1489.13 1470.74 1487.28 1468.59 Q1485.45 1466.44 1482.3 1466.44 M1491.58 1451.78 L1491.58 1456.04 Q1489.82 1455.21 1488.02 1454.77 Q1486.24 1454.33 1484.48 1454.33 Q1479.85 1454.33 1477.39 1457.45 Q1474.96 1460.58 1474.61 1466.9 Q1475.98 1464.89 1478.04 1463.82 Q1480.1 1462.73 1482.58 1462.73 Q1487.79 1462.73 1490.8 1465.9 Q1493.83 1469.05 1493.83 1474.49 Q1493.83 1479.82 1490.68 1483.03 Q1487.53 1486.25 1482.3 1486.25 Q1476.3 1486.25 1473.13 1481.67 Q1469.96 1477.06 1469.96 1468.33 Q1469.96 1460.14 1473.85 1455.28 Q1477.74 1450.39 1484.29 1450.39 Q1486.05 1450.39 1487.83 1450.74 Q1489.64 1451.09 1491.58 1451.78 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M1922.68 1454.1 Q1919.06 1454.1 1917.24 1457.66 Q1915.43 1461.2 1915.43 1468.33 Q1915.43 1475.44 1917.24 1479.01 Q1919.06 1482.55 1922.68 1482.55 Q1926.31 1482.55 1928.12 1479.01 Q1929.94 1475.44 1929.94 1468.33 Q1929.94 1461.2 1928.12 1457.66 Q1926.31 1454.1 1922.68 1454.1 M1922.68 1450.39 Q1928.49 1450.39 1931.54 1455 Q1934.62 1459.58 1934.62 1468.33 Q1934.62 1477.06 1931.54 1481.67 Q1928.49 1486.25 1922.68 1486.25 Q1916.87 1486.25 1913.79 1481.67 Q1910.73 1477.06 1910.73 1468.33 Q1910.73 1459.58 1913.79 1455 Q1916.87 1450.39 1922.68 1450.39 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M1942.84 1479.7 L1947.72 1479.7 L1947.72 1485.58 L1942.84 1485.58 L1942.84 1479.7 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M1967.91 1469.17 Q1964.57 1469.17 1962.65 1470.95 Q1960.75 1472.73 1960.75 1475.86 Q1960.75 1478.98 1962.65 1480.77 Q1964.57 1482.55 1967.91 1482.55 Q1971.24 1482.55 1973.16 1480.77 Q1975.08 1478.96 1975.08 1475.86 Q1975.08 1472.73 1973.16 1470.95 Q1971.26 1469.17 1967.91 1469.17 M1963.23 1467.18 Q1960.22 1466.44 1958.53 1464.38 Q1956.87 1462.32 1956.87 1459.35 Q1956.87 1455.21 1959.81 1452.8 Q1962.77 1450.39 1967.91 1450.39 Q1973.07 1450.39 1976.01 1452.8 Q1978.95 1455.21 1978.95 1459.35 Q1978.95 1462.32 1977.26 1464.38 Q1975.59 1466.44 1972.61 1467.18 Q1975.99 1467.96 1977.86 1470.26 Q1979.76 1472.55 1979.76 1475.86 Q1979.76 1480.88 1976.68 1483.57 Q1973.62 1486.25 1967.91 1486.25 Q1962.19 1486.25 1959.11 1483.57 Q1956.06 1480.88 1956.06 1475.86 Q1956.06 1472.55 1957.95 1470.26 Q1959.85 1467.96 1963.23 1467.18 M1961.52 1459.79 Q1961.52 1462.48 1963.18 1463.98 Q1964.87 1465.49 1967.91 1465.49 Q1970.92 1465.49 1972.61 1463.98 Q1974.32 1462.48 1974.32 1459.79 Q1974.32 1457.11 1972.61 1455.6 Q1970.92 1454.1 1967.91 1454.1 Q1964.87 1454.1 1963.18 1455.6 Q1961.52 1457.11 1961.52 1459.79 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M1159.74 1533.45 L1159.74 1538.98 Q1157.26 1537.71 1154.58 1537.07 Q1151.91 1536.44 1149.04 1536.44 Q1144.68 1536.44 1142.49 1537.77 Q1140.32 1539.11 1140.32 1541.79 Q1140.32 1543.82 1141.88 1545 Q1143.44 1546.15 1148.15 1547.2 L1150.16 1547.64 Q1156.4 1548.98 1159.01 1551.43 Q1161.65 1553.85 1161.65 1558.21 Q1161.65 1563.17 1157.7 1566.07 Q1153.79 1568.97 1146.91 1568.97 Q1144.05 1568.97 1140.93 1568.39 Q1137.84 1567.85 1134.4 1566.74 L1134.4 1560.69 Q1137.65 1562.38 1140.8 1563.24 Q1143.95 1564.07 1147.04 1564.07 Q1151.18 1564.07 1153.41 1562.66 Q1155.63 1561.23 1155.63 1558.65 Q1155.63 1556.27 1154.01 1554.99 Q1152.42 1553.72 1146.98 1552.54 L1144.94 1552.07 Q1139.5 1550.92 1137.08 1548.56 Q1134.66 1546.18 1134.66 1542.04 Q1134.66 1537.01 1138.22 1534.27 Q1141.79 1531.54 1148.34 1531.54 Q1151.59 1531.54 1154.46 1532.01 Q1157.32 1532.49 1159.74 1533.45 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M1191.15 1518.52 L1204.65 1518.52 L1204.65 1523.07 L1197.01 1523.07 L1197.01 1572.09 L1204.65 1572.09 L1204.65 1576.64 L1191.15 1576.64 L1191.15 1518.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M1216.9 1518.52 L1222.79 1518.52 L1222.79 1547.77 L1240.27 1532.4 L1247.75 1532.4 L1228.84 1549.07 L1248.54 1568.04 L1240.9 1568.04 L1222.79 1550.63 L1222.79 1568.04 L1216.9 1568.04 L1216.9 1518.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M1255.13 1520.52 L1261.56 1520.52 L1261.56 1564.73 Q1261.56 1573.33 1258.28 1577.21 Q1255.03 1581.09 1247.81 1581.09 L1245.36 1581.09 L1245.36 1575.68 L1247.36 1575.68 Q1251.63 1575.68 1253.38 1573.3 Q1255.13 1570.91 1255.13 1564.73 L1255.13 1520.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M1284.51 1520.52 L1289.92 1520.52 L1273.37 1574.09 L1267.96 1574.09 L1284.51 1520.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M1295.84 1518.52 L1301.73 1518.52 L1301.73 1547.77 L1319.2 1532.4 L1326.68 1532.4 L1307.77 1549.07 L1327.48 1568.04 L1319.84 1568.04 L1301.73 1550.63 L1301.73 1568.04 L1295.84 1568.04 L1295.84 1518.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M1357.27 1549.81 Q1357.27 1543.44 1354.63 1539.94 Q1352.02 1536.44 1347.27 1536.44 Q1342.56 1536.44 1339.92 1539.94 Q1337.31 1543.44 1337.31 1549.81 Q1337.31 1556.14 1339.92 1559.64 Q1342.56 1563.14 1347.27 1563.14 Q1352.02 1563.14 1354.63 1559.64 Q1357.27 1556.14 1357.27 1549.81 M1363.12 1563.62 Q1363.12 1572.72 1359.08 1577.15 Q1355.04 1581.6 1346.7 1581.6 Q1343.61 1581.6 1340.88 1581.13 Q1338.14 1580.68 1335.56 1579.72 L1335.56 1574.03 Q1338.14 1575.43 1340.65 1576.1 Q1343.17 1576.76 1345.78 1576.76 Q1351.54 1576.76 1354.4 1573.74 Q1357.27 1570.75 1357.27 1564.67 L1357.27 1561.77 Q1355.45 1564.92 1352.62 1566.48 Q1349.79 1568.04 1345.84 1568.04 Q1339.28 1568.04 1335.27 1563.05 Q1331.26 1558.05 1331.26 1549.81 Q1331.26 1541.53 1335.27 1536.53 Q1339.28 1531.54 1345.84 1531.54 Q1349.79 1531.54 1352.62 1533.1 Q1355.45 1534.66 1357.27 1537.81 L1357.27 1532.4 L1363.12 1532.4 L1363.12 1563.62 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M1376.01 1559.96 L1382.73 1559.96 L1382.73 1568.04 L1376.01 1568.04 L1376.01 1559.96 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M1396.16 1520.52 L1402.59 1520.52 L1402.59 1540.61 L1423.92 1520.52 L1432.19 1520.52 L1408.61 1542.68 L1433.88 1568.04 L1425.41 1568.04 L1402.59 1545.16 L1402.59 1568.04 L1396.16 1568.04 L1396.16 1520.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M1452.34 1518.52 L1452.34 1576.64 L1438.84 1576.64 L1438.84 1572.09 L1446.45 1572.09 L1446.45 1523.07 L1438.84 1523.07 L1438.84 1518.52 L1452.34 1518.52 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><polyline clip-path="url(#clip870)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="233.987,1423.18 233.987,47.2441 "/>
<polyline clip-path="url(#clip870)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="233.987,1178.19 252.884,1178.19 "/>
<polyline clip-path="url(#clip870)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="233.987,903.017 252.884,903.017 "/>
<polyline clip-path="url(#clip870)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="233.987,627.842 252.884,627.842 "/>
<polyline clip-path="url(#clip870)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="233.987,352.666 252.884,352.666 "/>
<polyline clip-path="url(#clip870)" style="stroke:#000000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="233.987,77.4901 252.884,77.4901 "/>
<path clip-path="url(#clip870)" d="M120.742 1191.54 L137.061 1191.54 L137.061 1195.47 L115.117 1195.47 L115.117 1191.54 Q117.779 1188.78 122.362 1184.15 Q126.968 1179.5 128.149 1178.16 Q130.394 1175.64 131.274 1173.9 Q132.177 1172.14 132.177 1170.45 Q132.177 1167.7 130.232 1165.96 Q128.311 1164.22 125.209 1164.22 Q123.01 1164.22 120.556 1164.99 Q118.126 1165.75 115.348 1167.3 L115.348 1162.58 Q118.172 1161.45 120.626 1160.87 Q123.08 1160.29 125.117 1160.29 Q130.487 1160.29 133.681 1162.97 Q136.876 1165.66 136.876 1170.15 Q136.876 1172.28 136.066 1174.2 Q135.279 1176.1 133.172 1178.69 Q132.593 1179.36 129.492 1182.58 Q126.39 1185.77 120.742 1191.54 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M145.695 1160.91 L167.917 1160.91 L167.917 1162.9 L155.371 1195.47 L150.487 1195.47 L162.292 1164.85 L145.695 1164.85 L145.695 1160.91 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M177.084 1160.91 L195.44 1160.91 L195.44 1164.85 L181.366 1164.85 L181.366 1173.32 Q182.385 1172.97 183.403 1172.81 Q184.422 1172.63 185.44 1172.63 Q191.227 1172.63 194.607 1175.8 Q197.987 1178.97 197.987 1184.39 Q197.987 1189.96 194.514 1193.07 Q191.042 1196.14 184.723 1196.14 Q182.547 1196.14 180.278 1195.77 Q178.033 1195.4 175.626 1194.66 L175.626 1189.96 Q177.709 1191.1 179.931 1191.65 Q182.153 1192.21 184.63 1192.21 Q188.635 1192.21 190.973 1190.1 Q193.311 1188 193.311 1184.39 Q193.311 1180.77 190.973 1178.67 Q188.635 1176.56 184.63 1176.56 Q182.755 1176.56 180.88 1176.98 Q179.028 1177.39 177.084 1178.27 L177.084 1160.91 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M129.885 901.663 Q133.242 902.381 135.117 904.649 Q137.015 906.918 137.015 910.251 Q137.015 915.367 133.496 918.168 Q129.978 920.969 123.496 920.969 Q121.32 920.969 119.006 920.529 Q116.714 920.112 114.26 919.256 L114.26 914.742 Q116.205 915.876 118.519 916.455 Q120.834 917.033 123.357 917.033 Q127.755 917.033 130.047 915.297 Q132.362 913.561 132.362 910.251 Q132.362 907.195 130.209 905.482 Q128.08 903.746 124.26 903.746 L120.232 903.746 L120.232 899.904 L124.445 899.904 Q127.894 899.904 129.723 898.538 Q131.552 897.149 131.552 894.557 Q131.552 891.895 129.654 890.483 Q127.779 889.047 124.26 889.047 Q122.339 889.047 120.14 889.464 Q117.941 889.881 115.302 890.76 L115.302 886.594 Q117.964 885.853 120.279 885.483 Q122.617 885.112 124.677 885.112 Q130.001 885.112 133.103 887.543 Q136.204 889.95 136.204 894.071 Q136.204 896.941 134.561 898.932 Q132.917 900.899 129.885 901.663 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M155.88 888.816 Q152.269 888.816 150.441 892.381 Q148.635 895.922 148.635 903.052 Q148.635 910.158 150.441 913.723 Q152.269 917.265 155.88 917.265 Q159.515 917.265 161.32 913.723 Q163.149 910.158 163.149 903.052 Q163.149 895.922 161.32 892.381 Q159.515 888.816 155.88 888.816 M155.88 885.112 Q161.69 885.112 164.746 889.719 Q167.825 894.302 167.825 903.052 Q167.825 911.779 164.746 916.385 Q161.69 920.969 155.88 920.969 Q150.07 920.969 146.991 916.385 Q143.936 911.779 143.936 903.052 Q143.936 894.302 146.991 889.719 Q150.07 885.112 155.88 885.112 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M186.042 888.816 Q182.431 888.816 180.602 892.381 Q178.797 895.922 178.797 903.052 Q178.797 910.158 180.602 913.723 Q182.431 917.265 186.042 917.265 Q189.676 917.265 191.482 913.723 Q193.311 910.158 193.311 903.052 Q193.311 895.922 191.482 892.381 Q189.676 888.816 186.042 888.816 M186.042 885.112 Q191.852 885.112 194.908 889.719 Q197.987 894.302 197.987 903.052 Q197.987 911.779 194.908 916.385 Q191.852 920.969 186.042 920.969 Q180.232 920.969 177.153 916.385 Q174.098 911.779 174.098 903.052 Q174.098 894.302 177.153 889.719 Q180.232 885.112 186.042 885.112 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M130.88 626.487 Q134.237 627.205 136.112 629.473 Q138.01 631.742 138.01 635.075 Q138.01 640.191 134.492 642.992 Q130.973 645.793 124.492 645.793 Q122.316 645.793 120.001 645.353 Q117.709 644.936 115.256 644.08 L115.256 639.566 Q117.2 640.7 119.515 641.279 Q121.83 641.858 124.353 641.858 Q128.751 641.858 131.042 640.122 Q133.357 638.385 133.357 635.075 Q133.357 632.02 131.205 630.307 Q129.075 628.571 125.255 628.571 L121.228 628.571 L121.228 624.728 L125.441 624.728 Q128.89 624.728 130.718 623.362 Q132.547 621.973 132.547 619.381 Q132.547 616.719 130.649 615.307 Q128.774 613.872 125.255 613.872 Q123.334 613.872 121.135 614.288 Q118.936 614.705 116.297 615.585 L116.297 611.418 Q118.959 610.677 121.274 610.307 Q123.612 609.937 125.672 609.937 Q130.996 609.937 134.098 612.367 Q137.2 614.774 137.2 618.895 Q137.2 621.765 135.556 623.756 Q133.913 625.723 130.88 626.487 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M150.903 641.186 L167.223 641.186 L167.223 645.122 L145.279 645.122 L145.279 641.186 Q147.941 638.432 152.524 633.802 Q157.13 629.149 158.311 627.807 Q160.556 625.284 161.436 623.548 Q162.339 621.788 162.339 620.099 Q162.339 617.344 160.394 615.608 Q158.473 613.872 155.371 613.872 Q153.172 613.872 150.718 614.636 Q148.288 615.399 145.51 616.95 L145.51 612.228 Q148.334 611.094 150.788 610.515 Q153.241 609.937 155.278 609.937 Q160.649 609.937 163.843 612.622 Q167.038 615.307 167.038 619.798 Q167.038 621.927 166.227 623.848 Q165.44 625.747 163.334 628.339 Q162.755 629.01 159.653 632.228 Q156.552 635.422 150.903 641.186 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M177.084 610.562 L195.44 610.562 L195.44 614.497 L181.366 614.497 L181.366 622.969 Q182.385 622.622 183.403 622.46 Q184.422 622.274 185.44 622.274 Q191.227 622.274 194.607 625.446 Q197.987 628.617 197.987 634.034 Q197.987 639.612 194.514 642.714 Q191.042 645.793 184.723 645.793 Q182.547 645.793 180.278 645.422 Q178.033 645.052 175.626 644.311 L175.626 639.612 Q177.709 640.747 179.931 641.302 Q182.153 641.858 184.63 641.858 Q188.635 641.858 190.973 639.751 Q193.311 637.645 193.311 634.034 Q193.311 630.423 190.973 628.316 Q188.635 626.21 184.63 626.21 Q182.755 626.21 180.88 626.626 Q179.028 627.043 177.084 627.923 L177.084 610.562 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M129.885 351.312 Q133.242 352.029 135.117 354.298 Q137.015 356.566 137.015 359.9 Q137.015 365.015 133.496 367.816 Q129.978 370.617 123.496 370.617 Q121.32 370.617 119.006 370.177 Q116.714 369.761 114.26 368.904 L114.26 364.39 Q116.205 365.525 118.519 366.103 Q120.834 366.682 123.357 366.682 Q127.755 366.682 130.047 364.946 Q132.362 363.21 132.362 359.9 Q132.362 356.844 130.209 355.131 Q128.08 353.395 124.26 353.395 L120.232 353.395 L120.232 349.552 L124.445 349.552 Q127.894 349.552 129.723 348.187 Q131.552 346.798 131.552 344.205 Q131.552 341.543 129.654 340.131 Q127.779 338.696 124.26 338.696 Q122.339 338.696 120.14 339.113 Q117.941 339.529 115.302 340.409 L115.302 336.242 Q117.964 335.502 120.279 335.131 Q122.617 334.761 124.677 334.761 Q130.001 334.761 133.103 337.191 Q136.204 339.599 136.204 343.719 Q136.204 346.589 134.561 348.58 Q132.917 350.548 129.885 351.312 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M145.927 335.386 L164.283 335.386 L164.283 339.321 L150.209 339.321 L150.209 347.793 Q151.228 347.446 152.246 347.284 Q153.265 347.099 154.283 347.099 Q160.07 347.099 163.45 350.27 Q166.829 353.441 166.829 358.858 Q166.829 364.437 163.357 367.538 Q159.885 370.617 153.566 370.617 Q151.39 370.617 149.121 370.247 Q146.876 369.876 144.468 369.136 L144.468 364.437 Q146.552 365.571 148.774 366.126 Q150.996 366.682 153.473 366.682 Q157.478 366.682 159.815 364.575 Q162.153 362.469 162.153 358.858 Q162.153 355.247 159.815 353.14 Q157.478 351.034 153.473 351.034 Q151.598 351.034 149.723 351.451 Q147.871 351.867 145.927 352.747 L145.927 335.386 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M186.042 338.465 Q182.431 338.465 180.602 342.029 Q178.797 345.571 178.797 352.701 Q178.797 359.807 180.602 363.372 Q182.431 366.913 186.042 366.913 Q189.676 366.913 191.482 363.372 Q193.311 359.807 193.311 352.701 Q193.311 345.571 191.482 342.029 Q189.676 338.465 186.042 338.465 M186.042 334.761 Q191.852 334.761 194.908 339.367 Q197.987 343.951 197.987 352.701 Q197.987 361.427 194.908 366.034 Q191.852 370.617 186.042 370.617 Q180.232 370.617 177.153 366.034 Q174.098 361.427 174.098 352.701 Q174.098 343.951 177.153 339.367 Q180.232 334.761 186.042 334.761 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M130.88 76.136 Q134.237 76.8535 136.112 79.1221 Q138.01 81.3906 138.01 84.7239 Q138.01 89.8396 134.492 92.6405 Q130.973 95.4414 124.492 95.4414 Q122.316 95.4414 120.001 95.0016 Q117.709 94.5849 115.256 93.7285 L115.256 89.2146 Q117.2 90.3488 119.515 90.9275 Q121.83 91.5062 124.353 91.5062 Q128.751 91.5062 131.042 89.7701 Q133.357 88.034 133.357 84.7239 Q133.357 81.6683 131.205 79.9554 Q129.075 78.2193 125.255 78.2193 L121.228 78.2193 L121.228 74.3767 L125.441 74.3767 Q128.89 74.3767 130.718 73.011 Q132.547 71.6221 132.547 69.0295 Q132.547 66.3675 130.649 64.9555 Q128.774 63.5203 125.255 63.5203 Q123.334 63.5203 121.135 63.937 Q118.936 64.3536 116.297 65.2332 L116.297 61.0666 Q118.959 60.3259 121.274 59.9555 Q123.612 59.5851 125.672 59.5851 Q130.996 59.5851 134.098 62.0157 Q137.2 64.4231 137.2 68.5434 Q137.2 71.4138 135.556 73.4045 Q133.913 75.3721 130.88 76.136 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M145.695 60.2101 L167.917 60.2101 L167.917 62.2009 L155.371 94.7701 L150.487 94.7701 L162.292 64.1453 L145.695 64.1453 L145.695 60.2101 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M177.084 60.2101 L195.44 60.2101 L195.44 64.1453 L181.366 64.1453 L181.366 72.6175 Q182.385 72.2702 183.403 72.1082 Q184.422 71.923 185.44 71.923 Q191.227 71.923 194.607 75.0943 Q197.987 78.2656 197.987 83.6822 Q197.987 89.2609 194.514 92.3627 Q191.042 95.4414 184.723 95.4414 Q182.547 95.4414 180.278 95.071 Q178.033 94.7007 175.626 93.9599 L175.626 89.2609 Q177.709 90.3951 179.931 90.9507 Q182.153 91.5062 184.63 91.5062 Q188.635 91.5062 190.973 89.3998 Q193.311 87.2933 193.311 83.6822 Q193.311 80.0711 190.973 77.9647 Q188.635 75.8582 184.63 75.8582 Q182.755 75.8582 180.88 76.2748 Q179.028 76.6915 177.084 77.5711 L177.084 60.2101 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M16.4842 809.579 L16.4842 769.38 L21.895 769.38 L21.895 786.249 L64.0042 786.249 L64.0042 792.71 L21.895 792.71 L21.895 809.579 L16.4842 809.579 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M14.479 743.249 L14.479 729.753 L19.0304 729.753 L19.0304 737.392 L68.0464 737.392 L68.0464 729.753 L72.5979 729.753 L72.5979 743.249 L14.479 743.249 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M16.4842 717.022 L16.4842 710.593 L36.568 710.593 L16.4842 689.267 L16.4842 680.992 L38.6368 704.577 L64.0042 679.305 L64.0042 687.772 L41.1194 710.593 L64.0042 710.593 L64.0042 717.022 L16.4842 717.022 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M14.479 660.845 L72.5979 660.845 L72.5979 674.34 L68.0464 674.34 L68.0464 666.733 L19.0304 666.733 L19.0304 674.34 L14.479 674.34 L14.479 660.845 Z" fill="#000000" fill-rule="evenodd" fill-opacity="1" /><polyline clip-path="url(#clip872)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:0.25; fill:none" points="456.991,1236.19 616.09,1087.97 761.415,949.966 894.408,822.188 1016.24,704.632 1127.87,597.299 1230.08,500.187 1323.52,413.298 1408.77,336.631 1486.34,270.186 1556.75,213.964 1620.59,167.964 1678.67,132.186 1732.53,106.63 1786.88,91.2968 1863.8,86.1857 1926.86,91.2968 1996.54,106.63 2052.26,132.186 2089.14,167.964 2120.19,213.964 2146.22,270.186 2167.8,336.631 2185.47,413.298 2199.83,500.187 2211.56,597.299 2221.5,704.632 2230.69,822.188 2240.47,949.966 2252.63,1087.97 2269.57,1236.19 "/>
<polyline clip-path="url(#clip872)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1173.07,1025.36 2246.8,1025.36 "/>
<polyline clip-path="url(#clip872)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2246.8,1025.36 2287.92,498.301 "/>
<polyline clip-path="url(#clip872)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2287.92,498.301 2210.85,590.605 1134.86,590.605 "/>
<polyline clip-path="url(#clip872)" style="stroke:#0000ff; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="1134.86,590.605 1144.41,784.511 1153.97,885.969 1163.52,962.345 1173.07,1025.36 "/>
<polyline clip-path="url(#clip872)" style="stroke:#ff0000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:0.25; fill:none" points="293.952,1384.24 477.872,1216.93 644.494,1061.17 795.899,916.939 933.739,784.25 1059.34,663.098 1173.78,553.485 1277.92,455.41 1372.5,368.873 1458.16,293.874 1535.51,230.414 1605.23,178.492 1668.18,138.108 1725.93,109.262 1783.3,91.9548 1863.8,86.1857 1930.97,91.9548 2005.92,109.262 2059.66,138.108 2097.4,178.492 2128.82,230.414 2154.79,293.874 2175.97,368.873 2193.02,455.41 2206.69,553.485 2217.91,663.098 2227.81,784.25 2237.87,916.939 2250.05,1061.17 2267.07,1216.93 2292.79,1384.24 "/>
<polyline clip-path="url(#clip872)" style="stroke:#ff0000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2287.16,899.379 2241.37,961.116 749.752,961.116 "/>
<polyline clip-path="url(#clip872)" style="stroke:#ff0000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="2270.85,1245.71 2287.16,899.379 "/>
<polyline clip-path="url(#clip872)" style="stroke:#ff0000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="749.752,961.116 758.247,1156.99 766.742,1245.71 "/>
<polyline clip-path="url(#clip872)" style="stroke:#ff0000; stroke-linecap:round; stroke-linejoin:round; stroke-width:4; stroke-opacity:1; fill:none" points="766.742,1245.71 2270.85,1245.71 "/>
<path clip-path="url(#clip870)" d="M1104.13 1061.78 L1104.13 1001.36 L1150.86 1001.36 L1150.86 1061.78 L1104.13 1061.78 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M1149.7 1061.78 L1149.7 1001.36 L1196.43 1001.36 L1196.43 1061.78 L1149.7 1061.78 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M1195.27 1061.78 L1195.27 1001.36 L1242 1001.36 L1242 1061.78 L1195.27 1061.78 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M1145.35 1017.48 L1145.35 1021.51 Q1143.54 1020.58 1141.6 1020.12 Q1139.65 1019.66 1137.57 1019.66 Q1134.4 1019.66 1132.8 1020.63 Q1131.23 1021.6 1131.23 1023.55 Q1131.23 1025.03 1132.36 1025.89 Q1133.5 1026.72 1136.92 1027.48 L1138.38 1027.81 Q1142.92 1028.78 1144.81 1030.56 Q1146.74 1032.32 1146.74 1035.49 Q1146.74 1039.1 1143.87 1041.21 Q1141.02 1043.32 1136.02 1043.32 Q1133.93 1043.32 1131.67 1042.9 Q1129.42 1042.51 1126.92 1041.7 L1126.92 1037.3 Q1129.28 1038.52 1131.57 1039.15 Q1133.87 1039.75 1136.11 1039.75 Q1139.12 1039.75 1140.74 1038.73 Q1142.36 1037.69 1142.36 1035.82 Q1142.36 1034.08 1141.18 1033.15 Q1140.02 1032.23 1136.06 1031.37 L1134.58 1031.02 Q1130.62 1030.19 1128.87 1028.48 Q1127.11 1026.74 1127.11 1023.73 Q1127.11 1020.07 1129.7 1018.08 Q1132.29 1016.09 1137.06 1016.09 Q1139.42 1016.09 1141.5 1016.44 Q1143.59 1016.79 1145.35 1017.48 Z" fill="#0000ff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M1157.73 1009.36 L1157.73 1016.72 L1166.5 1016.72 L1166.5 1020.03 L1157.73 1020.03 L1157.73 1034.1 Q1157.73 1037.27 1158.59 1038.18 Q1159.47 1039.08 1162.13 1039.08 L1166.5 1039.08 L1166.5 1042.64 L1162.13 1042.64 Q1157.2 1042.64 1155.32 1040.82 Q1153.45 1038.96 1153.45 1034.1 L1153.45 1020.03 L1150.32 1020.03 L1150.32 1016.72 L1153.45 1016.72 L1153.45 1009.36 L1157.73 1009.36 Z" fill="#0000ff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M1176.97 1011.93 L1176.97 1038.8 L1182.62 1038.8 Q1189.77 1038.8 1193.08 1035.56 Q1196.41 1032.32 1196.41 1025.33 Q1196.41 1018.39 1193.08 1015.17 Q1189.77 1011.93 1182.62 1011.93 L1176.97 1011.93 M1172.29 1008.08 L1181.9 1008.08 Q1191.94 1008.08 1196.64 1012.27 Q1201.34 1016.44 1201.34 1025.33 Q1201.34 1034.26 1196.62 1038.45 Q1191.9 1042.64 1181.9 1042.64 L1172.29 1042.64 L1172.29 1008.08 Z" fill="#0000ff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M2200.64 1061.78 L2200.64 1001.36 L2247.37 1001.36 L2247.37 1061.78 L2200.64 1061.78 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M2246.22 1061.78 L2246.22 1001.36 L2292.95 1001.36 L2292.95 1061.78 L2246.22 1061.78 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M2228.84 1017.48 L2228.84 1021.51 Q2227.04 1020.58 2225.09 1020.12 Q2223.15 1019.66 2221.07 1019.66 Q2217.9 1019.66 2216.3 1020.63 Q2214.72 1021.6 2214.72 1023.55 Q2214.72 1025.03 2215.86 1025.89 Q2216.99 1026.72 2220.42 1027.48 L2221.88 1027.81 Q2226.41 1028.78 2228.31 1030.56 Q2230.23 1032.32 2230.23 1035.49 Q2230.23 1039.1 2227.36 1041.21 Q2224.52 1043.32 2219.52 1043.32 Q2217.43 1043.32 2215.16 1042.9 Q2212.92 1042.51 2210.42 1041.7 L2210.42 1037.3 Q2212.78 1038.52 2215.07 1039.15 Q2217.36 1039.75 2219.61 1039.75 Q2222.62 1039.75 2224.24 1038.73 Q2225.86 1037.69 2225.86 1035.82 Q2225.86 1034.08 2224.68 1033.15 Q2223.52 1032.23 2219.56 1031.37 L2218.08 1031.02 Q2214.12 1030.19 2212.36 1028.48 Q2210.6 1026.74 2210.6 1023.73 Q2210.6 1020.07 2213.2 1018.08 Q2215.79 1016.09 2220.56 1016.09 Q2222.92 1016.09 2225 1016.44 Q2227.09 1016.79 2228.84 1017.48 Z" fill="#0000ff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M2241.23 1009.36 L2241.23 1016.72 L2250 1016.72 L2250 1020.03 L2241.23 1020.03 L2241.23 1034.1 Q2241.23 1037.27 2242.09 1038.18 Q2242.96 1039.08 2245.63 1039.08 L2250 1039.08 L2250 1042.64 L2245.63 1042.64 Q2240.7 1042.64 2238.82 1040.82 Q2236.95 1038.96 2236.95 1034.1 L2236.95 1020.03 L2233.82 1020.03 L2233.82 1016.72 L2236.95 1016.72 L2236.95 1009.36 L2241.23 1009.36 Z" fill="#0000ff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M2267.34 1012.69 L2261 1029.89 L2273.71 1029.89 L2267.34 1012.69 M2264.7 1008.08 L2270 1008.08 L2283.17 1042.64 L2278.31 1042.64 L2275.16 1033.78 L2259.59 1033.78 L2256.44 1042.64 L2251.51 1042.64 L2264.7 1008.08 Z" fill="#0000ff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M2241.77 534.716 L2241.77 474.299 L2288.5 474.299 L2288.5 534.716 L2241.77 534.716 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M2287.35 534.716 L2287.35 474.299 L2334.08 474.299 L2334.08 534.716 L2287.35 534.716 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M2271.41 490.419 L2271.41 494.447 Q2269.6 493.521 2267.66 493.058 Q2265.71 492.595 2263.63 492.595 Q2260.46 492.595 2258.86 493.567 Q2257.29 494.54 2257.29 496.484 Q2257.29 497.965 2258.42 498.822 Q2259.56 499.655 2262.98 500.419 L2264.44 500.743 Q2268.98 501.715 2270.88 503.498 Q2272.8 505.257 2272.8 508.428 Q2272.8 512.039 2269.93 514.146 Q2267.08 516.252 2262.08 516.252 Q2260 516.252 2257.73 515.836 Q2255.48 515.442 2252.98 514.632 L2252.98 510.234 Q2255.34 511.461 2257.64 512.086 Q2259.93 512.688 2262.17 512.688 Q2265.18 512.688 2266.8 511.669 Q2268.42 510.627 2268.42 508.752 Q2268.42 507.016 2267.24 506.09 Q2266.08 505.164 2262.13 504.308 L2260.64 503.961 Q2256.69 503.127 2254.93 501.415 Q2253.17 499.678 2253.17 496.669 Q2253.17 493.012 2255.76 491.021 Q2258.35 489.03 2263.12 489.03 Q2265.48 489.03 2267.57 489.378 Q2269.65 489.725 2271.41 490.419 Z" fill="#0000ff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M2283.79 482.294 L2283.79 489.655 L2292.57 489.655 L2292.57 492.965 L2283.79 492.965 L2283.79 507.039 Q2283.79 510.211 2284.65 511.114 Q2285.53 512.016 2288.19 512.016 L2292.57 512.016 L2292.57 515.581 L2288.19 515.581 Q2283.26 515.581 2281.39 513.752 Q2279.51 511.901 2279.51 507.039 L2279.51 492.965 L2276.39 492.965 L2276.39 489.655 L2279.51 489.655 L2279.51 482.294 L2283.79 482.294 Z" fill="#0000ff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M2303.03 499.077 L2303.03 511.739 L2310.53 511.739 Q2314.3 511.739 2316.11 510.188 Q2317.94 508.614 2317.94 505.396 Q2317.94 502.155 2316.11 500.627 Q2314.3 499.077 2310.53 499.077 L2303.03 499.077 M2303.03 484.864 L2303.03 495.28 L2309.95 495.28 Q2313.38 495.28 2315.04 494.007 Q2316.73 492.711 2316.73 490.072 Q2316.73 487.456 2315.04 486.16 Q2313.38 484.864 2309.95 484.864 L2303.03 484.864 M2298.35 481.021 L2310.3 481.021 Q2315.64 481.021 2318.54 483.243 Q2321.43 485.466 2321.43 489.563 Q2321.43 492.734 2319.95 494.609 Q2318.47 496.484 2315.6 496.947 Q2319.05 497.688 2320.95 500.049 Q2322.87 502.387 2322.87 505.905 Q2322.87 510.535 2319.72 513.058 Q2316.57 515.581 2310.76 515.581 L2298.35 515.581 L2298.35 481.021 Z" fill="#0000ff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M1088.71 627.02 L1088.71 566.604 L1135.44 566.604 L1135.44 627.02 L1088.71 627.02 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M1134.29 627.02 L1134.29 566.604 L1181.02 566.604 L1181.02 627.02 L1134.29 627.02 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M1117.66 582.724 L1117.66 586.751 Q1115.86 585.825 1113.91 585.362 Q1111.97 584.899 1109.89 584.899 Q1106.72 584.899 1105.12 585.872 Q1103.54 586.844 1103.54 588.788 Q1103.54 590.27 1104.68 591.126 Q1105.81 591.96 1109.24 592.723 L1110.7 593.048 Q1115.23 594.02 1117.13 595.802 Q1119.05 597.561 1119.05 600.733 Q1119.05 604.344 1116.18 606.45 Q1113.34 608.557 1108.34 608.557 Q1106.25 608.557 1103.98 608.14 Q1101.74 607.747 1099.24 606.936 L1099.24 602.538 Q1101.6 603.765 1103.89 604.39 Q1106.18 604.992 1108.43 604.992 Q1111.44 604.992 1113.06 603.973 Q1114.68 602.932 1114.68 601.057 Q1114.68 599.321 1113.5 598.395 Q1112.34 597.469 1108.38 596.612 L1106.9 596.265 Q1102.94 595.432 1101.18 593.719 Q1099.42 591.983 1099.42 588.973 Q1099.42 585.316 1102.02 583.325 Q1104.61 581.335 1109.38 581.335 Q1111.74 581.335 1113.82 581.682 Q1115.91 582.029 1117.66 582.724 Z" fill="#0000ff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M1130.05 574.599 L1130.05 581.96 L1138.82 581.96 L1138.82 585.27 L1130.05 585.27 L1130.05 599.344 Q1130.05 602.515 1130.91 603.418 Q1131.79 604.321 1134.45 604.321 L1138.82 604.321 L1138.82 607.885 L1134.45 607.885 Q1129.52 607.885 1127.64 606.057 Q1125.77 604.205 1125.77 599.344 L1125.77 585.27 L1122.64 585.27 L1122.64 581.96 L1125.77 581.96 L1125.77 574.599 L1130.05 574.599 Z" fill="#0000ff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M1170.49 575.987 L1170.49 580.918 Q1168.13 578.719 1165.44 577.631 Q1162.78 576.543 1159.77 576.543 Q1153.85 576.543 1150.7 580.177 Q1147.55 583.788 1147.55 590.64 Q1147.55 597.469 1150.7 601.103 Q1153.85 604.714 1159.77 604.714 Q1162.78 604.714 1165.44 603.626 Q1168.13 602.538 1170.49 600.339 L1170.49 605.223 Q1168.03 606.89 1165.28 607.723 Q1162.55 608.557 1159.49 608.557 Q1151.65 608.557 1147.13 603.765 Q1142.62 598.95 1142.62 590.64 Q1142.62 582.307 1147.13 577.515 Q1151.65 572.7 1159.49 572.7 Q1162.6 572.7 1165.33 573.534 Q1168.08 574.344 1170.49 575.987 Z" fill="#0000ff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M2218.23 935.793 L2218.23 875.377 L2264.96 875.377 L2264.96 935.793 L2218.23 935.793 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M2263.8 935.793 L2263.8 875.377 L2310.53 875.377 L2310.53 935.793 L2263.8 935.793 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M2309.37 935.793 L2309.37 875.377 L2356.1 875.377 L2356.1 935.793 L2309.37 935.793 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M2262.62 891.497 L2262.62 895.524 Q2260.81 894.599 2258.87 894.136 Q2256.92 893.673 2254.84 893.673 Q2251.67 893.673 2250.07 894.645 Q2248.5 895.617 2248.5 897.561 Q2248.5 899.043 2249.63 899.899 Q2250.76 900.733 2254.19 901.497 L2255.65 901.821 Q2260.19 902.793 2262.08 904.575 Q2264 906.335 2264 909.506 Q2264 913.117 2261.13 915.223 Q2258.29 917.33 2253.29 917.33 Q2251.2 917.33 2248.94 916.913 Q2246.69 916.52 2244.19 915.71 L2244.19 911.311 Q2246.55 912.538 2248.84 913.163 Q2251.13 913.765 2253.38 913.765 Q2256.39 913.765 2258.01 912.747 Q2259.63 911.705 2259.63 909.83 Q2259.63 908.094 2258.45 907.168 Q2257.29 906.242 2253.33 905.386 L2251.85 905.038 Q2247.89 904.205 2246.13 902.492 Q2244.38 900.756 2244.38 897.747 Q2244.38 894.089 2246.97 892.099 Q2249.56 890.108 2254.33 890.108 Q2256.69 890.108 2258.77 890.455 Q2260.86 890.802 2262.62 891.497 Z" fill="#ff0000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M2275 883.372 L2275 890.733 L2283.77 890.733 L2283.77 894.043 L2275 894.043 L2275 908.117 Q2275 911.288 2275.86 912.191 Q2276.74 913.094 2279.4 913.094 L2283.77 913.094 L2283.77 916.659 L2279.4 916.659 Q2274.47 916.659 2272.59 914.83 Q2270.72 912.978 2270.72 908.117 L2270.72 894.043 L2267.59 894.043 L2267.59 890.733 L2270.72 890.733 L2270.72 883.372 L2275 883.372 Z" fill="#ff0000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M2294 912.723 L2310.32 912.723 L2310.32 916.659 L2288.38 916.659 L2288.38 912.723 Q2291.04 909.969 2295.63 905.339 Q2300.23 900.686 2301.41 899.344 Q2303.66 896.821 2304.54 895.085 Q2305.44 893.325 2305.44 891.636 Q2305.44 888.881 2303.5 887.145 Q2301.57 885.409 2298.47 885.409 Q2296.27 885.409 2293.82 886.173 Q2291.39 886.937 2288.61 888.487 L2288.61 883.765 Q2291.44 882.631 2293.89 882.052 Q2296.34 881.474 2298.38 881.474 Q2303.75 881.474 2306.94 884.159 Q2310.14 886.844 2310.14 891.335 Q2310.14 893.464 2309.33 895.386 Q2308.54 897.284 2306.44 899.876 Q2305.86 900.548 2302.75 903.765 Q2299.65 906.96 2294 912.723 Z" fill="#ff0000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M703.6 997.531 L703.6 937.114 L750.33 937.114 L750.33 997.531 L703.6 997.531 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M749.173 997.531 L749.173 937.114 L795.903 937.114 L795.903 997.531 L749.173 997.531 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M734.636 953.234 L734.636 957.262 Q732.83 956.336 730.886 955.873 Q728.942 955.41 726.858 955.41 Q723.687 955.41 722.09 956.382 Q720.516 957.355 720.516 959.299 Q720.516 960.78 721.65 961.637 Q722.784 962.47 726.21 963.234 L727.668 963.558 Q732.205 964.53 734.104 966.313 Q736.025 968.072 736.025 971.243 Q736.025 974.854 733.154 976.961 Q730.307 979.067 725.307 979.067 Q723.224 979.067 720.955 978.651 Q718.71 978.257 716.21 977.447 L716.21 973.049 Q718.571 974.276 720.863 974.901 Q723.155 975.503 725.4 975.503 Q728.409 975.503 730.029 974.484 Q731.65 973.442 731.65 971.567 Q731.65 969.831 730.469 968.905 Q729.312 967.979 725.354 967.123 L723.872 966.776 Q719.914 965.942 718.155 964.229 Q716.395 962.493 716.395 959.484 Q716.395 955.827 718.988 953.836 Q721.58 951.845 726.349 951.845 Q728.71 951.845 730.793 952.193 Q732.877 952.54 734.636 953.234 Z" fill="#ff0000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M747.02 945.109 L747.02 952.47 L755.793 952.47 L755.793 955.78 L747.02 955.78 L747.02 969.854 Q747.02 973.026 747.877 973.928 Q748.756 974.831 751.418 974.831 L755.793 974.831 L755.793 978.396 L751.418 978.396 Q746.488 978.396 744.613 976.567 Q742.738 974.716 742.738 969.854 L742.738 955.78 L739.613 955.78 L739.613 952.47 L742.738 952.47 L742.738 945.109 L747.02 945.109 Z" fill="#ff0000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M776.163 959.762 Q779.52 960.479 781.395 962.748 Q783.293 965.017 783.293 968.35 Q783.293 973.466 779.775 976.266 Q776.256 979.067 769.775 979.067 Q767.599 979.067 765.284 978.628 Q762.992 978.211 760.539 977.354 L760.539 972.841 Q762.483 973.975 764.798 974.553 Q767.113 975.132 769.636 975.132 Q774.034 975.132 776.326 973.396 Q778.64 971.66 778.64 968.35 Q778.64 965.294 776.488 963.581 Q774.358 961.845 770.539 961.845 L766.511 961.845 L766.511 958.003 L770.724 958.003 Q774.173 958.003 776.001 956.637 Q777.83 955.248 777.83 952.655 Q777.83 949.993 775.932 948.581 Q774.057 947.146 770.539 947.146 Q768.617 947.146 766.418 947.563 Q764.219 947.98 761.58 948.859 L761.58 944.693 Q764.242 943.952 766.557 943.581 Q768.895 943.211 770.955 943.211 Q776.279 943.211 779.381 945.642 Q782.483 948.049 782.483 952.169 Q782.483 955.04 780.839 957.03 Q779.196 958.998 776.163 959.762 Z" fill="#ff0000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M2224.7 1282.12 L2224.7 1221.71 L2271.43 1221.71 L2271.43 1282.12 L2224.7 1282.12 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M2270.27 1282.12 L2270.27 1221.71 L2317 1221.71 L2317 1282.12 L2270.27 1282.12 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M2256.02 1237.83 L2256.02 1241.85 Q2254.22 1240.93 2252.27 1240.46 Q2250.33 1240 2248.25 1240 Q2245.07 1240 2243.48 1240.97 Q2241.9 1241.95 2241.9 1243.89 Q2241.9 1245.37 2243.04 1246.23 Q2244.17 1247.06 2247.6 1247.82 L2249.06 1248.15 Q2253.59 1249.12 2255.49 1250.9 Q2257.41 1252.66 2257.41 1255.83 Q2257.41 1259.45 2254.54 1261.55 Q2251.69 1263.66 2246.69 1263.66 Q2244.61 1263.66 2242.34 1263.24 Q2240.1 1262.85 2237.6 1262.04 L2237.6 1257.64 Q2239.96 1258.87 2242.25 1259.49 Q2244.54 1260.09 2246.79 1260.09 Q2249.8 1260.09 2251.42 1259.07 Q2253.04 1258.03 2253.04 1256.16 Q2253.04 1254.42 2251.86 1253.5 Q2250.7 1252.57 2246.74 1251.71 L2245.26 1251.37 Q2241.3 1250.53 2239.54 1248.82 Q2237.78 1247.08 2237.78 1244.07 Q2237.78 1240.42 2240.38 1238.43 Q2242.97 1236.44 2247.74 1236.44 Q2250.1 1236.44 2252.18 1236.78 Q2254.26 1237.13 2256.02 1237.83 Z" fill="#ff0000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M2268.41 1229.7 L2268.41 1237.06 L2277.18 1237.06 L2277.18 1240.37 L2268.41 1240.37 L2268.41 1254.45 Q2268.41 1257.62 2269.26 1258.52 Q2270.14 1259.42 2272.81 1259.42 L2277.18 1259.42 L2277.18 1262.99 L2272.81 1262.99 Q2267.88 1262.99 2266 1261.16 Q2264.13 1259.31 2264.13 1254.45 L2264.13 1240.37 L2261 1240.37 L2261 1237.06 L2264.13 1237.06 L2264.13 1229.7 L2268.41 1229.7 Z" fill="#ff0000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M2284.19 1259.05 L2291.83 1259.05 L2291.83 1232.69 L2283.52 1234.35 L2283.52 1230.09 L2291.79 1228.43 L2296.46 1228.43 L2296.46 1259.05 L2304.1 1259.05 L2304.1 1262.99 L2284.19 1262.99 L2284.19 1259.05 Z" fill="#ff0000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M720.591 1282.12 L720.591 1221.71 L767.321 1221.71 L767.321 1282.12 L720.591 1282.12 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M766.164 1282.12 L766.164 1221.71 L812.894 1221.71 L812.894 1282.12 L766.164 1282.12 Z" fill="#ffffff" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M751.06 1237.83 L751.06 1241.85 Q749.254 1240.93 747.31 1240.46 Q745.365 1240 743.282 1240 Q740.111 1240 738.513 1240.97 Q736.939 1241.95 736.939 1243.89 Q736.939 1245.37 738.074 1246.23 Q739.208 1247.06 742.634 1247.82 L744.092 1248.15 Q748.629 1249.12 750.527 1250.9 Q752.448 1252.66 752.448 1255.83 Q752.448 1259.45 749.578 1261.55 Q746.731 1263.66 741.731 1263.66 Q739.648 1263.66 737.379 1263.24 Q735.134 1262.85 732.634 1262.04 L732.634 1257.64 Q734.995 1258.87 737.287 1259.49 Q739.578 1260.09 741.824 1260.09 Q744.833 1260.09 746.453 1259.07 Q748.073 1258.03 748.073 1256.16 Q748.073 1254.42 746.893 1253.5 Q745.736 1252.57 741.777 1251.71 L740.296 1251.37 Q736.337 1250.53 734.578 1248.82 Q732.819 1247.08 732.819 1244.07 Q732.819 1240.42 735.412 1238.43 Q738.004 1236.44 742.773 1236.44 Q745.134 1236.44 747.217 1236.78 Q749.3 1237.13 751.06 1237.83 Z" fill="#ff0000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M763.444 1229.7 L763.444 1237.06 L772.217 1237.06 L772.217 1240.37 L763.444 1240.37 L763.444 1254.45 Q763.444 1257.62 764.3 1258.52 Q765.18 1259.42 767.842 1259.42 L772.217 1259.42 L772.217 1262.99 L767.842 1262.99 Q762.911 1262.99 761.036 1261.16 Q759.161 1259.31 759.161 1254.45 L759.161 1240.37 L756.036 1240.37 L756.036 1237.06 L759.161 1237.06 L759.161 1229.7 L763.444 1229.7 Z" fill="#ff0000" fill-rule="evenodd" fill-opacity="1" /><path clip-path="url(#clip870)" d="M791.268 1232.5 L779.462 1250.95 L791.268 1250.95 L791.268 1232.5 M790.041 1228.43 L795.92 1228.43 L795.92 1250.95 L800.851 1250.95 L800.851 1254.84 L795.92 1254.84 L795.92 1262.99 L791.268 1262.99 L791.268 1254.84 L775.666 1254.84 L775.666 1250.32 L790.041 1228.43 Z" fill="#ff0000" fill-rule="evenodd" fill-opacity="1" /></svg>
</div><div style=' border: 1px solid;'><div style='display: flex; justify-content: space-around; margin: 20px;'><div style = "display: inline-block; border: 1px solid #666666;"><!DOCTYPE html>
<html>
<meta charset="UTF-8">
<style>
  table, td, th {
      border-collapse: collapse; color: black;
      font-family: sans-serif;
  }

  td, th {
      border-bottom: 0;
      padding: 4px
  }

  tr:nth-child(odd) {
      background: #eee;
  }

  tr:nth-child(even) {
      background: #fff;
  }

  tr.header {
      background: #fff !important;
      font-weight: bold;
  }

  tr.subheader {
      background: #fff !important;
      color: dimgray;
  }

  tr.headerLastRow {
      border-bottom: 2px solid black;
  }

  th.rowNumber, td.rowNumber {
      text-align: right;
  }

</style>
<body>
<table>
  <thead>
    <tr class = "header headerLastRow">
      <th style = "color: black; text-align: center; padding: 11px;  font-size: 130%;"></th>
      <th style = "color: black; text-align: center; padding: 11px;  font-size: 130%;">Total</th>
      <th style = "color: black; text-align: center; padding: 11px;  font-size: 130%;">Component</th>
      <th style = "color: black; text-align: center; padding: 11px;  font-size: 130%;">Value</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <td style = "text-align: left; padding: 11px;  font-size: 130%;">qin<BR>Q̇in</td>
      <td style = "text-align: left; padding: 11px;  font-size: 130%;">166.4013 kJ/kg<BR>416.0033 kW</td>
      <td style = "text-align: left; padding: 11px;  font-size: 130%;">evaporator:<BR>   st4 &gt;&gt; st1</td>
      <td style = "text-align: left; padding: 11px;  font-size: 130%;">166.4013 kJ/kg<BR>416.0033 kW</td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 11px;  font-size: 130%;">qout<BR>Q̇out</td>
      <td style = "text-align: left; padding: 11px;  font-size: 130%;">155.9332 kJ/kg<BR>569.6185 kW</td>
      <td style = "text-align: left; padding: 11px;  font-size: 130%;">condenser:<BR>   stB &gt;&gt; stC</td>
      <td style = "text-align: left; padding: 11px;  font-size: 130%;">155.9332 kJ/kg<BR>569.6185 kW</td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 11px;  font-size: 130%;">win<BR>Ẇin</td>
      <td style = "text-align: left; padding: 11px;  font-size: 130%;">48.3941 kJ/kg<BR>153.6152 kW</td>
      <td style = "text-align: left; padding: 11px;  font-size: 130%;">compressor:<BR>   stA &gt;&gt; stB<BR><BR>compressor:<BR>   st1 &gt;&gt; st2</td>
      <td style = "text-align: left; padding: 11px;  font-size: 130%;">28.3008 kJ/kg<BR>103.3818 kW<BR><BR>20.0934 kJ/kg<BR>50.2334 kW</td>
    </tr>
    <tr>
      <td style = "text-align: left; padding: 11px;  font-size: 130%;">wout<BR>Ẇout</td>
      <td style = "text-align: left; padding: 11px;  font-size: 130%;">0.0 kJ/kg<BR>0.0 kW</td>
      <td style = "text-align: left; padding: 11px;  font-size: 130%;"></td>
      <td style = "text-align: left; padding: 11px;  font-size: 130%;"></td>
    </tr>
  </tbody>
</table>
</body>
</html>
</div></div><h2 style='text-align: center; border: 3px solid; padding: 15px; margin: 10px;'>Coefficient of performance (COP) = 2.7081</h2></div></div>
```
